<?php
/*
 * Plugin Name: MAKLI - Product Display & eCommerce
 * Description:  Easy to use and powerful WordPress eCommerce plugin from Makli.com. If you want to catalog/ display or sell easy and quick, Makli is for you. Three modes are supported. (1) Catalog/ Display only (2) Display with WooCommerce (3) Full Makli e-commerce
 * Version: 3.1-revision-1
 * Text Domain:ptsc
 * Domain Path: /languages
 * Author: creativeon.com
 * Author URI: http://creativeon.com/
*/


/*
 * Define the Constants
 *
 * */

define("PTSC_PATH", dirname(__FILE__));

define("PTSC_URL", untrailingslashit(plugins_url(basename(dirname(__FILE__)))));

define("PTSC_FILE", __FILE__);

define("PTSC_VERSION", 'Version 3.1-revision-1');

/*
//==========Include Files Here==============//
*/
require_once(PTSC_PATH . "/includes/class_install.php");
require_once(PTSC_PATH . '/includes/functions.php');
include('elementor-main-class.php');
global $ins;
$ins = new ptsc_install();

/*
//===========Function to load text domain directory=============//
*/

/*
//==========start Here==============//
*/
if (!function_exists('ptsc_get_textdomain')) {
    function ptsc_get_textdomain()
    {
        load_plugin_textdomain("ptsc", false, plugin_dir_url(__FILE__) . '/languages');
    }
}

/*
//==========End Here==============//
*/

add_action("plugins_loaded", "ptsc_get_textdomain");

/*
//==========activation hook==============//
*/
if (!function_exists('activate_ptsc')) {
    function activate_ptsc()
    {
        global $ins;
        $ins->install();
        add_option('makli_do_activation_redirect', true);
    }
}

register_activation_hook(__FILE__, 'activate_ptsc');


/*
//==========Uninstall Hook==============//
*/
if (!function_exists('uninstall_ptsc')) {
    function uninstall_ptsc()
    {
        global $ins;
        $ins->uninstall();
    }
}
register_uninstall_hook(__FILE__, 'uninstall_ptsc');

if (!function_exists('customrole_activate')) {
    function customrole_activate()
    {
        add_role('ptsc', 'ptsc',
            array(
                'read' => true));
    }
}
register_activation_hook(__FILE__, 'customrole_activate');

function custom_product_tabs($tabs)
{
    $tabs['giftcard'] = array(
        'label' => __('Makli Description', 'woocommerce'),
        'target' => 'giftcard_options',
        'class' => array('show_if_simple', 'show_if_variable'),
    );
    return $tabs;
}

add_filter('woocommerce_product_data_tabs', 'custom_product_tabs');

function giftcard_options_product_tab_content()
{
    global $post;

    // Note the 'id' attribute needs to match the 'target' parameter set above
    ?>
    <div id='giftcard_options' class='panel woocommerce_options_panel'><?php
        ?>
        <div class='options_group'><?php
            woocommerce_wp_textarea_input(array(
                'id' => '_ptsc_description',
                'label' => __('Description', 'woocommerce'),
                'desc_tip' => 'true',
                'type' => 'Textarea',
                'description' => __('Enter the description in key:value format for comparison table', 'woocommerce'),
                'rows' => '30',

            ));
            ?></div>

    </div>
    <?php
}

add_filter('woocommerce_product_data_panels', 'giftcard_options_product_tab_content');

function save_giftcard_option_fields($post_id)
{

    $allow_personal_message = isset($_POST['_allow_personal_message']) ? 'yes' : 'no';
    update_post_meta($post_id, '_allow_personal_message', $allow_personal_message);


    $woocommerce_custom_procut_textarea = $_POST['_ptsc_description'];

    if (!empty($woocommerce_custom_procut_textarea)) :
        update_post_meta($post_id, '_ptsc_description', esc_html($woocommerce_custom_procut_textarea));
    endif;

}

add_action('woocommerce_process_product_meta_simple', 'save_giftcard_option_fields');
add_action('woocommerce_process_product_meta_variable', 'save_giftcard_option_fields');

function ptsc_generate_pass($length = 10){
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return $randomString;
}

function ptsc_register_new_client($user_data){

    $ptsc_signup_errors = '';
    $response = array();
    if (isset($user_data["firstname"]) && wp_verify_nonce($user_data['ptsc_register_client_nonce'], 'ptsc-register-client-nonce')) {
        $user_login = $user_data["firstname"].rand(10,1000000);
        $user_email = $user_data["email"];
        $user_first = $user_data["firstname"];
        $user_last = $user_data["lastname"];
        $user_pass = $user_data["password"];
        $pass_confirm = $user_data["password2"];

        if (username_exists($user_login)) {
            // Username already registered
            $ptsc_signup_errors .= '<li>' . esc_html__('Username already taken','ptsc') .'</li>';
        }
        if (!validate_username($user_login)) {
            $ptsc_signup_errors .=  '<li>' . esc_html__('Invalid username','ptsc') . '</li>';
        }
        if ($user_login == '') {
            $ptsc_signup_errors .=  '<li>' . esc_html__('Please enter a username','ptsc') . '</li>';
        }
        if (!is_email($user_email)) {
            $ptsc_signup_errors .= '<li>' . esc_html__('Invalid email','ptsc')  . '</li>';
        }
        if (email_exists($user_email)) {
            $ptsc_signup_errors .= '<li>' . esc_html__('Email already registered','ptsc')  . '</li>';
        }
        if ($user_pass == '') {
            $ptsc_signup_errors .= '<li>' . esc_html__('Please enter a password','ptsc')  . '</li>';
        }
        if ($user_pass != $pass_confirm) {
            // passwords do not match
            $ptsc_signup_errors .= '<li>' . esc_html__('Passwords do not match','ptsc') . '</li>';
        }


        // only create the user in if there are no errors
        if (empty($ptsc_signup_errors)) {

            $new_user_id = wp_insert_user(array(
                    'user_login' => $user_login,
                    'user_pass' => $user_pass,
                    'user_email' => $user_email,
                    'first_name' => $user_first,
                    'last_name' => $user_last,
                    'user_registered' => date('Y-m-d H:i:s'),
                    'role' => 'ptsc'
                )
            );
            if ($new_user_id) {
                $response['user_id'] = $new_user_id;
                wp_set_auth_cookie($new_user_id, true);
                // send an email to the admin alerting them of the registration
                wp_new_user_notification($new_user_id);
                wp_set_current_user($new_user_id, $user_login);
                do_action('wp_login', $user_login);
            }
            $response['status'] = "OK";

        }else{
            $response['status'] = "ERROR";
            $response['errors'] = $ptsc_signup_errors;
        }

    }
    return $response;
}
add_action('init', 'ptsc_register_new_client');

function ptsc_login_client($credentials){
    global $errors;
    $errors = array();
    $response['status'] = "ERROR";
    if (!empty($credentials['ptsc_login_email']) && wp_verify_nonce($credentials['ptsc_login_nonce'], 'ptsc-login-nonce')) {

        if(email_exists($credentials['ptsc_login_email'])) {
            $user = get_user_by('email', $credentials['ptsc_login_email']);

            if (!$user) {

                $errors['username'] = 'Invalid email';
            }
            if (!isset($credentials['ptsc_login_pass']) || $credentials['ptsc_login_pass'] == '') {

                $errors['empty_password'] = ['enter a password'];
            }

            if (!wp_check_password($credentials['ptsc_login_pass'], $user->user_pass, $user->ID)) {

                $errors['incorrect_password'] = ['Incorrect password'];
            }

            if (empty($errors)) {
                wp_set_auth_cookie($user->ID, true);
                wp_set_current_user($user->ID, $_POST['clr_user_authenticate_name']);
                do_action('wp_login', $_POST['clr_user_authenticate_name']);

                $response['status'] = 'OK';
                $response['message'] = 'user is logged in successfully!!';
                $response['user_id'] = $user->ID;

            } else {
                $response['status'] = 'ERROR';
                $response['message'] = 'Invalid username or password';
            }
        }else{
            $response['status'] = 'ERROR';
            $response['message'] = 'We cannot validate you, please register with us';
        }
    }else{
        $response['status'] = 'ERROR';
        $response['message'] = 'Empty Email or password';
    }
    return $response;
}
add_action('init', 'ptsc_login_client');

//~~ Action Hook send emails when the orders are placed
function ptsc_order_email_process($email_data){
    require_once (PTSC_PATH . '/classes/ptsc.php');
    $ptsc = new PTSC();

    $email_template = $ptsc->ptsc_email_templates->ptsc_get_by('type','order-confirmation');
    $email_template = $email_template[0];

    $order_generated = $ptsc->ptsc_orders->ptsc_get_by('order_id',$email_data['order_id']);
    $order_generated = $order_generated[0];

    //~~ Getting client email who is placing the order.
    $client_email = $email_data['email'];

    //~~If admin has not set the email in makli settings then pickup the admin email from wordpress.
    $admin_email = empty(get_option('ptsc_email_sender_email')) ? get_bloginfo('admin_email') : get_option('ptsc_email_sender_email');

    //~~ if admin emails option is enabled then send email to admins
    $admin_email = get_option('enable_admin_emails') == '1' ? $admin_email : '';
    $to = array($client_email,$admin_email);

    $email_client_data = [];
    $email_client_data['receiver_name'] = $email_data['firstname'];
    $email_client_data['product_id'] = $email_data['ptsc_pid'];
    $email_client_data['first_name'] = $email_data['firstname'];
    $email_client_data['last_name'] = $email_data['lastname'];
    $email_client_data['receiver_email'] = $email_data['email'];
    $email_client_data['phone_no'] = $email_data["phonenumber"];
    $email_client_data['paymentmethod'] = $email_data["paymentmethod"];
    $email_client_data['billingcycle'] = $email_data["billingcycle"];
    $email_client_data['order_number'] = $order_generated["order_number"];
    $email_client_data['order_date'] = $order_generated["order_date"];
    $email_client_data['order_expire_date'] = $order_generated["expire_date"];
    $email_client_data['order_amount'] = $order_generated["amount"];
    //$email_client_data['order_billingcycle'] = $order_generated["billingcycle"];
    $email_client_data['order_status'] = $order_generated["status"];
    $email_client_data['company_name'] = $email_data["ptsc_company_name"];
    $email_client_data['company_domain'] = $email_data["ptsc_company_domain"];
    $email_client_data['company_logo'] = $email_data["ptsc_company_logo"];
    $email_client_data["ptsc_email_signature"] = $email_data["ptsc_email_signature"];

    $subject = $email_template['subject'];
    $message = html_entity_decode($email_template['message']);
    $complete_message = html_entity_decode($email_data['ptsc_email_header']).$message.html_entity_decode($email_data['ptsc_email_footer']);
    $complete_message = $ptsc->ptsc_scan_email_body($complete_message,$email_client_data);
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";

    wp_mail($to,$subject,$complete_message,$headers);
}
add_action('ptsc_order_placed', 'ptsc_order_email_process');

//~~ Action Hook send emails when the invoices are generated
function ptsc_invoice_gen_email_process($email_data){
    require_once (PTSC_PATH . '/classes/ptsc.php');
    $ptsc = new PTSC();

    $email_template = $ptsc->ptsc_email_templates->ptsc_get_by('type','invoice-generated');
    $email_template = $email_template[0];

    $invoice_generated = $ptsc->ptsc_invoices->ptsc_get_by('id',$email_data['invoice_id']);
    $invoice_generated = $invoice_generated[0];

    $invoice_items = $ptsc->ptsc_invoice_items->ptsc_get_by('invoice_id',$invoice_generated['id']);


    $to = $email_data['email'];

    $email_client_data = [];
    $email_client_data['receiver_name'] = $email_data['firstname'];
    $email_client_data['product_id'] = $email_data['ptsc_pid'];
    $email_client_data['first_name'] = $email_data['firstname'];
    $email_client_data['last_name'] = $email_data['lastname'];
    $email_client_data['receiver_email'] = $email_data['email'];
    $email_client_data['phone_no'] = $email_data["phonenumber"];
    $email_client_data['paymentmethod'] = $email_data["paymentmethod"];
    $email_client_data['billingcycle'] = $email_data["billingcycle"];
    $email_client_data['invoice_date_created'] = $invoice_generated["invoice_date"];
    $email_client_data['invoice_num'] = $invoice_generated["invoice_no"];
    $email_client_data['invoice_total'] = $invoice_generated["total"];
    $email_client_data['invoice_date_due'] = $invoice_generated["due_date"];
    $email_client_data['invoice_items'] = $invoice_items["item_descriptions"];
    $email_client_data['company_name'] = $email_data["ptsc_company_name"];
    $email_client_data['company_domain'] = $email_data["ptsc_company_domain"];
    $email_client_data['company_logo'] = $email_data["ptsc_company_logo"];
    $email_client_data['ptsc_email_signature'] = $email_data["ptsc_email_signature"];

    $subject = $email_template['subject'];
    $message = html_entity_decode($email_template['message']);
    $complete_message = html_entity_decode($email_data['ptsc_email_header']).$message.html_entity_decode($email_data['ptsc_email_footer']);
    $complete_message = $ptsc->ptsc_scan_email_body($complete_message,$email_client_data);
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";

    wp_mail($to,$subject,$complete_message,$headers);
}
add_action('ptsc_invoice_generated', 'ptsc_invoice_gen_email_process');


//~~ Action Hook send emails when the invoices are paid
function ptsc_invoice_paid_email_process($invoice_data,$client_info){
    require_once (PTSC_PATH . '/classes/ptsc.php');
    $ptsc = new PTSC();

    $email_template = $ptsc->ptsc_email_templates->ptsc_get_by('type','invoice-paid');
    $email_template = $email_template[0];

    $invoice_items = $ptsc->ptsc_invoices->ptsc_get_by('invoice_id',$invoice_data['id']);


    $to = $client_info['client_email'];

    $email_client_data = [];
    $email_client_data['receiver_name'] = $client_info['client_name'];
    $email_client_data['invoice_date_created'] = $invoice_data["invoice_date"];
    $email_client_data['invoice_num'] = $invoice_data["invoice_no"];
    $email_client_data['invoice_total'] = $invoice_data["total"];
    $email_client_data['invoice_items'] = $invoice_items["item_descriptions"];
    $email_client_data['invoice_status'] = $invoice_data["status"];
    $email_client_data['ptsc_email_signature'] = $client_info["signature"];
    $email_client_data['company_name'] = $client_info["company_name"];
    $email_client_data['company_domain'] = $client_info["company_domain"];
    $email_client_data['company_logo'] = $client_info["company_logo"];

    $subject = $email_template['subject'];
    $message = html_entity_decode($email_template['message']);
    $complete_message = html_entity_decode($client_info['email_header']).$message.html_entity_decode($client_info['email_footer']);
    $complete_message = $ptsc->ptsc_scan_email_body($complete_message,$email_client_data);
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";

    wp_mail($to,$subject,$complete_message,$headers);
}
add_action('ptsc_invoice_paid','ptsc_invoice_paid_email_process',10,2);

//~~ Action Hook send emails when the invoices are paid
function ptsc_send_contact_email($client_info){
    require_once (PTSC_PATH . '/classes/ptsc.php');
    $ptsc = new PTSC();

    $email_template = $ptsc->ptsc_email_templates->ptsc_get_by('type','contact-form');
    $email_template = $email_template[0];


    $to = get_option('ptsc_email_sender_email');

    $email_data = [];
    $email_data['admin_name'] = get_option('ptsc_email_sender');
    $email_data['first_name'] = $client_info["ptsc_fn_contact_from"];
    $email_data['last_name'] = $client_info["ptsc_ls_contact_from"];

    /*
     * It is the client email, we are assigning it as
     * "receiver email" because in scanning function this
     * variable is using otherwise it is not the receiver
     * email here, it is just client email address.
    */
    $email_data['receiver_email'] = $client_info["ptsc_email_contact_from"];
    $email_data['phone_no'] = $client_info["ptsc_phone_contact_from"];
    $email_data['client_Message'] = $client_info["ptsc_ms_contact_from"];

    $subject = $email_template['subject'];
    $message = html_entity_decode($email_template['message']);
    $complete_message = html_entity_decode($client_info['email_header']).$message.html_entity_decode($client_info['email_footer']);
    $complete_message = $ptsc->ptsc_scan_email_body($complete_message,$email_data);
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";

    wp_mail($to,$subject,$complete_message,$headers);
}
add_action('ptsc_cf_email','ptsc_send_contact_email');

/*
 * Functions to set screen options
 *
 * */
function ptsc_set_order_screen_option($status, $option, $value)
{
    if ('ptsc_orders_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_order_screen_option', 99, 3);


function ptsc_set_services_list_screen_option($status, $option, $value)
{
    if ('ptsc_services_list_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_services_list_screen_option', 99, 3);


function ptsc_set_list_services_screen_option($status, $option, $value)
{
    if ('ptsc_list_services_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_list_services_screen_option', 99, 3);


function ptsc_set_sale_groups_screen_option($status, $option, $value)
{
    if ('ptsc_sale_groups_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_sale_groups_screen_option', 99, 3);


function ptsc_set_all_invoice_screen_option($status, $option, $value)
{
    if ('ptsc_all_invoice_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_all_invoice_screen_option', 99, 3);

function ptsc_set_email_templates_screen_option($status, $option, $value)
{
    if ('ptsc_email_templates_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_email_templates_screen_option', 99, 3);

function ptsc_set_tooltips_page_screen_option($status, $option, $value)
{
    if ('ptsc_tooltips_page_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_tooltips_page_screen_option', 99, 3);

function ptsc_set_currency_page_screen_option($status, $option, $value)
{
    if ('ptsc_currency_page_per_page' == $option) return $value;
    return $status;
}
add_filter('set-screen-option', 'ptsc_set_currency_page_screen_option', 99, 3);


//~~ Left side links add new
function makli_description_links ($links ) {
    $makli_left_links = array(
        '<a href="admin.php?page=ptsc-getting-started">'. esc_html__("Wizard", "admin", "ptsc").'</a>',
        '<a href="admin.php?page=ptsc">'. esc_html__("Register", "admin", "ptsc").'</a>',
    );
    return array_merge( $links, $makli_left_links );
}
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'makli_description_links' );



add_filter( 'plugin_row_meta', 'makli_custom_row_meta', 10, 2 );

function makli_custom_row_meta( $links, $file )
{

    if (strpos($file, 'ptsc.php') !== false) {
        $new_links = array(
            '<a href="https://makli.com" target="_blank">'. esc_html__("View details", "admin", "ptsc").'</a>',
            '<a href="https://makli.com/support" target="_blank">'. esc_html__("Support", "admin", "ptsc").'</a>'
        );

        $links = array_merge($links, $new_links);
    }

    return $links;
}
