<?php
/**
 * Created by PhpStorm.
 * User: Zain Ul Abidin
 * Date: 2/22/2021
 * Time: 7:25 PM
 */

namespace ElementorPtsc\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
Use Elementor\Controls_Stack;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Makli_Order extends Widget_Base
{
    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name()
    {
        return 'makli-order';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title()
    {
        return __('Makli Checkout', 'ptsc');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-posts-ticker';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories()
    {
        return ['ptsc'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @return array Widget scripts dependencies.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_script_depends()
    {
        return ['ptsc'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {
        $all_ptsc_templates = ptsc_singlePageTemplates_list();

        $this->start_controls_section(
            'general',
            [
                'label' => __('General', 'ptsc'),
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => __('HTML Template', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => array_flip($all_ptsc_templates),
                'description' => 'To show order pages in different views'
            ]
        );


        $this->add_control(
            'hide_product',
            [
                'label' => __('Hide Product', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'no',
                'options' => [
                    'yes' => __('Yes', 'ptsc'),
                    'no' => __('No', 'ptsc'),
                ],
                'description' => 'To show or hide the product dropdown on the order page'
            ]
        );

        $this->add_control(
            'hide_description',
            [
                'label' => __('Hide Product Description', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'no',
                'options' => [
                    'yes' => __('Yes', 'ptsc'),
                    'no' => __('No', 'ptsc'),
                ],
                'description' => 'To show or hide the product description in the summary area of the order page'
            ]
        );

        $this->add_control(
            'pid',
            [
                'label' => __('Product ID', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Product id, enter in numeric form, when order page load then the product with this product id will auto selected on the order page'
            ]
        );

        $this->add_control(
            'billingcycle',
            [
                'label' => __('Billing Cyle', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'monthly',
                'options' => [
                    'monthly' => __('Monthly', 'ptsc'),
                    'quarterly' => __('Quarterly', "ptsc"),
                    'semiannually' => __('Semi Annually', "ptsc"),
                    'annually' => __('Annually', "ptsc"),
                    'biennially' => __('Bi Annually', "ptsc"),
                    'triennially' => __('Tri Annually', "ptsc"),
                ],
            ]
        );

        $this->add_control(
            'promocode',
            [
                'label' => __('PromoCode', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Promocode, when order page load then it will auto populate in the coupon code field, if product is also selected then coupon code will auto apply on that product depending upon the validation criteria'
            ]
        );

        $this->add_control(
            'hosting_title',
            [
                'label' => __('Hosting Title', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Text to show as the title of product section'
            ]
        );

        $this->add_control(
            'billing_info_text',
            [
                'label' => __('Billing Info Text', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Text to show as the title of billing info section'
            ]
        );

        $this->add_control(
            'payment_text',
            [
                'label' => __('Payment Text', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Text to show as the title of payment section'
            ]
        );

        $this->add_control(
            'tc_text',
            [
                'label' => __('Terms & Conditions Text', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Enter text to show as terms and conditions heading'
            ]
        );

        $this->add_control(
            'checkout_text',
            [
                'label' => __('Checkout Text', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Text to show on the checkout button'
            ]
        );

        $this->add_control(
            'summary_title',
            [
                'label' => __('Summary Title', 'ptsc'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'ptsc'),
                'description' => 'Text to show as the title of summary section in order page'
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        echo '<div class="">';
        $style = $settings['style'];
        $hide_product = 'hide_product';
        $hide_description = $settings['hide_description'];
        $pid = $settings['pid'];
        $billingcycle = $settings['billingcycle'];
        $promocode = $settings['promocode'];
        $hosting_title = $settings['hosting_title'];
        $billing_info_text = $settings['billing_info_text'];
        $payment_text = $settings['payment_text'];
        $tc_text = $settings['tc_text'];
        $checkout_text = $settings['checkout_text'];
        $summary_title = $settings['summary_title'];


        echo do_shortcode('[makli_cart_single_page style="' . $style . '" hide_product="' . $hide_product . '" hide_description="' . $hide_description . '" 
        pid="' . $pid . '" billingcycle="' . $billingcycle . '" promocode="' . $promocode . '" hosting_title="' . $hosting_title . '"
        billing_info_text="' . $billing_info_text . '" payment_text="' . $payment_text . '" tc_text="' . $tc_text . '" checkout_text="' . $checkout_text . '"
        summary_title="' . $summary_title . '" ]');
        echo '</div>';
    }

    /**
     * Render the widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function content_template()
    {
        ?>
        <div class="title">
            {{{ settings.$style }}}
            {{{ settings.$hide_product }}}
            {{{ settings.$hide_description }}}
            {{{ settings.$pid }}}
            {{{ settings.$billingcycle }}}
            {{{ settings.$promocode }}}
            {{{ settings.$hosting_title }}}
            {{{ settings.$billing_info_text }}}
            {{{ settings.$payment_text }}}
            {{{ settings.$tc_text }}}
            {{{ settings.$checkout_text }}}
            {{{ settings.$summary_title }}}
        </div>
        <?php
    }
}