<?php

class PTSC
{
    public $ptsc_group;
    public $ptsc_group_detail;
    public $ptsc_products;
    public $ptsc_coupons;
    public $ptsc_pricing;
    public $ptsc_currency;
    public $ptsc_tooltip;
    public $ptsc_orders;
    public $ptsc_client_services;
    public $ptsc_email_templates;
    public $ptsc_payment_gateways;
    public $ptsc_payment_gateway_options;
    public $ptsc_invoices;
    public $ptsc_invoice_items;
    public $ptsc_users;
    public $ptsc_payment;
    public $smarty;

    public function __construct()
    {
        $this->require_group();
        $this->require_group_detail();
        $this->require_products();
        $this->require_coupons();
        $this->require_currency();
        $this->require_pricing();
        $this->require_tooltip();
        $this->require_orders();
        $this->require_client_services();
        $this->require_email_templates();
        $this->require_payment_gateways();
        $this->require_payment_gateway_options();
        $this->require_invoices();
        $this->require_invoice_items();
        $this->require_users();
        $this->require_payment();
        $this->require_smarty();

        $this->ptsc_group = new PTSC_Group();
        $this->ptsc_group_detail = new PTSC_Group_Details();
        $this->ptsc_products = new PTSC_Products();
        $this->ptsc_coupons = new PTSC_Coupons();
        $this->ptsc_pricing = new PTSC_Pricing();
        $this->ptsc_currency = new PTSC_Currency();
        $this->ptsc_tooltip = new PTSC_Tooltips();
        $this->ptsc_orders = new PTSC_Orders();
        $this->ptsc_client_services = new ptsc_client_services();
        $this->ptsc_email_templates = new ptsc_email_templates();
        $this->ptsc_payment_gateways = new ptsc_payment_gateways();
        $this->ptsc_payment_gateway_options = new ptsc_payment_gateway_options();
        $this->ptsc_invoices = new ptsc_invoices();
        $this->ptsc_invoice_items = new ptsc_invoice_items();
        $this->ptsc_users = new ptsc_users();
        $this->ptsc_payment = new ptsc_payment();
        $this->smarty = new Smarty();
    }

    // =======================================================================//
    // Require File functions                                                  //
    // =======================================================================//
    public function require_group()
    {
        require_once(PTSC_PATH . '/classes/ptsc_groups.php');
    }

    public function require_group_detail()
    {
        require_once(PTSC_PATH . '/classes/ptsc_group_details.php');
    }

    public function require_products()
    {
        require_once(PTSC_PATH . '/classes/ptsc_products.php');
    }

    public function require_coupons()
    {
        require_once(PTSC_PATH . '/classes/ptsc_coupons.php');
    }

    public function require_pricing()
    {
        require_once(PTSC_PATH . '/classes/ptsc_Pricing.php');
    }

    public function require_currency()
    {
        require_once(PTSC_PATH . '/classes/ptsc_currency.php');
    }

    public function require_tooltip()
    {
        require_once(PTSC_PATH . '/classes/ptsc_tooltips.php');
    }

    public function require_orders()
    {
        require_once(PTSC_PATH . '/classes/ptsc_orders.php');
    }

    public function require_client_services()
    {
        require_once(PTSC_PATH . '/classes/ptsc_client_services.php');
    }

    public function require_email_templates()
    {
        require_once(PTSC_PATH . '/classes/ptsc_email_templates.php');
    }

    public function require_payment_gateways()
    {
        require_once(PTSC_PATH . '/classes/ptsc_payment_gateways.php');
    }

    public function require_payment_gateway_options()
    {
        require_once(PTSC_PATH . '/classes/ptsc_payment_gateway_options.php');
    }

    public function require_invoices()
    {
        require_once(PTSC_PATH . '/classes/ptsc_invoices.php');
    }

    public function require_invoice_items()
    {
        require_once(PTSC_PATH . '/classes/ptsc_invoice_items.php');
    }

    public function require_users()
    {
        require_once(PTSC_PATH . '/classes/ptsc_users.php');
    }

    public function require_payment()
    {
        require_once(PTSC_PATH . '/classes/ptsc_payment.php');
    }

    public function require_smarty()
    {
        require_once(PTSC_PATH . '/includes/libs/Smarty.class.php');
    }




    // =======================================================================//
    // Utility functions for plugin                                            //
    // =======================================================================//
    public function ptsc_get_product_sort_column($groupid)
    {
        $rows = $this->ptsc_group_detail->ptsc_get_sorted_by('group_id', $groupid, 'order_by');
        //ppa($rows);
        $custom_order = false;
        foreach ($rows as $row) {
            if ($row['order_by'] != '0') {
                $custom_order = true;
            }

        }
        if ($custom_order == false) {
            $order_column = 'product_id';
        } else {
            $order_column = 'order_by';
        }
        //ppa($order_column);
        return $order_column;

    }

    public function ptsc_get_group_full($id)
    {


        $result = $this->ptsc_group->ptsc_get($id);

        if ($result == "") {
            $error_heading = esc_html__('Oops! No widget available for id' . " " . ($id), 'ptsc');
            $error_instruction = esc_html__('Please go to Makli > widgets > Add Widget > and add widget options there. ', 'ptsc');
            $result = ptsc_render_error_message($error_instruction, $error_heading, "danger");
            //$result= ptsc_render_error_message($instruction,$error_heading,'danger');
            echo $result;
            return __("Oops! No widget available for id ($id)", "ptsc");
        }


        //~~ We have free & Ontime billing cycles also now, so we do not need to set as bellow.
        if ($result["billingcycle"] == "") {
            $result["billingcycle"] = "";
        }

        /*		if ( $result["billingcycle2"] == "" ) {
                    $result["billingcycle2"] = "annually";

                }*/


        $order_column = $this->ptsc_get_product_sort_column($id);


        $rows = $this->ptsc_group_detail->ptsc_get_sorted_by('group_id', $id, $order_column);
        foreach ($rows as &$row) {
            $product = $this->ptsc_products->ptsc_get($row['product_id']);
            $description_array = isset($product['product_description']) ? $product['product_description'] : '';
            $description_array = trim(strip_tags($description_array, "\n"));
            $formatted_description_array = isset($product['formatted_product_description']) ? $product['formatted_product_description'] : '';
            $formatted_description_array = trim(strip_tags($formatted_description_array, "\n"));
            //$description_array=explode("\n",$description_array);
            $R['cdescription'] = '';
            $R['description'] = $description_array;
            $R['formatted_description'] = $formatted_description_array;
            $R['name'] = isset($product["product_name"]) ? $product["product_name"] : '';
            $R['pay_type'] = isset($product['pay_type']) ? $product['pay_type'] : '';
            $R['order_url'] = '';
            $R['product_button_text'] = isset($product["product_button_text"]) ? $product["product_button_text"] : '';

            $row = array_merge($R, $row);
        }
        $result["plans"] = $rows;
        return $result;
        //ppa($rows);
    }


    public function check_template_file($html_template, $shortcode_name)
    {
        if (is_file($html_template)) {
            return $html_template;
        }
        $html_template = basename($html_template);
        if (get_option("load_sytle_orders") == "whmpress") {
            $html_template = basename($html_template);
            $Path = PTSC_PATH . "/themes/" . basename($this->get_template_directory()) . '/' . $shortcode_name . '/' . $html_template;
        } elseif (get_option("load_sytle_orders") == "author") {
            $html_template = basename($html_template);
            $Path = $this->get_template_directory() . $shortcode_name . '/' . $html_template;
        } else {
            $Path = $html_template;
        }

        if (is_file($Path)) {
            return $Path;
        }

        $Path = PTSC_PATH . "/templates/" . $shortcode_name . "/default.tpl";
        if (!is_file($Path)) {
            $Path = PTSC_PATH . "/templates/" . $shortcode_name . "/default.html";
        }

        return $Path;

    }

    public function get_all_ptsc_template_files($shortcode_name)
    {
        $Files = [];
        $Path = $this->get_template_directory() . "/templates/" . $shortcode_name . "/custom_fields.csv";
        //$Path = WHMP_PLUGIN_DIR . "/themes/" . basename($this->whmp_get_template_directory()) . '/' . $shortcode_name;
        if (is_dir($Path)) {
            $files = scandir($Path);
            foreach ($files as $file) {
                $ext = $this->get_file_extension($file);
                if ($ext == "html" || $ext == "tpl") {
                    $Files[] = [
                        "file_path" => $Path . '/' . $file,
                        "description" => "By ptsc - " . basename($file),
                    ];
                }
            }
        }

        $Path = $this->get_template_directory() . "/ptsc/" . $shortcode_name;
        if (is_dir($Path)) {
            $files = scandir($Path);
            foreach ($files as $file) {
                $ext = $this->get_file_extension($file);
                if ($ext == "html" || $ext == "tpl") {
                    $Files[] = [
                        "file_path" => $Path . '/' . $file,
                        "description" => "By ThemeAuthor - " . basename($file),
                    ];
                }
            }
        }

        $Path = PTSC_PATH . "/templates/" . $shortcode_name;
        if (is_dir($Path)) {
            $files = scandir($Path);
            foreach ($files as $file) {
                $ext = $this->get_file_extension($file);
                if ($ext == "html" || $ext == "tpl") {
                    $Files[] = [
                        "file_path" => $Path . '/' . $file,
                        "description" => " " . basename($file),
                    ];
                }
            }
        }

        return $Files;
    }

    public function get_template_array($shortcode)
    {
        $file_path = $this->get_template_directory() . "/templates/" . $shortcode . "/custom_fields.csv";
        if (!is_file($file_path)) {
            return [];
        }
        $CustomFields = array_map('str_getcsv', file($file_path));

        $field_names = [];
        foreach ($CustomFields as $custom_field) {
            $field_names[] = @$custom_field[0];
        }

        return $field_names;
    }


    public function get_template_directory()
    {
        return PTSC_PATH . '/templates';
    }

    public function get_default_template($shortcode)
    {
        $html_template = $this->get_template_directory() . "/" . $shortcode . "/" . "default.tpl";
        return $html_template;
    }

    /**
     * @return string
     */
    public function ptsc_get_stylesheet_directory()
    {
        return get_stylesheet_directory();
    }

    public function get_template_file($html_file, $shortcode)
    {
        $html_cat_file = explode('/', $html_file);
        $html_cat = $html_cat_file[0];
        $html_file = $html_cat_file[1];
        if (is_file($html_file)) {
            return $html_file;
        }
        $html_file = basename($html_file);
        $path = $this->get_template_directory() . "/" . $shortcode . "/" . $html_cat . "/" . $html_file;

        return $path;
    }

    public function get_template_files_all($shortcode)
    {
        $Files = [];
        $path = $this->get_template_directory() . "/" . $shortcode;
        $files = scandir($path);
        foreach ($files as $file) {
            $ext = $this->get_file_extension($file);
            if ($ext == "html" || $ext == "tpl") {
                $Files[] = [
                    "file_path" => $path . "/" . $file,
                    "description" => "By PTSC Templates-" . basename($file)
                ];
            }
        }
        return $Files;
    }

    public function is_json($json_value)
    {
        json_decode($json_value);

        return (json_last_error() == JSON_ERROR_NONE);
    }

    public function read_csv_file($csv_file)
    {
        $rows = array_map('str_getcsv', file($csv_file));
        $header = array_shift($rows);
        $header = array_filter($header);
        $csv = [];
        foreach ($rows as $row) {
            $ar = [];
            foreach ($header as $x => $col) {
                if (!isset($row[$x])) {
                    $ar[$col] = null;
                } else if ($row[$x] == "NULL") {
                    $ar[$col] = null;
                } else {
                    $ar[$col] = isset($row[$x]) ? $row[$x] : null;
                }
            }
            $csv[] = $ar;
        }

        return $csv;
    }

    public function get_template_files($shortcode, array $categories = [])
    {
        $template_names = $files = $CustomFields = [];

        /*
         * Checking if templates are in their relevant categories
         * If yes then pick templates from their categories else
         * pick directly.
         */
        if (!empty($categories)) {
            foreach ($categories as $temp_cat) {
                $path = $this->get_template_directory() . "/" . $shortcode . "/" . $temp_cat;
                if (is_dir($path)) {
                    $resources = scandir($path);
                    foreach ($resources as $resource) {
                        $ext = $this->get_file_extension($resource);
                        if ($ext == "tpl") {
                            $files[] = $temp_cat . '/' . $resource;
                        }

                        if ($ext == "xml") {
                            $xmldata = simplexml_load_file($path . '/' . $resource) or die("Failed to load");
                            $template_names[] = json_decode(json_encode($xmldata->name), true);

                        }
                    }
                }
            }
        } else {
            $path = $this->get_template_directory() . "/" . $shortcode;
            if (is_dir($path)) {
                $resources = scandir($path);
                foreach ($resources as $resource) {
                    $ext = $this->get_file_extension($resource);
                    if ($ext == "tpl") {
                        $files[] = $resource;
                    }
                }
            }
        }


        // Getting custom fields from CSV file.
        if (is_file(PTSC_PATH . "/templates/ptsc_pricing_table/custom_fields.csv")) {
            $CustomFields = $this->read_csv_file(PTSC_PATH . "/templates/ptsc_pricing_table/custom_fields.csv");
            //if ($shortcode_name=="whmpress_pricing_table") $this->debug($CustomFields);
        }

        return [
            "files" => $files,
            "custom_fields" => $CustomFields,
            "template_name" => $template_names,
        ];

    }

    public function get_file_extension($filename)
    {
        $f = pathinfo($filename);
        if (isset($f["extension"])) {
            return strtolower(trim($f["extension"]));
        } else {
            return "";
        }
    }

    public function get_info_file_content($shortcode, $file)
    {

        $ext = $this->get_file_extension($file);

        if ($ext == "info") {
            return "";
        }
        $path = $this->get_template_directory() . "/" . $shortcode . "/" . $file;

        return $content = file_get_contents($path);
    }

    public function get_info_files($shortcode)
    {
        $path = $this->get_template_directory() . "/" . $shortcode;
        $info_files = [];
        $files = scandir($path);
        foreach ($files as $file) {
            $file = basename($file);
            if ($this->get_file_extension($file) == "info") {
                $info_files[] = $file;
            }
        }
        return $info_files;
    }

    public function select_tpl_first($html_template)
    {
        $html_template = str_replace(['.html', '.tpl'], ['', ''], $html_template);
        if (is_file($html_template . '.tpl')) {
            $html_template = $html_template . '.tpl';
        } elseif (is_file($html_template . '.html')) {
            $html_template = $html_template . '.tpl';
        }
        return $html_template;
    }

    public function ptsc_smarty_template($filename, $args)
    {
        $this->smarty->setTemplateDir(dirname($filename));
        $this->smarty->setCompileDir(PTSC_PATH . '/includes/libs/template_c');
        //$this->smarty->debugging=true;
        $this->smarty->assign($args);


        return $this->smarty->display(basename($filename));
    }

    public function ptsc_scan_email_body($email_message, $client_data)
    {
        $receiver_name = isset($client_data['receiver_name']) ? $client_data['receiver_name'] : '';
        $client_first_name = isset($client_data['first_name']) ? $client_data['first_name'] : "";
        $client_last_name = isset($client_data['last_name']) ? $client_data['last_name'] : "";
        $receiver_email = isset($client_data['receiver_email']) ? $client_data['receiver_email'] : "";
        $phone_no = isset($client_data['phone_no']) ? $client_data['phone_no'] : "";
        $billingcycle = isset($client_data['billingcycle']) ? $client_data['billingcycle'] : "";
        $payment_method = isset($client_data['paymentmethod']) ? $client_data['paymentmethod'] : "";
        $product_id = isset($client_data['product_id']) ? $client_data['product_id'] : "";
        $order_number = isset($client_data['order_number']) ? $client_data['order_number'] : "";
        $order_date = isset($client_data['order_date']) ? $client_data['order_date'] : "";
        $order_expire_date = isset($client_data['order_expire_date']) ? $client_data['order_expire_date'] : "";
        $order_amount = isset($client_data['order_amount']) ? $client_data['order_amount'] : "";
        $order_status = isset($client_data['order_status']) ? $client_data['order_status'] : "";
        $invoice_date_created = isset($client_data['invoice_date_created']) ? $client_data['invoice_date_created'] : "";
        $invoice_number = isset($client_data['invoice_num']) ? $client_data['invoice_num'] : "";
        $invoice_total = isset($client_data['invoice_total']) ? $client_data['invoice_total'] : "";
        $invoice_date_due = isset($client_data['invoice_date_due']) ? $client_data['invoice_date_due'] : "";
        $invoice_items = isset($client_data['invoice_items']) ? $client_data['invoice_items'] : "";
        $company_name = isset($client_data['company_name']) ? $client_data['company_name'] : "";
        $company_domain = isset($client_data['company_domain']) ? $client_data['company_domain'] : "";
        $company_logo_url = isset($client_data['company_logo']) ? $client_data['company_logo'] : "";
        $invoice_status = isset($client_data['invoice_status']) ? $client_data['invoice_status'] : "";
        $admin_name = isset($client_data['admin_name']) ? $client_data['admin_name'] : '';
        $client_message = isset($client_data['client_Message']) ? $client_data['client_Message'] : '';

        $email_signature = !empty($client_data['ptsc_email_signature']) ? $client_data['ptsc_email_signature'] : "abc";

        $placeholders_to_remove = array(
            "{admin_name}",
            "{client_name}",
            "{client_first_name}",
            "{client_last_name}",
            "{client_email}",
            "{client_phonenumber}",
            "{order_billingcycle}",
            "{order_paymentmethod}",
            "{client_prduct_id}",
            "{order_number}",
            "{order_date}",
            "{order_expire_date}",
            "{order_amount}",
            "{order_status}",
            "{order_payment_method}",
            "{invoice_date_created}",
            "{invoice_payment_method}",
            "{invoice_num}",
            "{invoice_total}",
            "{invoice_due_date}",
            "{invoice_items}",
            "{company_name}",
            "{company_domain}",
            "{company_logo_url}",
            "{invoice_last_payment_amount}",
            "{invoice_amount_paid}",
            "{invoice_status}",
            "{signature}",
            "{client_message}",
        );

        $client_data_to_add = array(
            $admin_name,
            $receiver_name,
            $client_first_name,
            $client_last_name,
            $receiver_email,
            $phone_no,
            $billingcycle,
            $payment_method,
            $product_id,
            $order_number,
            $order_date,
            $order_expire_date,
            $order_amount,
            $order_status,
            $payment_method,
            $invoice_date_created,
            $payment_method,
            $invoice_number,
            $invoice_total,
            $invoice_date_due,
            $invoice_items,
            $company_name,
            $company_domain,
            $company_logo_url,
            $invoice_total,
            $invoice_total,
            $invoice_status,
            $email_signature,
            $client_message,
        );

        $final_email_msg = str_replace($placeholders_to_remove, $client_data_to_add, $email_message);

        return stripslashes($final_email_msg);
    }

    public function get_current_language()
    {
        if (defined('ICL_LANGUAGE_CODE')) {
            return ICL_LANGUAGE_CODE;
        } elseif (function_exists('pll_current_language')) {
            return pll_current_language();
        } elseif (isset($_GET["lang"])) {
            return $_GET["lang"];
        } else {
            return get_locale();
        }
    }

    public function description_to_array($description, $rows, $sep, $return, $strip_sections = false)
    {

        if (isset($description)) {
            $description = preg_split("/\R/", strip_tags($description));
        } else {
            $description = [];
        }
        $description = array_diff($description, ['']);
        $features = [];
        $values = [];
        $simple_description = [];
        $features_values = [];
        $features_values_split = [];
        $x = 0;
        $rows_c = 0;
        foreach ($description as $line) {
            if ($strip_sections == 1 && strpos($line, "--") !== false && strpos($line, "--", 3) == true) {

            } else {

                $simple_description[$x] = $line;

                $strpos = strpos($line, $sep);
                if ($strpos === false) {
                    $description[$line] = "";
                } else {
                    $features[$x] = trim(substr($line, 0, $strpos));
                    $features[$x] = preg_replace('/\t+/', '', $features[$x]);

                    $values[$x] = trim(substr($line, $strpos + 1));
                    $values[$x] = preg_replace('/\t+/', '', $values[$x]);

                    $features_values[$features[$x]] = [
                        "feature" => $features[$x],
                        "value" => $values[$x],
                        "tooltip" => "",
                        "tooltip_url" => $this->return_tooltip_url($features[$x]),
                        "tooltip_icon" => $this->return_tooltip_icon($features[$x]),
                    ];

                    $features_values_split[$x] = [
                        "feature" => $simple_description[$x],
                        "feature_value" => $values[$x],
                        "tooltip_url" => $this->return_tooltip_url($features[$x]),
                        "tooltip_text" => $this->return_tooltip($features[$x]),
                        "tooltip_icon" => $this->return_tooltip_icon($features[$x]),
                        "icon_class" => "",
                        "feature_title" => $features[$x]

                    ];
                    $rows_c++;
                }


                $x++;
                if ($rows_c == $rows) {
                    break;
                }
            }
        }


        if ($return == 0) {
            return $features;
        }
        if ($return == 1) {
            return $values;
        }
        if ($return == 3) {
            return $simple_description;
        }
        if ($return == 4) {
            return $features_values;
        }

        if ($return == 5) {
            return $features_values_split;
        }


        return "";

    }

    public function linked_description_to_array($description, $rows, $sep, $return, $strip_sections = false)
    {
        if (isset($description)) {
            $description = preg_split("/\R/", strip_tags($description));
        } else {
            $description = [];
        }
        $description = array_diff($description, ['']);
        $features = [];
        $values = [];
        $simple_description = [];
        $features_values = [];
        $features_values_split = [];
        $x = 0;
        $rows_c = 0;
        foreach ($description as $line) {
            if ($strip_sections == 1 && strpos($line, "--") !== false && strpos($line, "--", 3) == true) {

                $lineee = str_replace('--', '', $line);
                $lineee = '<div class="ptsc_mob_heading">' . $lineee . '</div>';
                $features_values[$lineee]['feature'] = '';
                $features_values[$lineee]['value'] = '';
            } else {

                $simple_description[$x] = $line;

                $strpos = strpos($line, $sep);
                if ($strpos === false) {
                    $description[$line] = "";
                } else {
                    $features[$x] = trim(substr($line, 0, $strpos));
                    $features[$x] = preg_replace('/\t+/', '', $features[$x]);

                    $values[$x] = trim(substr($line, $strpos + 1));
                    $values[$x] = preg_replace('/\t+/', '', $values[$x]);

                    $features_values[$features[$x]] = [
                        "feature" => $this->return_feature_title($features[$x]),
                        "value" => $values[$x],
                        "tooltip" => $this->return_tooltip($features[$x]),
                        "tooltip_url" => $this->return_tooltip_url($features[$x]),
                    ];

                    $features_values_split[$x] = [
                        /* "feature"=>$simple_description[ $x ],*/
                        "feature" => $this->return_feature_title($features[$x]),
                        "feature_value" => $values[$x],
                        "tooltip_text" => $this->return_tooltip($features[$x]),
                        "icon_class" => "",
                        "feature_title" => $this->return_feature_title($features[$x])

                    ];
                    $rows_c++;
                }


                $x++;
                if ($rows_c == $rows) {
                    break;
                }
            }
        }

        if ($return == 0) {
            return $features;
        }
        if ($return == 1) {
            return $values;
        }
        if ($return == 3) {
            return $simple_description;
        }
        if ($return == 4) {
            return $features_values;
        }

        if ($return == 5) {
            return $features_values_split;
        }


        return "";

    }

    public function ptsc_break_price($group_info, $product_id, $billingcycle)
    {

        $decimals = '';
        $pay_type = $this->ptsc_products->ptsc_get_column('pay_type', $product_id);


        if ($pay_type == "one time") {
            $billingcycle = "monthly";
        }


        if (isset($group_info['decimals'])) {
            $decimals = $group_info['decimals'];
        }

        //== comment repeated code
        /* if(isset($group_info['decimals'])) {
            $decimals = $group_info['decimals'];
        } */

        $duration_style = (isset($group_info['duration_style']) && ($group_info['duration_style'] != "")) ? $group_info['duration_style'] : get_option("ptsc_duration_style");

        $duration_connector = (isset($group_info['duration_connector']) && ($group_info['duration_connector'] != "")) ? $group_info['duration_connector'] : get_option("ptsc_duration_connector");


        $price = $this->ptsc_get_price($product_id, $billingcycle);
        $formatted = $this->ptsc_format_price([
            "price" => $price,
            "decimal" => $decimals,
            'paytpe' => $pay_type
        ]);

        $currency = $this->ptsc_currency->ptsc_get($this->ptsc_get_current_currency_id_i());

        //~~ improved below
        //$duration = ($pay_type!="one time")?($this->ptsc_convert_billingcycle($billingcycle,$duration_style,$duration_connector)):(($pay_type!="free")?"One Time":"Free");
        if ($pay_type == "one time") {
            $duration = "One Time";
        } elseif ($pay_type == "free") {
            $duration = "Free";
        } else {
            $duration = $duration_connector . $this->ptsc_convert_billingcycle($billingcycle, $duration_style, $duration_connector);
        }


        if (is_string($duration)) {
            $duration = ucwords($duration);
        }
        $price_info = [];
        $price_info['price'] = $formatted['price'];
        $price_info['amount'] = $formatted['amount'];
        $price_info["fraction"] = $formatted["fraction"];
        $price_info["decimal"] = $formatted["decimal_separator"];
        $price_info["prefix"] = $currency["prefix"];
        $price_info["suffix"] = $currency["suffix"];
        $price_info["duration"] = $duration;

        if ($pay_type == "free") {
            $price_info["duration"] = "";
            $price_info["prefix"] = "";
            $price_info["suffix"] = "";
            $price_info['amount'] = "Free";
        }
        //Default values when price is not configured
        if ($price_info['price'] == -1) {
            $price_info["duration"] = "";
            $price_info["prefix"] = "";
            $price_info["suffix"] = "";
        }

        return $price_info;
    }


    public function ptsc_format_price($args = [])
    {
        $zero_string = get_option('ptsc_price_zero_' . $this->get_current_language());
        $not_configured_string = get_option('ptsc_price_not_configured_' . $this->get_current_language());

        $price = (isset($args['price'])) ? floatval($args['price']) : '0';

        $decimal = (isset($args['decimals'])) ? $args['decimal'] : get_option("ptsc_decimals");
        //== if decimal field is empty
        if ($decimal == "") {
            $decimal = 2;
        }

        $decimal_separator = get_option("ptsc_decimal_separator");

        $thousand_separator = get_option("ptsc_thousand_separator");
        $message = '0';

        if (get_option("ptsc_show_trailing_zeros") == "yes") {
            if (is_numeric($price)) {
                $decimal = (int)$decimal;
                $price = number_format($price, $decimal, $decimal_separator, $thousand_separator);

                $message = '1';
            }
        } else {
            $price = round($price, $decimal);
            $price = number_format($price, $decimal, $decimal_separator, $thousand_separator);

            if ($this->ptsc_is_trailing_zeros($price)) {
                if ($decimal > 0) {
                    $num = -1 * ($decimal + 1);
                    $price = substr($price, 0, $num);
                    $message = '1';
                }
            }

        }


        $tmp = explode($decimal_separator, $price);
        $amount = $tmp[0];
        $fraction = isset($tmp[1]) ? $tmp[1] : "";

        if ($price < 0) {
            $amount = $not_configured_string;
            $fraction = '';
            $decimal_separator = '';
        }

        if ($price == 0) {
            $amount = $zero_string;
            $fraction = '';
            $decimal_separator = '';
        }

        $output = [
            'price' => $price,
            'amount' => $amount,
            'fraction' => $fraction,
            'decimal_separator' => $decimal_separator,
            'message' => $message
        ];
        return $output;
    }

    public function ptsc_get_price($product_id, $billing_cycle)
    {

        //~~
        global $wpdb;
        $ptsc_install = new ptsc_install();
        $product = $this->ptsc_products->ptsc_get($product_id);
        //$price = $this->ptsc_pricing->ptsc_get_by('relid',$product_id);


        $current_price = "";
        $cur = $this->ptsc_get_current_currency_id_i();
        $currency = $this->ptsc_currency_info_combo($cur);
        $c_id = $currency["c_id"];

        $Q = "SELECT `pr_id`,`type`,`monthly`, `quarterly`, `semiannually`, `annually`, `biennially`, `triennially`,`msetupfee`, `qsetupfee`, `ssetupfee`, `asetupfee`, `bsetupfee`, `tsetupfee` FROM `" . $ptsc_install->get_table_name("pricings") . "` WHERE `currency`='{$c_id}' AND `relid`='{$product_id}'";
        //ppa($Q,"Q data");
        $price = $wpdb->get_row($Q, ARRAY_A);
        //ppa($price,"Price function");
        if ($product['pay_type'] == "one time") {
            $billing = "monthly";
        } else {
            $billing = $billing_cycle;
        }
        //ppa($billing,'biling');
        /*foreach ($price as $prc)
        {
            $current_price = (!empty($prc[$billing]))? $prc[$billing]:"-1";
        }*/
        $current_price = (!empty($price[$billing])) ? $price[$billing] : "-1";
        //ppa($current_price,"Current Price");

        return $current_price;

    }

    public function ptsc_get_default_currency()
    {
        $currency = get_option("ptsc_default_currency");

        if (!empty($currency) && is_numeric($currency)) {
            return $currency;
        }
        $currency_id = $this->ptsc_currency->ptsc_get_column_by('c_id', 'default', 1);
        return $currency_id;
    }

    public function ptsc_prepare_html($group, $html_table_class, $r)
    {

        $style_2 = [
            'comparison-02',
            'comparison-04',
            'comparison-05',
            'comparison-06',
            'comparison-07',
        ];
        $parts = array();

        /********** First Column of Top Row ***********/
        $important = 0;
        $i = 0;
        /*foreach ($group['plans'] as $plan) {
            if ($plan['product_id'] == $group['important']) {
                $important = $i;
            }
            $i++;

        }*/

        //~~ Set values for Show discounts (Discount is not being offered in intial version)
        /*		if ( ( $group['show_discount'] != "no" ) && ( $group['show_discount_banner'] == "yes" ) ) {
                    $discount_container = $this->ptsc_prepare_plan_discounts( $group['plans'][ $important ], "", $group['show_discount_secondary'] );
                } else {
                    $discount_container = "";
                }*/
        $discount_container = "";


        //~~ Set values for toggle container
        $toggle_container = $this->ptsc_prepare_duration_toggle($group, $r);
        $heading_column_top = '
				<div class="ptsc_toggle_top_comparison ptsc_comparison_table_titles_col ptsc_comparison_table_titles_col_top">
					' . $discount_container . '
					<div class="ptsc_price_toggle">' . $toggle_container . '</div>
				</div>';
        $heading_column_top .= '
				<div class="ptsc_comparison_table_col ptsc_comparison_table_titles_col ptsc_comparison_table_titles_col_top">
				</div>';


        /********** Top Header Start ***********/
        if (true) {
            $counter = 0;
            $tables = '';
            foreach ($group["plans"] as $plan) {

                // Breaking loop if number of plans exceeds 4
                //todo: there should be a message to display here.
                /*			if ( $counter > 5 ) {
                                break;
                            }*/

                // Current Table Promo Text
                $featured = $promo = '';
                if ($plan["featured"] == "yes") {
                    $featured = "featured";
                    $promo =
                        '<div class="ptsc_promo-text">
							<div class="ptsc_holder">
								<span>' . $group["ribbon_text"] . '</span>
							</div>
						</div> <!-- /.PTSC_promo-text -->';
                }

                // Current Table Heading
                $heading =
                    '<div class="ptsc_heading">
						<div class="ptsc_holder">
							<h2>' . $plan['name'] . '</h2>
						</div>
					</div> <!-- /.PTSC_heading -->';

                // Current Table Text
                if ($plan['cdescription'] == '') {
                    $text = '';
                } else {
                    $text =
                        '<div class="ptsc_text">
					<div class="ptsc_holder">
						<p>' . $plan['cdescription'] . '</p>
					</div>
				</div> <!-- /.whmp_text -->';
                }

                // Current Table Price


                $price = $this->ptsc_prepare_plan_price($plan);

                // Current Table Discount Text and Value (Not offering discounts in this version)
                $discount = ($group['show_discount'] == "no") ? $this->ptsc_prepare_plan_discounts($plan, "table", $group['show_discount_secondary']) : "";


                // Current Table Features
                $args = [
                    'description_array' => $plan["description_array"],
                    'section' => "top",
                    'return_rows' => -1,
                    'convert_fa' => $group['convert_to_symbol'],
                    'convert_fa_no' => $group['convert_no_with'],
                    'convert_fa_yes' => $group['convert_yes_with'],
                ];
                $features = $this->ptsc_prepare_plan_features_list($args);

                // Current Table Buttons
                $button = $this->ptsc_prepare_plan_button($group, $plan);

                // Compiling Current Table Column
                if (in_array($html_table_class, $style_2)) {
                    $table_html = $promo . $heading . $price . $discount . $text . $features . $button;
                } else {
                    $table_html = $promo . $heading . $text . $price . $discount . $features . $button;
                }
                $table =
                    '<div class="ptsc_comparison_table_col">
						<div class="ptsc_pricing_table  ' . $featured . ' ' . $html_table_class . ' ">
							' . $table_html . '
						</div><!-- /.PTSC_pricing_table -->
					</div>';

                $tables .= $table;
                $counter++;
            }

            $parts["top"] = '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_tables">';
            $parts["top"] .= $heading_column_top;
            $parts["top"] .= $tables;
            $parts["top"] .= '</div>';
        }

        /********** Top Header end ***********/


        /********** Middle Start ***********/
        // call to function to build middle part without section

        if ($group["have_sections"] == false) {
            $parts["middle"] = $this->ptsc_prepare_html_middle($group);
        } else {
            $parts["middle"] = $this->ptsc_prepare_html_middle_sections($group);
        }

        /********** Middle end ***********/

        /********** Summary Start ***********/
        $counter = 0;
        $tables = '';
        foreach ($group["plans"] as $plan) {

            // Breaking loop if number of plans exceeds 4
            //commenting by zain
            /*		if ( $counter == 4 ) {
                        break;
                    }
            */

            //ppa($plan);
            $featured = '';
            if ($plan["featured"] == "yes") {
                $featured = "featured";
            }

            // Current Table Heading
            $heading =
                '<div class="ptsc_heading">
						<div class="ptsc_holder">
							<h2>' . $plan['name'] . '</h2>
						</div>
					</div> <!-- /.PTSC_heading -->';

            // Current Table Price
            $price = $this->ptsc_prepare_plan_price($plan);

            // Current Table Buttons
            $button = $this->ptsc_prepare_plan_button($group, $plan);

            // Compiling Current Table Column
            $table =
                '<div class="ptsc_comparison_table_col">
						<div class="ptsc_pricing_table  ' . $featured . ' ' . $html_table_class . ' ">
							' . $heading . $price . $button . '
						</div><!-- /.PTSC_pricing_table -->
					</div>';

            $tables .= $table;
            $counter++;
        }

        $parts['bottom'] = '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_summary">';
        $parts['bottom'] .= '<div class="ptsc_comparison_table_col ptsc_comparison_table_titles_col"></div>';
        $parts['bottom'] .= $tables;
        $parts['bottom'] .= '</div>';


        /********** Summary  end ***********/

        return $parts;


    }

    public function ptsc_middle_section($group)
    {

        //$convert_fa = ( $group['convert_to_symbol'] == "1" ) ? "yes" : "no";


        $mid1 = '<!--**** middle start ***-->';
        $mid1 .= '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_heading">';
        $mid1 .= '<span>' . esc_html__("COMPARISON TABLE INCLUDES", "ptsc") . '</span>';
        $mid1 .= '</div>';

        $mid1 .= '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_content">';
        $mid1 .= '<div class="ptsc_comparison_table_col ptsc_comparison_table_titles_col">';
        $mid1 .= '<!--first column, with feature title starts-->';
        $mid1 .= '<ul class="ptsc_comparison_table_feature_titles">';
        $tmp = '';

        foreach ($group["plans"] as $plan) {
            foreach ($plan["description"] as $key => $pair) {
                $tooltip_text = $tooltip_class = "";
                if ($group['enable_tooltips'] == 1) {
                    $tooltip_class = ($pair['tooltip'] == "") ? '' : ' ptsc_has_tooltip';
                    $tooltip_text = ($pair['tooltip'] == "") ? '' : '<div class="ptsc_tooltip">' . $pair['tooltip'] . '</div>';
                    $tooltip_url = ($pair['tooltip_url'] == "") ? '' : $pair['tooltip_url'];
                }
                $tmp .= '<li class="' . $tooltip_class . '">';
                $tmp .= '<span class="ptsc_feature_title_text">' . $key . ':</span>';
                $tmp .= $tooltip_text;
                $tmp .= '</li>';
            }
            break; // we only need titles from first one.
        }
        $mid1 .= $tmp;
        $mid1 .= '</ul>';
        $mid1 .= '<!--feature title end-->';
        $mid1 .= '</div>';

        $mid2 = '';
        $counter = 0;
        //$return_row = count( $group["plans"][0]["description_array"] );
        foreach ($group["plans"] as $plan) {
            // Breaking loop if number of plans exceeds 4
            /*	if ( $counter == 4 ) {
                    break;
                }*/
            $featured = '';
            if ($plan["featured"] == "yes") {
                $featured = "featured";
            }

            $mid2 .= '<!-- Column (' . $counter . ') START -->';
            $mid2 .= '<div class="ptsc_comparison_table_col">';
            $mid2 .= '<ul class="ptsc_comparison_table_feature_values ' . $featured . '">';

            $args = [
                'description_array' => $plan["description"],
                'section' => "middle",
                'return_rows' => -1,
                'convert_fa' => $group['convert_to_symbol'],
                'convert_fa_no' => $group['convert_no_with'],
                'convert_fa_yes' => $group['convert_yes_with'],
            ];
            $mid2 .= $this->ptsc_prepare_plan_features_list($args);
            $mid2 .= '</ul>';
            $mid2 .= '</div>';
            $mid2 .= '<!-- column (' . $counter . ') END -->';
            $counter++;
        }
        $mid3 = '</div>';
        $mid3 .= '<!--**** middle end ***-->';

        $mid = $mid1 . $mid2 . $mid3;

        $parts = $mid;

        return $parts;
    }

    public function ptsc_bottom_section($group, $html_table_class)
    {
        $counter = 0;
        $tables = '';
        foreach ($group["plans"] as $plan) {

            // Breaking loop if number of plans exceeds 4
            /*if ($counter == 4) {
                break;
            }*/


            $featured = '';
            if ($plan["featured"] == "yes") {
                $featured = "featured";
            }

            // Current Table Heading
            $heading =
                '<div class="ptsc_heading">
						<div class="ptsc_holder">
							<h2>' . $plan['name'] . '</h2>
						</div>
					</div> <!-- /.ptsc_heading -->';

            // Current Table Price
            $price = 50;

            // Current Table Buttons
            $button = $button = "<div class='ptsc_holder '>
				<a type='button' class='ptsc_submit-button '>" . $group['button_text'] . "</a>
			</div>";

            // Compiling Current Table Column
            $table =
                '<div class="ptsc_comparison_table_col">
						<div class="ptsc_pricing_table  ' . $featured . ' ' . $html_table_class . ' ">
							' . $heading . $price . $button . '
						</div><!-- /.ptsc_pricing_table -->
					</div>';

            $tables .= $table;
            $counter++;
        }

        $parts = '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_summary">';
        $parts .= '<div class="ptsc_comparison_table_col ptsc_comparison_table_titles_col"></div>';
        $parts .= $tables;
        $parts .= '</div>';


        /********** Summary  end ***********/

        return $parts;
    }

    public function ptsc_top_section($group, $html_table_class)
    {

        //$data=[];

        $style_2 = [
            'comparison-02',
            'comparison-04',
            'comparison-05',
            'comparison-06',
            'comparison-07'
        ];

        // =======================================================================//
        // First Column of top Row                                                 //
        // =======================================================================//
        if (($group['show_discount'] != 'no') && ($group['discount_banner'] == 'yes')) {
            $discount_container = ''; //todo write a prepare plan discounts
        } else {
            $discount_container = '';
        }

        $toggle_container = '';

        $heading_top = "<div class='ptsc_comparison_table_col ptsc_comparison_table_title_col'>
				$discount_container
				<div class='ptsc_price_toggle'>
					$toggle_container
				</div></div>
		";


        // =======================================================================//
        // Top header start        //
        // =======================================================================//


        $counter = 0;
        $tables = '';

        foreach ($group['plans'] as $plan) {
            /*if ($counter > 5) {
                break;
            }*/

            $featured = $promo = '';

            $promo = "
			<div class='ptsc_promo-text'>
				<div class='ptsc_holder'>
					<span>" . $group['ribbon_text'] . "</span>
				</div>
			</div>";

            // =======================================================================//
            // curent table heading        //
            // =======================================================================//

            $heading = "<div class='ptsc_heading'>
					<div class='ptsc_holder'>
						<h2>" . $plan['name'] . "</h2>
					</div>
				</div>";

            if ($plan['description'] == '') {
                $text = '';
            } else {
                $text = "
				<div class='ptsc_text'>
					<div class='ptsc_holder'>
						<p>" . $plan['name'] . "</p>
					</div>
				</div>";
            }

            $price = $this->ptsc_prepare_plan_price($plan);

            $discount = '';

            $args = [
                "description_array" => $plan["description"],
                'section' => 'top',
                'return_rows' => -1,
                'convert_fa' => $group['convert_to_symbol'],
                'convert_fa_no' => $group['convert_no_with'],
                'convert_fa_yes' => $group['convert_yes_with']
            ];
            $features = $this->ptsc_prepare_plan_features_list($args);
            $button = "<div class='ptsc_holder '>
				<a type='button' class='ptsc_submit-button '>" . $group['button_text'] . "</a>
			</div>";

            $button = "<div class='ptsc_button'>" . $button . "</div>";

            if (in_array($html_table_class, $style_2)) {
                $table_html = $promo . $heading . $price . $discount . $text . $features . $button;
            } else {
                $table_html = $promo . $heading . $text . $price . $discount . $features . $button;
            }

            $table =
                '<div class="ptsc_comparison_table_col">
						<div class="ptsc_pricing_table  ' . $featured . ' ' . $html_table_class . ' ">
							' . $table_html . '
						</div><!-- /.ptsc_pricing_table -->
					</div>';

            $tables .= $table;
            $counter++;
        }

        $parts = '';

        $parts .= "<div class='ptsc_comparison_table_row ptsc_comparison_table_section_tables'>";
        $parts .= $heading_top;
        $parts .= $tables;
        $parts .= "</div>";


        return $parts;
    }

    public function ptsc_prepare_plan_price($plan)
    {
        //ppa($plan["complete_discount_string"]);
        $price = "";
        $c = 0;
        $plan_prefix = $plan['prefix'];
        $plan_suffix = $plan['suffix'];
        if (is_array($plan['all_durations']) && !empty($plan['all_durations'])) {
            foreach ($plan['all_durations'] as $key => $dur) {
                $no_prefix_prices = [
                    'n/a',
                    'Free',
                    '0',
                    '0.00',
                    '-1'
                ];
                if (in_array(strtolower($dur["price"]['price']), $no_prefix_prices)) {
                    $dur_prefix = "";
                    $dur_suffix = "";
                } else {
                    $dur_prefix = $plan_prefix;
                    $dur_suffix = $plan_suffix;
                }
                // Current Table Price
                if (!empty($dur['price']['amount'])) {
                    $display = ($c == 0) ? '' : 'style="display: none;"';
                    $prefix = '<span class="ptsc_unit">' . $dur_prefix . ' </span>';
                    $suffix = '<span class="ptsc_unit">' . $dur_suffix . ' </span>';
                    $amount = '<span class="ptsc_amount">' . $dur['price']['amount'] . '</span>';
                    $fraction = ($dur['price']['fraction'] == '') ? '' : '<span class="ptsc_fraction">' . $dur['price']['fraction'] . '</span>';
                    $decimal = ($dur['price']['fraction'] == '') ? '' : '<span class="ptsc_decimal">' . $plan['decimal'] . '</span>';
                    $duration = '<span class="ptsc_period"> ' . '/' . $dur['price']['duration'] . '</span>';
                    if (($plan['show_discount'] == 'yes') && (isset($plan['pay_type']) && $plan['pay_type'] == 'recurring') && ($key != $plan["complete_discount_string"]['pri_billing'])) {
                        $price .=
                            '<div class="ptsc_holder ' . $key . '" ' . $display . ' >
							' . $plan["complete_discount_string"][$key] . '
						</div>';
                    } else {
                        $price .=
                            '<div class="ptsc_holder ' . $key . '" ' . $display . ' >
							' . $plan['complete_discount_string']['primary_discount_string'] . $prefix . $amount . $decimal . $fraction . $suffix . $duration . '
						</div>';
                    }
                }

                $c++;
            }
            $price = '<div class="ptsc_price">' . $price . '</div> <!-- /.PTSC_price -->';
        }

        return $price;
    }

    function ptsc_auto_plan_price($plan)
    {
        //ppa($plan);
        $price = "";
        $c = 0;
        $plan_prefix = $plan['prefix'];
        $plan_suffix = $plan['suffix'];
        if (is_array($plan['all_durations']) && !empty($plan['all_durations'])) {
            $no_prefix_prices = [
                'n/a',
                'Free',
                '0',
                '0.00',
                '-1'
            ];
            foreach ($plan['all_durations'] as $key => $dur) {
                if (in_array(strtolower($dur["price"]['price']), $no_prefix_prices)) {
                    $dur_prefix = "";
                    $dur_suffix = "";
                } else {
                    $dur_prefix = $plan_prefix;
                    $dur_suffix = $plan_suffix;
                }
                // Current Table Price
                if (!empty($dur['price']['amount'])) {
                    $display = ($c == 0) ? '' : 'style="display: none;"';
                    $prefix = '<span class="currency">' . $dur_prefix . ' </span>';
                    $suffix = '<span class="currency">' . $dur_suffix . ' </span>';
                    $amount = '<span class="amount">' . $dur['price']['amount'] . '</span>';
                    $fraction = ($dur['price']['fraction'] == '') ? '' : '<span class="fraction">' . $dur['price']['fraction'] . '</span>';
                    $decimal = ($dur['price']['fraction'] == '') ? '' : '<span class="decimal">' . $plan['decimal'] . '</span>';
                    $duration = '<span class="duration"> ' . '/' . $dur['price']['duration'] . '</span>';
                    if (($plan['show_discount'] == 'yes') && ($plan['pay_type'] == 'recurring') && ($key != $plan["complete_discount_string"]['pri_billing'])) {

                        $price .=
                            '<div class="holder ' . $key . '" ' . $display . ' >
							' . $plan["complete_discount_string"][$key] . '
						</div>';
                    } else {
                        $price .=
                            '<div class="holder ' . $key . '" ' . $display . ' >
							' . $plan['complete_discount_string']['primary_discount_string'] . $prefix . $amount . $decimal . $fraction . $suffix . $duration . '
						</div>';
                    }
                }

                $c++;
            }
            $price = '<div class="pricing_table_price ptsc_price_table">' . $price . '</div> <!-- /.PTSC_price -->';
        }

        return $price;
    }

    function ptsc_prepare_plan_features_list($args = [], $x = 0)
    {
        $description_array = (isset($args['description_array'])) ? $args['description_array'] : "";
        $section = (isset($args['section'])) ? $args['section'] : "";
        $return_rows = (isset($args['return_rows'])) ? $args['return_rows'] : -1;
        $convert_fa = (isset($args['convert_fa'])) ? $args['convert_fa'] : 1;
        $convert_fa_no = ($args['convert_fa_no'] != "") ? $args['convert_fa_no'] : "fa-close";
        $convert_fa_yes = ($args['convert_fa_yes'] != "") ? $args['convert_fa_yes'] : "fa-check";


        $feature_array = '';
        if (is_array($description_array) && !empty($description_array)) {
            $counter = 1;
            $feature_value_index = 0;
            //ppa($description_array);
            foreach ($description_array as $key => $pair) {
                $tooltip_class = (empty($pair['tooltip'])) ? '' : ' ptsc_has_tooltip';
                $tooltip_text = (empty($pair['tooltip'])) ? '' : '<div class="ptsc_tooltip">' . $pair['tooltip'] . '</div>';
                $key = (empty($pair['tooltip_url'])) ? $key : '<a href="' . $pair['tooltip_url'] . '">' . $key . '</a>';

                $temp_val = strtolower(!empty($pair["value"]) ? $pair['value'] : '');
                switch ($temp_val) {
                    case 'yes':
                    {
                        if (strtolower($convert_fa) == 1) {
                            $pair["value"] = '<i class="fa ptsc_icon_yes ' . $convert_fa_yes . '"></i>';
                        }
                        break;
                    }
                    case 'no':
                    {
                        if (strtolower($convert_fa) == 1) {
                            $pair["value"] = '<i class="fa ptsc_icon_no ' . $convert_fa_no . '"></i>';
                        }
                        break;
                    }
                    case '':
                    {
                        $pair["value"] = '-';
                        break;
                    }
                    default:
                    {

                    }
                }
                $feature_array .= '<li class="ptsc_feature_height_' . $x . '_' . $feature_value_index . ' ' . $tooltip_class . '" id="' . $feature_value_index . '">';
                if ($section == 'top') {
                    $feature_array .= '<strong>' . $key . ': ' . ' ' . ' </strong>';
                    $feature_array .= $tooltip_text;
                } else {
                    $feature_array .= '<span class="ptsc_comp_feature_title_responsive">' . $key . ':</span>';
                }
                $feature_array .= '<span class="ptsc_comparison_aling_center">' . $pair["value"] . '</span>';
                $feature_array .= '</li>';

                if ($counter == $return_rows) {
                    break;
                }
                $counter++;
                $feature_value_index++;
            }
        }
        $features = '
					<div class="ptsc_features ptsc_plan_description_responsive">
						<div class="ptsc_holder">
							<ul class="ptsc_comparison_table_feature_values">
								' . $feature_array . '
							</ul>
						</div>
					</div> <!-- /.whmp_features -->';

        if ($section == 'top') {
            return $features;
        } else {
            return $feature_array;
        }
    }

    public function calculate_discount($group, $product_id)
    {
        $billing1 = $group["billingcycle"];
        $billing2 = $group["billingcycle2"];
        $currency = $group["currency"];
        $type = $group["show_discount"];
        $decimals = $group["decimals"];
        $cost1 = '';
        $cost2 = '';
        $cost_string1 = '';
        $cost_string2 = '';

        //$show_duration = $group['show_duration'];
        $duration_as = $group["show_duration_as"];

        $table_pricing = $this->ptsc_pricing->table_name;
        global $wpdb;
        $Q = "select `$billing1` from `$table_pricing` where `relid`=%s and `currency`=%s";
        $price1 = $wpdb->get_var($wpdb->prepare($Q, $product_id, $currency));
        $Q = "select `$billing2` from `$table_pricing` where `relid`=%s and `currency`=%s";
        $price2 = $wpdb->get_var($wpdb->prepare($Q, $product_id, $currency));

        $months1 = $this->ptsc_convert_billingcycle($billing1, "months");

        $monthly_price1 = number_format(($price1 / $months1), $decimals);
        $monthly_prce_string1 = $monthly_price1 . $this->ptsc_convert_billingcycle("monthly", $duration_as, "per") . " when paid " . $this->ptsc_convert_billingcycle($billing2, "duration");

        $months2 = $this->ptsc_convert_billingcycle($billing2, "months");
        $monthly_price2 = number_format(($price2 / $months2), $decimals);
        $monthly_prce_string2 = $monthly_price2 . $this->ptsc_convert_billingcycle("monthly", $duration_as, "per") . " when paid " . $this->ptsc_convert_billingcycle($billing2, "duration");
        //echo "months=". $months;

        $discount1 = $discount2 = 0;

        //$discount_string1  = "";
        $lang = $this->get_current_language();
        $discount_string1 = get_option("ptsc_discount_string1_" . $lang);
        $discount_string2 = get_option("ptsc_discount_string2_" . $lang);

        $feature_string1 = get_option("ptsc_feature_string1_" . $lang);
        $feature_string2 = get_option("ptsc_feature_string2_" . $lang);

        if ($type == "amount") {
            $cost1 = $price1;
            $cost2 = number_format(($price2 / $months2), $decimals);

            $discount1 = 0;
            $discount2 = $cost1 - $cost2;

            //---- discount 1 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2 . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per");
            $discount_string1 = str_replace("{duration}", $dur, $discount_string1);
            $discount_string1 = str_replace("{discount}", $dis, $discount_string1);

            //---- discount 2 -----//

            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2 . " " . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per");
            $discount_string2 = str_replace("{duration}", $dur, $discount_string2);
            $discount_string2 = str_replace("{discount}", $dis, $discount_string2);


            $cost_string1 = "Switch " . $this->ptsc_convert_billingcycle($billing2) . $cost2 . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per");
            $cost_string2 = "costs " . $cost2 . $this->ptsc_convert_billingcycle($billing1, $duration_as, "per");


            //---- Feature 1 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2 . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per");
            $temp_array = explode("<br>", $feature_string1);
            $temp = "";
            if (is_array($temp_array) && count($temp_array) > 1) {
                $temp .= '<span class="ptsc_discount_text">' . $temp_array[0] . '</span>';
                $temp .= '<span class="ptsc_discount_value">' . $temp_array[1] . '</span>';
                $feature_string1 = $temp;
            }
            $feature_string1 = str_replace("{duration}", $dur, $feature_string1);
            $feature_string1 = str_replace("{discount}", $dis, $feature_string1);

            //---- Feature 2 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2 . " " . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per");


            $temp_array = explode("<br>", $feature_string2);
            $temp = "";
            if (is_array($temp_array) && count($temp_array) > 1) {
                $temp .= '<span class="ptsc_discount_text">' . $temp_array[0] . '</span>';
                $temp .= '<span class="ptsc_discount_value">' . $temp_array[1] . '</span>';
                $feature_string2 = $temp;
            }
            $feature_string2 = str_replace("{duration}", $dur, $feature_string2);
            $feature_string2 = str_replace("{discount}", $dis, $feature_string2);


        }

        if ($type == "percentage") {
            $cost1 = $price1;
            $cost2 = number_format(($price2 / $months2), $decimals);

            $cost_string1 = "Switch " . $this->ptsc_convert_billingcycle($billing2) . $cost2 . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per2");
            $cost_string2 = "costs " . $cost2 . $this->ptsc_convert_billingcycle($billing1, "$duration_as", "per2");

            if ($price1 == 0) {
                $discount2 = "100%";
            } else {
                $discount2 = round(100 - ($price2 / ($price1 * $months2) * 100), 0) . "%";
            }


            $discount1 = $discount2;

            //---- discount 1 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2;
            $discount_string1 = str_replace("{duration}", $dur, $discount_string1);
            $discount_string1 = str_replace("{discount}", $dis, $discount_string1);

            //---- discount 2 -----//

            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2;
            $discount_string2 = str_replace("{duration}", $dur, $discount_string2);
            $discount_string2 = str_replace("{discount}", $dis, $discount_string2);


            //---- Feature 1 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2;
            $temp_array = explode("<br>", $feature_string1);
            $temp = "";
            if (is_array($temp_array) && count($temp_array) > 1) {
                $temp .= '<span class="ptsc_discount_text">' . $temp_array[0] . '</span>';
                $temp .= '<span class="ptsc_discount_value">' . $temp_array[1] . '</span>';
                $feature_string1 = $temp;
            }
            $feature_string1 = str_replace("{duration}", $dur, $feature_string1);
            $feature_string1 = str_replace("{discount}", $dis, $feature_string1);

            //---- Feature 2 -----//
            $dur = $this->ptsc_convert_billingcycle($billing2);
            $dis = $discount2;
            $temp_array = explode("<br>", $feature_string2);
            $temp = "";
            if (is_array($temp_array) && count($temp_array) > 1) {
                $temp .= '<span class="ptsc_discount_text">' . $temp_array[0] . '</span>';
                $temp .= '<span class="ptsc_discount_value">' . $temp_array[1] . '</span>';
                $feature_string2 = $temp;
            }
            $feature_string2 = str_replace("{duration}", $dur, $feature_string2);
            $feature_string2 = str_replace("{discount}", $dis, $feature_string2);


            //echo "per month=" . $discount2;
        }

        $discount_array = [
            [
                "billingcycle" => $billing1,
                "discount" => $discount1,
                "discount_string" => $discount_string1,
                "cost" => $cost1,
                "cost_string" => $cost_string1,
                "montly_price" => $monthly_price1,
                "monthly_price_string" => $monthly_prce_string1,
                "feature_string" => $feature_string1,

            ],

            [
                "billing_cycle" => $billing2,
                "discount" => $discount2,
                "discount_string" => $discount_string2,
                "cost" => $cost2,
                "cost_string" => $cost_string2,
                "montly_price" => $monthly_price2,
                "monthly_price_string" => $monthly_prce_string2,
                "feature_string" => $feature_string2,
            ],
        ];
        return $discount_array;

    }

    public function all_prices($group, $product_id, $billing_cycle = ["monthly", "quarterly", "semiannually", "annually", "biennially", "triennially"])
    {
        $all_price = array();

        //~~ Just remove empty billing cycles and then count, and set showdiscount veriable accordingly
        $billing_cycle = array_filter($billing_cycle);
        $discount_valid = (count($billing_cycle) > 1) ? true : false;

        //if ($discount_valid) {
        //$discount = $this->calculate_discount($group, $product_id);
        //}
        //ppa($discount);
        $counter = 0;

        foreach ($billing_cycle as $billing) {
            if ($billing != "") {
                $price = $this->ptsc_break_price($group, $product_id, $billing);

                if (!empty(get_option('ptsc_override_string_price_due'))) {
                    $duration = get_option('ptsc_override_string_price_due');
                } else {
                    $duration = $price['duration'];
                }

                $order_url = $this->ptsc_order_url($product_id, $billing);
                $all_price[$billing]["price"] = [
                    "price" => $price['price'],
                    "amount" => $price['amount'],
                    "decimal" => $price['decimal'],
                    "fraction" => $price['fraction'],
                    "duration" => $duration,
                    "order_url" => $order_url,
                ];


//                if ($discount_valid && ("no" != strtolower($group["show_discount"]))) {
//                    $all_price[$billing]["discount"] = $discount[$counter];
//                }
                $counter++;
            }
        }

        return $all_price;
    }

    public function ptsc_discount_string($plan, $group)
    {

        //ppa($group,'group');
        //~~ Get all billingcycles array
        $all_billing_cycles = array($group['billingcycle'], $group['billingcycle2'], $group['billingcycle3'], $group['billingcycle4'], $group['billingcycle5'], $group['billingcycle6']);
        $complete_discount_string = array();
        $billing_with_months = array(
            'monthly' => 1,
            'quarterly' => 3,
            'semiannually' => 6,
            'annually' => 12,
            'biennially' => 24,
            'triennially' => 36
        );

        //~~ Get all non empty values of the array
        $all_billing_cycles = array_filter($all_billing_cycles);

        //~~ Getting minimum billingcycle from the list that user has selected
        $primary_billingcycle = reset($all_billing_cycles);

        //~~ Getting maximum billingcycle from the list that user has selected.
        $max_billing_cycle = end($all_billing_cycles);

        //~~ BillingCycles Array other than primary billingcycle
        $all_secondary_billing_cycles = $all_billing_cycles;
        array_shift($all_secondary_billing_cycles);

        //~~ It will calculate the discounts for all billingcycles w.r.t minimum billing cycle.
        foreach ($all_secondary_billing_cycles as $sec_billing) {
            //~~ Getting largest billingcycle from the list that user has selected
            $secondary_billingcycle = $sec_billing;

            /*
             * Getting smallest unit of months by we will multiply primary billingcycle
             * to get its participation in largest billingcycle.
             */
            $unit_of_months = $billing_with_months[$secondary_billingcycle] / $billing_with_months[$primary_billingcycle];

            //~~ Apply discount only if the pay type is recurring
            if ($plan['pay_type'] == 'recurring') {
                //~~ Preparing discount string
                $total_price_according_to_primary_billingcycle = $plan["all_durations"][$primary_billingcycle]['price']['amount'] * $unit_of_months;
                $total_saving = $total_price_according_to_primary_billingcycle - $plan["all_durations"][$secondary_billingcycle]['price']['amount'];
                $discount_months = round($total_saving / $plan["all_durations"][$primary_billingcycle]['price']['amount']);
                $discounted_price_per_primary_billing_cycle = $plan["all_durations"][$secondary_billingcycle]['price']['amount'] / $unit_of_months;
                $discount_style_2_amount = $total_price_according_to_primary_billingcycle - $plan["all_durations"][$secondary_billingcycle]['price']['amount'];
                $discount_style_2_per = ($discount_style_2_amount * 100) / $total_price_according_to_primary_billingcycle;


                $complete_discount_string[$sec_billing] = '<div class="ptsc_month_wise_discount_string">' . '<strong class="ptsc_saving_string">' . esc_html__("You're Saving ", "ptsc") . $plan['prefix'] . $total_saving . '</strong>' . '<span class="ptsc_month_discount_description">' . esc_html__(" by getting ", "ptsc") . $discount_months . esc_html__(" months free with " . $secondary_billingcycle . " prepay", "ptsc") . '</span>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_discount_applied_string">' . '<strong>' . $secondary_billingcycle . esc_html__(" discount applied!", "ptsc") . '</strong>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_secondary_discount_string">' . '<span class="ptsc_price_discount_string">' . esc_html__("Starting at ", "ptsc") . '</span>' . '<span class="ptsc_discount_del_price">' . $plan['prefix'] . $plan["all_durations"][$primary_billingcycle]['price']['amount'] . '/' . $plan["all_durations"][$primary_billingcycle]['price']['duration'] . '</span>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_pricing_doscoint_scondary">' . '<span class="currency">' . $plan['prefix'] . '</span>' . '<span class="amount">' . round($discounted_price_per_primary_billing_cycle, 2) . '</span>' . '<span class="duration">' . '/' . $plan["all_durations"][$primary_billingcycle]['price']['duration'] . '</span>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="discount_style_2">' . $secondary_billingcycle . ' ' . 'get' . ' (' . round($discount_style_2_per, '0') . '%' . ' ' . 'discount' . ')' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_secondary_discount_string ptsc_string_extra_discount">' . '<span class="ptsc_price_discount_string">' . esc_html__('Billed at ', "ptsc") . '</span>' . '<span class="ptsc_discount_del_price">' . $plan['prefix'] . $total_price_according_to_primary_billingcycle . '</span>' . '<span class="ptsc_discount_section_larger_price">' . ' ' . '<span class="">' . $plan['prefix'] . '</span>' . $plan["all_durations"][$secondary_billingcycle]['price']['amount'] . "/" . $plan["all_durations"][$secondary_billingcycle]['price']['duration'] . '</span>' . '</div>';
            } else {
                $complete_discount_string[$sec_billing] = '';
            }
        }


        if ($plan['pay_type'] == 'recurring' && $plan['show_discount'] == 'yes') {
            $unit_of_months_for_primary_string = $billing_with_months[$max_billing_cycle] / $billing_with_months[$primary_billingcycle];
            $total_price_according_to_primary_billingcycle_for_primary_string = $plan["all_durations"][$primary_billingcycle]['price']['amount'] * $unit_of_months_for_primary_string;
            $total_saving_for_primary_string = $total_price_according_to_primary_billingcycle_for_primary_string - $plan["all_durations"][$max_billing_cycle]['price']['amount'];
            $discount_months_for_primary_string = round($total_saving_for_primary_string / $plan["all_durations"][$primary_billingcycle]['price']['amount']);
            $complete_discount_string['pri_billing'] = $primary_billingcycle;
            $complete_discount_string['primary_discount_string'] = '<div class="ptsc_pri_billing_wise_discount_string">' . '<strong class="ptsc_saving_string">' . esc_html__("Save ", "ptsc") . $plan['prefix'] . $total_saving_for_primary_string . '</strong>' . '<span class="wpct_month_discount_description">' . esc_html__(" by getting ", "ptsc") . $discount_months_for_primary_string . esc_html__(" months free with " . $max_billing_cycle . " prepay", "ptsc") . '</span>' . '</div>';
        } else {
            $complete_discount_string['primary_discount_string'] = '';
        }

        return $complete_discount_string;

    }

    public function ptsc_discount_string_com_sli($plan, $group)
    {

        //ppa($group,'group');
        //~~ Get all billingcycles array
        $all_billing_cycles = array($group['billingcycle'], $group['billingcycle2'], $group['billingcycle3'], $group['billingcycle4'], $group['billingcycle5'], $group['billingcycle6']);
        $complete_discount_string = array();
        $billing_with_months = array(
            'monthly' => 1,
            'quarterly' => 3,
            'semiannually' => 6,
            'annually' => 12,
            'biennially' => 24,
            'triennially' => 36
        );

        //~~ Get all non empty values of the array
        $all_billing_cycles = array_filter($all_billing_cycles);

        //~~ Getting minimum billingcycle from the list that user has selected
        $primary_billingcycle = reset($all_billing_cycles);

        //~~ Getting maximum billingcycle from the list that user has selected.
        $max_billing_cycle = end($all_billing_cycles);

        //~~ BillingCycles Array other than primary billingcycle
        $all_secondary_billing_cycles = $all_billing_cycles;
        array_shift($all_secondary_billing_cycles);

        //~~ It will calculate the discounts for all billingcycles w.r.t minimum billing cycle.
        foreach ($all_secondary_billing_cycles as $sec_billing) {
            //~~ Getting largest billingcycle from the list that user has selected
            $secondary_billingcycle = $sec_billing;

            /*
             * Getting smallest unit of months by we will multiply primary billingcycle
             * to get its participation in largest billingcycle.
             */
            $unit_of_months = $billing_with_months[$secondary_billingcycle] / $billing_with_months[$primary_billingcycle];

            //~~ Apply discount only if the pay type is recurring
            if ($plan['pay_type'] == 'recurring') {
                //~~ Preparing discount string
                $total_price_according_to_primary_billingcycle = $plan["all_durations"][$primary_billingcycle]['price']['amount'] * $unit_of_months;
                $total_saving = $total_price_according_to_primary_billingcycle - $plan["all_durations"][$secondary_billingcycle]['price']['amount'];
                $discount_months = round($total_saving / $plan["all_durations"][$primary_billingcycle]['price']['amount']);
                $discounted_price_per_primary_billing_cycle = $plan["all_durations"][$secondary_billingcycle]['price']['amount'] / $unit_of_months;


                $complete_discount_string[$sec_billing] = '<div class="ptsc_month_wise_discount_string">' . '<strong class="ptsc_saving_string">' . esc_html__("You're Saving ", "ptsc") . $plan['prefix'] . $total_saving . '</strong>' . '<span class="ptsc_month_discount_description">' . esc_html__(" by getting ", "ptsc") . $discount_months . esc_html__(" months free with " . $secondary_billingcycle . " prepay", "ptsc") . '</span>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_discount_applied_string">' . '<strong>' . $secondary_billingcycle . esc_html__(" discount applied!", "ptsc") . '</strong>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_secondary_discount_string">' . '<span class="ptsc_price_discount_string">' . esc_html__("Starting at ", "ptsc") . '</span>' . '<span class="ptsc_discount_del_price">' . $plan['prefix'] . $plan["all_durations"][$primary_billingcycle]['price']['amount'] . '/' . $plan["all_durations"][$primary_billingcycle]['price']['duration'] . '</span>' . '</div>';
                $complete_discount_string[$sec_billing] .= '<span class="ptsc_unit">' . $plan['prefix'] . '</span>' . '<span class="ptsc_amount">' . round($discounted_price_per_primary_billing_cycle, 2) . '</span>' . '<span class="ptsc_period">' . '/' . $plan["all_durations"][$primary_billingcycle]['price']['duration'] . '</span>';
                $complete_discount_string[$sec_billing] .= '<div class="ptsc_secondary_discount_string ptsc_string_extra_discount">' . '<span class="ptsc_price_discount_string">' . esc_html__('Billed at ', "ptsc") . '</span>' . '<span class="ptsc_discount_del_price">' . $plan['prefix'] . $total_price_according_to_primary_billingcycle . '</span>' . '<span class="ptsc_discount_section_larger_price">' . ' ' . $plan['prefix'] . $plan["all_durations"][$secondary_billingcycle]['price']['amount'] . "/" . $plan["all_durations"][$secondary_billingcycle]['price']['duration'] . '</span>' . '</div>';
            } else {
                $complete_discount_string[$sec_billing] = '';
            }
        }


        if ($plan['pay_type'] == 'recurring' && $plan['show_discount'] == 'yes') {
            $unit_of_months_for_primary_string = $billing_with_months[$max_billing_cycle] / $billing_with_months[$primary_billingcycle];
            $total_price_according_to_primary_billingcycle_for_primary_string = $plan["all_durations"][$primary_billingcycle]['price']['amount'] * $unit_of_months_for_primary_string;
            $total_saving_for_primary_string = $total_price_according_to_primary_billingcycle_for_primary_string - $plan["all_durations"][$max_billing_cycle]['price']['amount'];
            $discount_months_for_primary_string = round($total_saving_for_primary_string / $plan["all_durations"][$primary_billingcycle]['price']['amount']);
            $complete_discount_string['pri_billing'] = $primary_billingcycle;
            $complete_discount_string['primary_discount_string'] = '<div class="ptsc_pri_billing_wise_discount_string">' . '<strong class="ptsc_saving_string">' . esc_html__("Save ", "ptsc") . $plan['prefix'] . $total_saving_for_primary_string . '</strong>' . '<span class="wpct_month_discount_description">' . esc_html__(" by getting ", "ptsc") . $discount_months_for_primary_string . esc_html__(" months free with " . $max_billing_cycle . " prepay", "ptsc") . '</span>' . '</div>';
        } else {
            $complete_discount_string['primary_discount_string'] = '';
        }

        return $complete_discount_string;

    }

    public function all_prices_woo($group, $billing_cycle = ["monthly", "quarterly", "semiannually", "annually", "biennially", "triennially"])
    {
        $all_price_woo = array();

        //~~ Just remove empty billing cycles and then count, and set showdiscount veriable accordingly
        $billing_cycle = array_filter($billing_cycle);
        $discount_valid = (count($billing_cycle) > 1) ? true : false;

        $counter = 0;

        foreach ($billing_cycle as $billing) {
            if ($billing != "") {
                $all_price_woo[$billing]["price"] = [
                    "price" => $group['price'],
                    "amount" => $group['amount'],
                    "decimal" => $group['decimal'],
                    "fraction" => $group['fraction'],
                    "duration" => $group['duration'],
                    "order_url" => $group["order_url"],
                ];
                $counter++;
            }
        }

        return $all_price_woo;
    }

    public function return_tooltip($match_string)
    {
        global $wpdb;
        $tbl_tooltip = $this->ptsc_tooltip->table_name;
        $row = $wpdb->get_row("SELECT * FROM `" . $tbl_tooltip . "` WHERE `match_string` LIKE '%" . $match_string . "%'");

        if (isset($row)) {
            return $row->tooltip_text;
        } else {
            return null;
        }


    }

    public function return_tooltip_url($match_string)
    {

        global $wpdb;
        $tbl_tooltip = $this->ptsc_tooltip->table_name;
        $row = $wpdb->get_row("SELECT * FROM `" . $tbl_tooltip . "` WHERE `match_string` LIKE '%" . $match_string . "%'");

        if (isset($row)) {
            return $row->tooltiplink;
        } else {
            return null;
        }


    }

    public function return_tooltip_icon($match_string)
    {

        global $wpdb;
        $tbl_tooltip = $this->ptsc_tooltip->table_name;
        $row = $wpdb->get_row("SELECT * FROM `" . $tbl_tooltip . "` WHERE `match_string` LIKE '%" . $match_string . "%'");

        if (isset($row)) {
            return $row->tooltipicon;
        } else {
            return null;
        }


    }

    public function return_feature_title($match_string)
    {

        $title = $match_string;
        $is_tooltip_url = $this->return_tooltip_url($match_string);
        if ($is_tooltip_url != "") {
            $linked_title = '<a href="' . $is_tooltip_url . '">' . $title . '</a>';
            return $linked_title;

        } else {
            return $title;
        }


    }

    public function ptsc_prepare_plan_discounts($plan, $table = "", $show_secondary = "no")
    {
        $price = "";
        $c = 0;
        if (!empty($plan['pay_type']) && $plan['pay_type'] == 'recurring') {
            if (is_array($plan['all_durations']) && !empty($plan['all_durations'])) {
                foreach ($plan['all_durations'] as $key => $dur) {

                    if (!empty($dur['price']['amount'])) {
                        // Current Table Price
                        $display = ($c == 0) ? '' : 'style="display: none;"';
                        //$discount      = '<span class="ptsc_discount_text">' . $dur['discount']['feature_string'] . '</span>';
                        $feature_string = isset($dur['discount']['feature_string']) ? $dur['discount']['feature_string'] : '';
                        //$discount_string = "";
                        /*if ( !empty($dur['discount']['discount_string']) ) {
                            $discount_string = '<span class="ptsc_discount_string">' . $dur['discount']['discount_string'] . '</span>';
                        }*/
                        //ppa($dur);
                        $discount_string = '';

                        if ($show_secondary == "no" && $c == 1) {
                            $price .= '<div class="ptsc_holder ' . $key . '" ' . $display . ' ></div>';
                        } else {
                            if ($table == "table") {
                                $price .=
                                    '<div class="ptsc_holder ' . $key . '" ' . $display . ' >'
                                    . $discount_string .
                                    '</div>';
                            } else {
                                $price .=
                                    '<div class="ptsc_holder ' . $key . '" ' . $display . ' >'
                                    . $feature_string .
                                    '</div>';
                            }
                        }
                    }

                    $c++;
                }
                $price = '<div class="ptsc_discounts_container">' . $price . '</div> <!-- /.PTSC_price -->';
            }
        }
        return $price;
    }

    public function ptsc_prepare_duration_toggle($group, $r)
    {
        $toggle_container = '';
        $dur_array = $group["plans"][0]['all_durations'];

        //~~ We are setting toggle style as radio as it is deleted from options
        $group['toggle_style'] = 'radio_button';
        if ($group['toggle_style'] == 'radio_button') {
            if (is_array($dur_array) && (!empty($dur_array) && count($dur_array) > 1)) {
                $c = 0;
                $toggle_container .= '<div class="ptsc_radio_toggle">';
                foreach ($group["plans"][0]['all_durations'] as $key => $dur) {
                    $active = ($c == 0) ? 'active' : '';
                    $checked = ($c == 0) ? 'checked="checked"' : '';
                    if (!empty($group["plans"][0][array_search($key, $group) . '_override_string'])) {
                        $toggle_container .= '<label><input type="radio" name="duration_' . $r . '" data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ' . $checked . '><span>' . $group['plans'][0][array_search($key, $group) . '_override_string'] . '</span></label>';
                    } else {
                        $toggle_container .= '<label><input type="radio" name="duration_' . $r . '" data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ' . $checked . '><span>' . $this->ptsc_convert_billingcycle($key) . '</span></label>';
                    }

                    $c++;
                }
                $toggle_container .= '</div>';

            }
        } elseif ($group['toggle_style'] == 'slider_toggle') {
            if (is_array($dur_array) && (!empty($dur_array) && count($dur_array) > 1)) {
                //ppa($group["plans"][0]['all_durations']);
                $c = 1;
                $duration_counter = 1;
                $toggle_container .= '<ul id="JS_Data" style="display: none !important;">';
                foreach ($group["plans"][0]['all_durations'] as $key => $dur) {
                    $toggle_container .= '<li data-index = "' . $duration_counter . '" >';
                    $toggle_container .= '<span data-index = "' . $key . '" ></span >';
                    $toggle_container .= '</li >';
                    $duration_counter++;
                }
                $toggle_container .= '</ul>';
                $toggle_container .= '<div style="clear: both;"></div>';
                $toggle_container .= '<div id="heading_slider">';
                $toggle_container .= '<div id="head_text">';
                $toggle_container .= '<h3>Choose your billing cycle</h3>';
                $toggle_container .= '</div>';
                $toggle_container .= '<div class="ptsc_slider_heading ptsc_package_title_mobile">';
                $toggle_container .= '<span>' . $group['plans'][0]['billingcycle'] . '</span>';
                $toggle_container .= '</div>';
                $toggle_container .= '<div class="ptsc_package_title" id="ptsc_package_title"><input type="hidden">';
                $toggle_container .= '<ul class="ptsc_packages_list">';
                foreach ($group["plans"][0]['all_durations'] as $key => $dur) {
                    $toggle_container .= '<li class="ptsc_package_title" data-index = "' . $c . '"  data-title = "' . $key . '">';
                    $toggle_container .= '<span class="ptsc_package_title_desktop" >' . $key . '</span >';
                    $toggle_container .= '<span class="ptsc_package_title_mobile" >' . $key . '</span>';
                    $toggle_container .= '</li>';
                    $c++;
                }
                $toggle_container .= '</ul>';
                $toggle_container .= '</div>';

                $toggle_container .= '<div style="clear: both"></div>';
                $toggle_container .= '<div id="ptsc_slider"></div>';
                $toggle_container .= '</div>';
            }
        } else {
            if (is_array($dur_array) && (!empty($dur_array) && count($dur_array) > 1)) {
                $c = 0;
                $toggle_container .= '<select name="duration_dropdown" id="duration_dropdown" >';
                foreach ($group["plans"][0]['all_durations'] as $key => $dur) {
                    $active = ($c == 0) ? 'active' : '';
                    $selected = ($c == 0) ? 'selected="selected"' : '';

                    $toggle_container .= '<option name="duration_' . $r . '" value=" ' . $key . ' " data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ".' . $selected . '">' . $this->ptsc_convert_billingcycle($key) . '</option>';
                    $c++;
                }
                $toggle_container .= '</select>';
            }
        }

        return $toggle_container;
    }

    public function ptsc_prepare_duration_toggle_single($group, $r)
    {
        $toggle_container = '';
        $dur_array = $group["plan"]['all_durations'];
        if (is_array($dur_array) && (!empty($dur_array) && count($dur_array) > 1)) {
            $c = 0;
            foreach ($group["plan"]['all_durations'] as $key => $dur) {
                $active = ($c == 0) ? 'active' : '';
                $checked = ($c == 0) ? 'checked="checked"' : '';
                if (!empty($group["plans"][0][array_search($key, $group['plans'][0]) . '_override_string'])) {
                    $toggle_container .= '<label><input type="radio" name="duration_' . $r . '" data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ' . $checked . '><span>' . $group['plans'][0][array_search($key, $group['plans'][0]) . '_override_string'] . '</span></label>';
                } else {
                    $toggle_container .= '<label><input type="radio" name="duration_' . $r . '" data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ' . $checked . '><span>' . $this->ptsc_convert_billingcycle($key) . '</span></label>';
                }
                $c++;
            }

        }

        return $toggle_container;
    }

    function ptsc_prepare_duration_dropdown($group, $r)
    {
        $dropdown_container = '';
        $dur_array = $group["plans"][0]['all_durations'];
        if (is_array($dur_array) && (!empty($dur_array) && count($dur_array) > 1)) {
            $c = 0;
            $dropdown_container .= '<select name="duration_dropdown" id="duration_dropdown" >';
            foreach ($group["plans"][0]['all_durations'] as $key => $dur) {
                $active = ($c == 0) ? 'active' : '';
                $selected = ($c == 0) ? 'selected="selected"' : '';

                $dropdown_container .= '<option name="duration_' . $r . '" value=" ' . $key . ' " data-orderurl="' . $dur['price']['order_url'] . '" data-duration="' . $key . '" class="' . $active . '" ".' . $selected . '">' . $this->ptsc_convert_billingcycle($key) . '</option>';
                $c++;
            }
            $dropdown_container .= '</select>';
        }
        return $dropdown_container;
    }

    public function ptsc_prepare_plan_button($group, $plan)
    {
        $button = "";
        $c = 0;
        if (is_array($plan['all_durations']) && !empty($plan['all_durations'])) {
            foreach ($plan['all_durations'] as $key => $dur) {
                //~~ Setting Order URL

                $dur_order_url = '';
                if (!empty($dur['price']['order_url'])) {
                    $dur_order_url = $dur['price']['order_url'];
                } else {

                    if ($dur['price']['amount'] == 'Free') {
                        $dur_order_url = '';
                    } elseif ($dur['price']['duration'] == 'One Time') {
                        $dur_order_url = get_option('ptsc_order_page_url') . '?pid=' . $plan['product_id'] . '&billingcycle=monthly';
                    } else {
                        if (!empty(get_option('ptsc_order_page_url'))) {
                            $dur_order_url = get_option('ptsc_order_page_url') . '?pid=' . $plan['product_id'] . '&billingcycle=' . $key;
                        } elseif (!empty($dur['order_url'])) {
                            $dur_order_url = $dur['order_url'];
                        }
                    }
                }


                // Current Table Price
                $display = ($c == 0) ? '' : 'style="display: none;"';
                $button_text = !empty($plan['product_button_text']) ? $plan['product_button_text'] : $group["button_text"];
                $button .=
                    '<div class="ptsc_holder ' . $key . '" ' . $display . ' >
							<a type="button" class="ptsc_submit-button ptsc_submit" href="' . $dur_order_url . '">' . $button_text . '</a>
						</div>';
                $c++;
            }
            $button = '<div class="ptsc_button">' . $button . '</div> <!-- /.PTSC_button -->';
        }

        return $button;
    }

    public function ptsc_prepare_html_middle($group, $x = 0)
    {
        //$convert_fa = ( $group['convert_to_symbol'] == "1" ) ? "yes" : "no";


        $mid1 = '<!--**** middle start ***-->';
        $mid1 .= '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_heading">';
        $mid1 .= '<span>Comparison Table Includes</span>';
        $mid1 .= '</div>';

        $mid1 .= '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_content">';
        $mid1 .= '<div class="ptsc_comparison_table_col ptsc_comparison_table_titles_col">';
        $mid1 .= '<!--first column, with feature title starts-->';
        $mid1 .= '<ul class="ptsc_comparison_table_feature_titles">';
        $tmp = '';

        $feature_title_index = 0;
        $limit = $this->charater_limits(count($group["plans"]));
        foreach ($group["plans"] as $plan) {
            foreach ($plan["description_array"] as $key => $pair) {
//                $long_string_text = (mb_strlen(strtolower($key), Smarty::$_CHARSET) > $limit) ? '<span class="my-hover-toolstip">' . $key . ':</span>' : "";

                $tooltip_text = $tooltip_class = "";
                if ($group['enable_tooltips'] == 1) {
                    $featured_title = $this->return_feature_title($key);
                    $tooltip_class = ($pair['tooltip'] == "") ? '' : ' ptsc_has_tooltip';
                    $tooltip_text = ($pair['tooltip'] == "") ? '' : '<div class="ptsc_tooltip">' . $pair['tooltip'] . '</div>';
                    $key = $featured_title;
                    /*$key_text = ($pair['tooltip'] == "") ? '' : '<div class="ptsc_tooltip">' . $key . '</div>';*/
                }
                $tmp .= '<li class="ptsc_feature_height_' . $x . '_' . $feature_title_index . ' ' . $tooltip_class . '">';
                $tmp .= '<span class="ptsc_feature_title_text" id= "' . $feature_title_index . '">' . $key . ':</span>';
//                $tmp .= $long_string_text;
                $tmp .= $tooltip_text;
                $tmp .= '</li>';
                $feature_title_index++;
            }
            break; // we only need titles from first one.
        }
        $mid1 .= $tmp;
        $mid1 .= '</ul>';
        $mid1 .= '<!--feature title end-->';
        $mid1 .= '</div>';

        $mid2 = '';
        $counter = 0;
        //$return_row = count( $group["plans"][0]["description_array"] );
        foreach ($group["plans"] as $plan) {
            // Breaking loop if number of plans exceeds 4
            //commenting by zain
            /*	if ( $counter == 4 ) {
                    break;
                }
            */
            $featured = '';
            if ($plan["featured"] == "yes") {
                $featured = "featured";
            }

            $mid2 .= '<!-- Column (' . $counter . ') START -->';
            $mid2 .= '<div class="ptsc_comparison_table_col">';
            $mid2 .= '<ul class="ptsc_comparison_table_feature_values ' . $featured . '">';

            $args = [
                'description_array' => $plan["description_array"],
                'section' => "middle",
                'return_rows' => -1,
                'convert_fa' => $group['convert_to_symbol'],
                'convert_fa_no' => $group['convert_no_with'],
                'convert_fa_yes' => $group['convert_yes_with'],
            ];
            $mid2 .= $this->ptsc_prepare_plan_features_list($args);
            $mid2 .= '</ul>';
            $mid2 .= '</div>';
            $mid2 .= '<!-- column (' . $counter . ') END -->';
            $counter++;
        }
        $mid3 = '</div>';
        $mid3 .= '<!--**** middle end ***-->';

        $mid = $mid1 . $mid2 . $mid3;

        $parts["middle"] = $mid;

        return $parts["middle"];
    }

    public function ptsc_prepare_html_middle_sections($group)
    {
        $x = 0;
        $section = '';
        //$convert_fa = ( $group['convert_to_symbol'] == "1" ) ? "yes" : "no";

        foreach ($group["section"] as $title) {
            $section_title = '<!--**** start section title (' . $x . ') ***-->';
            $section_title .= '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_heading">';
            $section_title .= '<span>' . $title . '</span>';
            $section_title .= '</div>';
            $section_title .= '<!--**** end section title ***-->';

            $section_details = '<div class="ptsc_comparison_table_row ptsc_comparison_table_section_content">';

            $features_set = false;
            $section_features = '';
            $section_values = '';
            //todo: impliment beelow functions in PTSC_prepare_html_middle too.
            if (is_array($group['plans']) && !empty($group['plans'])) {
                foreach ($group["plans"] as $plan) {
                    $featured = '';
                    if ($plan["featured"] == "yes") {
                        $featured = "featured";
                    }


                    //todo: maybe we could check total groups at first and escape the loop when needed.

                    // only pass the first section of plan to get features and values
                    // get features only for once

                    // note: consider plans as columns, on each foreach, we get next plan/column and
                    //for that plans/column we only fetch values of required section.

                    //tooltips are not being offered as yet.

                    $tooltip_status = $group['enable_tooltips'];
                    if ($features_set == false) {
                        //$tmp = $this->description_to_array( $plan_description, $rows, $sep, 3, false );
                        $section_features .= $this->ptsc_feature_row_html($plan['description_section'][$x], $tooltip_status, $x);
                        $features_set = true;
                    }

                    if (isset($plan['description_section']) && is_array($plan['description_section']) && (count($plan['description_section']) > $x)) {

                        $section_values .= $this->ptsc_values_row_html($plan['description_section'][$x],$group, $featured, $x);
                    }
                }
            }
            $section_details .= $section_features . $section_values;
            $section_details .= '</div>';

            $section .= $section_title . $section_details;
            $x++;
        }

        $parts["middle"] = $section;

        return $parts["middle"];
    }

    public function ptsc_feature_row_html($plans, $tooltip_status = 1, $x = 0)
    {
        $tmp = "";
        $mid1 = '';
        $mid1 .= '<!--first column, with feature title starts-->';
        $mid1 .= '<div class="ptsc_comparison_table_col PTSC_comparison_table_titles_col">';
        $mid1 .= '<ul class="ptsc_comparison_table_feature_titles">';
        if (is_array($plans) && !empty($plans)) {
            $li_feature_counter = 0;
            foreach ($plans as $key => $pair) {
                $tooltip_text = $tooltip_class = "";
                if ($tooltip_status == 1) {
                    $tooltip_class = ($pair['tooltip'] == "") ? '' : ' ptsc_has_tooltip';
                    $tooltip_text = ($pair['tooltip'] == "") ? '' : '<div class="ptsc_tooltip">' . $pair['tooltip'] . '</div>';
                    $key = ($pair['tooltip_url'] == "") ? $key : '<a href="' . $pair['tooltip_url'] . '">' . $key . '</a>';
                }
                $tmp .= '<li class="ptsc_feature_height_' . $x . '_' . $li_feature_counter . ' ' . $tooltip_class . '">';
                $tmp .= '<span class="ptsc_feature_title_text">' . $key . ':</span>';
                $tmp .= $tooltip_text;
                $tmp .= '</li>';
                $li_feature_counter++;
            }
        }
        $mid1 .= $tmp;
        $mid1 .= '</ul>';
        $mid1 .= '</div>';
        $mid1 .= '<!-- end features column -->';

        return $mid1;
    }

    public function ptsc_values_row_html($plans, $group, $featured = '', $x = '0')
    {
        $mid2 = '';
        $mid2 .= '<!-- value column start -->';
        $mid2 .= '<div class="ptsc_comparison_table_col">';
        $mid2 .= '<ul class="ptsc_comparison_table_feature_values ' . $featured . ' ">';

        $args = [
            'description_array' => $plans,
            'section' => "middle",
            'return_rows' => -1,
            'convert_fa' => $group['convert_to_symbol'],
            'convert_fa_no' => $group['convert_no_with'],
            'convert_fa_yes' => $group['convert_yes_with'],
        ];
        $mid2 .= $this->ptsc_prepare_plan_features_list($args, $x);
        $mid2 .= '</ul>';
        $mid2 .= '</div>';
        $mid2 .= '<!-- value column end -->';

        return $mid2;
    }


    public function ptsc_convert_billingcycle($billingcycle, $style = "duration", $connector = "")
    {
        /**todo: take duration style in settings, suggested
         * duration connector:
         * none=blank
         * / = per
         * per = per2
         *
         * duration style:
         * Default = duration
         * Long (year) = long
         * Short (yr) = short
         * Convert to Months (12 month) = monthly
         */

        $valid_billing_cycles = ["onetime", "monthly", "quarterly", "semiannually", "annually", "biennially", "triennially"];

        $valid_styles = ["months", "duration", "duration2", "long", "short", "monthly"];
        $style = (in_array($style, $valid_styles)) ? $style : "duration";

        if (in_array($billingcycle, $valid_billing_cycles) == true) {

            $map = [
                "onetime" => [
                    "months" => 0,
                    "duration" => esc_html__("OneTime", "ptsc"),
                    "duration2" => esc_html__("Pay Once", "ptsc"),
                    "long" => esc_html__("One Time", "ptsc"),
                    "short" => esc_html__("OT", "ptsc"),
                    "monthly" => esc_html__("One Time", "ptsc"),
                ],

                "monthly" => [
                    "months" => 1,
                    "duration" => esc_html__("Monthly", "ptsc"),
                    "duration2" => esc_html__("1 month", "ptsc"),
                    "long" => esc_html__("Month", "ptsc"),
                    "short" => esc_html__("mo", "ptsc"),
                    "monthly" => esc_html__("1 Month", "ptsc"),
                ],

                "quarterly" => [
                    "months" => 3,
                    "duration" => esc_html__("Quarterly", "ptsc"),
                    "duration2" => esc_html__("3 month", "ptsc"),
                    "long" => esc_html__("Quarter", "ptsc"),
                    "short" => esc_html__("qu", "ptsc"),
                    "monthly" => esc_html__("3 Months", "ptsc"),
                ],

                "semiannually" => [
                    "months" => 6,
                    "duration" => esc_html__("Semi Annually", "ptsc"),
                    "duration2" => esc_html__("6 month", "ptsc"),
                    "long" => esc_html__("Half year", "ptsc"),
                    "short" => esc_html__("sa", "ptsc"),
                    "monthly" => esc_html__("6 Months", "ptsc"),
                ],

                "annually" => [
                    "months" => 12,
                    "duration" => esc_html__("Annually", "ptsc"),
                    "duration2" => esc_html__("1 year", "ptsc"),
                    "long" => esc_html__("Year", "ptsc"),
                    "short" => esc_html__("yr", "ptsc"),
                    "monthly" => esc_html__("12 Months", "ptsc"),
                ],

                "biennially" => [
                    "months" => 24,
                    "duration" => esc_html__("Biennially", "ptsc"),
                    "duration2" => esc_html__("2 Year", "ptsc"),
                    "long" => esc_html__("2 Years", "ptsc"),
                    "short" => esc_html__("2 yrs", "ptsc"),
                    "monthly" => esc_html__("24 Months", "ptsc"),
                ],

                "triennially" => [
                    "months" => 36,
                    "duration" => esc_html__("Triennially", "ptsc"),
                    "duration2" => esc_html__("3 Year", "ptsc"),
                    "long" => esc_html__("3 Years", "ptsc"),
                    "short" => esc_html__("3 yrs", "ptsc"),
                    "monthly" => esc_html__("36 Months", "ptsc"),
                ]
            ];

            return $map[$billingcycle][$style];

        } else {

            $error_message = esc_html__('Invalid billing cycle', "ptsc");

            return $error_message;
        }
    }


    /*public function ptsc_convert_billingcycle( $billingcycle,$style = "duration",$connector = "blank" ) {

        $connector="per";
		$map = [

			"free" => [
				"months"   => '',
				"duration" => "",

				"long" => [
					"blank" => "",
					"per"   => "",
					"per2"  => "",
				],

				"short" => [
					"blank" => "",
					"per"   => "",
					"per2"  => "",
				],

				"monthly" => [
					"blank" => "",
					"per"   => "",
					"per2"  => "",
				],
			],

			"monthly" => [
				"months"   => 1,
				"duration" => "monthly",

				"long" => [
					"blank" => "Month",
					"per"   => "/Month",
					"per2"  => "per Month",
				],

				"short" => [
					"blank" => "mo",
					"per"   => "/mo",
					"per2"  => "per mo",
				],

				"monthly" => [
					"blank" => "1 Month",
					"per"   => "/ Month",
					"per2"  => "per Month",
				],
			],

			"quarterly" => [
				"months"   => 3,
				"duration" => "quarterly",

				"long"  => [
					"blank" => "Quarter",
					"per"   => "/Quarter",
					"per2"  => "per Quarter",
				],
				"short" => [
					"blank" => "qu",
					"per"   => "/qu",
					"per2"  => "/qu",
				],

				"monthly" => [
					"blank" => "3 Months",
					"per"   => "/3 Months",
					"per2"  => "per 3 Months",
				],
			],

			"semiannually" => [
				"months"   => 6,
				"duration" => "semiannually",
				"long"     => [
					"blank" => "Half Year",
					"per"   => "/Half year",
					"per2"  => "per Half year",
				],
				"short"    => [
					"blank" => "sa",
					"per"   => "/sa",
					"pers"  => "per sa",
				],
				"monthly"  => [
					"blank" => "6 Months",
					"per"   => "/6 Months",
					"per2"  => "per 6 Months",
				]
			],

			"annually" => [
				"months"   => 12,
				"duration" => "Yearly",
				"long"     => [
					"blank" => "Year",
					"per"   => "/Year",
					"per2"  => "per Year",
				],
				"short"    => [
					"blank" => "yr",
					"per"   => "/yr",
					"per2"  => "per yr",
				],
				"monthly"  => [
					"blank" => "12 Months",
					"per"   => "/12 Months",
					"per2"  => "per 12 Months",
				],
			],

			"biennially" => [
				"months"   => 24,
				"duration" => "Biennially",
				"long"     => [
					"blank" => "2 Years",
					"per"   => "/2 Years",
					"per2"  => "per 2 Years",
				],

				"short" => [
					"blank" => "2 yrs",
					"per"   => "/2 yrs",
					"per2"  => "per 2 yrs",
				],

				"monthly" => [
					"blank" => "24 Months",
					"per"   => "/24 Months",
					"per2"  => "per 24 Months",
				],
			],

			"triennially" => [
				"months"   => 36,
				"duration" => "Triennially",

				"long" => [
					"blank" => "3 Years",
					"per"   => "/3 years",
					"per2"  => "per 3 years",
				],

				"short" => [
					"blank" => "3 yrs",
					"per"   => "/3 yrs",
					"per2"  => "per 3 yrs",
				],

				"monthly" => [
					"blank" => "36 Months",
					"per"   => "/36 Months",
					"per2"  => "per 36 Months",
				],
			]
		];


		if(empty($style)) {
			$style="duration";
		}
		if ( $style == "months" || $style == "duration" ) {
			return $map[ $billingcycle ][ $style ];

		} else {
			return $map[ $billingcycle ][ $style][$connector];
		}
	}*/

    public function ptsc_prepare_plan_durations($plan)
    {

        $price = "";
        $c = 0;
        if (is_array($plan['all_durations']) && !empty($plan['all_durations'])) {
            foreach ($plan['all_durations'] as $key => $dur) {
                // Current Table Price
                $display = ($c == 0) ? '' : 'style="display: none;"';
                $duration = $dur['price']['duration'];
                $price .=
                    '<span class="ptsc_holder ' . $key . '" ' . $display . ' >
							' . $duration . '
						</span>';
                $c++;
            }
        }

        return $price;
    }

    public function ptsc_get_current_currency_id_i()
    {
        if (isset($_GET["cur"])) {
            $currency = $_GET["cur"];
        } else {
            $currency = $this->ptsc_get_default_currency();
        }

        return $currency;
    }

    public function ptsc_get_products_table_name()
    {

        return $this->ptsc_products->table_name;
    }

    public function ptsc_is_trailing_zeros($price)
    {
        $fprice = (float)$price;
        $iprice = (int)$price;

        if ($iprice == $fprice) {
            return true;
        } else {
            return false;
        }
    }

    public function ptsc_price_function($billing1, $currency, $product_id, $decimals)
    {

    }

    public function ptsc_order_url($product_id, $billing = '')
    {
        if ($billing != '') {
            $target_url_handle = $billing . '_url';
            $table_pricing = $this->ptsc_pricing->table_name;
            $Q = "Select `$target_url_handle` from `$table_pricing` where `relid`=%s";
            global $wpdb;
            $result = $wpdb->get_var($wpdb->prepare($Q, $product_id));
            return $result;
        } else {
            return '';
        }
    }


    public function ptsc_all_products()
    {
        return $products = $this->ptsc_products->ptsc_select();
    }

    public function pts_all_groups()
    {
        return $groups = $this->ptsc_group->ptsc_select();
    }

    public function ptsc_all_group_details()
    {
        return $group_details = $this->ptsc_group_detail->ptsc_select();
    }

    public function ptsc_all_currencies()
    {
        return $this->ptsc_currency->ptsc_select();
    }

    public function ptsc_all_pricings()
    {
        return $this->ptsc_pricing->ptsc_select();
    }

    public function ptsc_all_tooltips()
    {
        return $tooltip = $this->ptsc_tooltip->ptsc_select();
    }

    public function ptsc_ppa($argument, $pretty_print = true)
    {
        $argument = "<pre>" . print_r($argument, $pretty_print) . "</pre>";
        return $argument;
    }

    //~~ New functions
    public function ptsc_currency_info()
    {
        global $wpdb;
        $ptsc_install = new PTSC_INSTALL();
        $c_id = get_option("ptsc_default_currency");
        if ($c_id == "0") {
            $Q = "SELECT * FROM `" . $ptsc_install->get_table_name("currencies") . "`WHERE  `default` = 1";
            $row = $wpdb->get_row($Q, ARRAY_A);
        } else {
            $Q = "SELECT * FROM `" . $ptsc_install->get_table_name("currencies") . "`WHERE  c_id = " . $c_id;
            $row = $wpdb->get_row($Q, ARRAY_A);
        }
        $currency = [
            /*"prefix" => get_option("ptsc_default_currency_symbol"),
            "suffix" => get_option("ptsc_default_currency_suffix"),*/
            "c_id" => $row["c_id"],
            "prefix" => $row["prefix"],
            "suffix" => $row["suffix"]
        ];
        return $currency;
    }

    public function ptsc_currency_info_combo($c_id)
    {
        global $wpdb;
        $ptsc_install = new PTSC_INSTALL();
        if ($c_id == "") {
            $Q = "SELECT * FROM `" . $ptsc_install->get_table_name("currencies") . "`WHERE  `default` = 1";
            $row = $wpdb->get_row($Q, ARRAY_A);
        } else {
            $Q = "SELECT * FROM `" . $ptsc_install->get_table_name("currencies") . "`WHERE  c_id = " . $c_id;
            $row = $wpdb->get_row($Q, ARRAY_A);
        }
        $currency = [
            /*"prefix" => get_option("ptsc_default_currency_symbol"),
            "suffix" => get_option("ptsc_default_currency_suffix"),*/
            "c_id" => $row["c_id"],
            "prefix" => $row["prefix"],
            "suffix" => $row["suffix"]
        ];
        return $currency;
    }

    function process_price($price, $decimal_sperator = "na")
    {
        if ($decimal_sperator == "na") {
            // get default decimal separator
            $decimal_sperator = get_option("ptsc_decimal_separator");
        }
        if ($decimal_sperator == "") {
            $decimal_sperator = ".";
        }
        $price = strip_tags($price);
        $totay = explode($decimal_sperator, $price);
        $out["amount"] = $totay[0];
        $out["fraction"] = isset($totay[1]) ? $totay[1] : "";

        return $out;
    }


    public function ptsc_order_combo_function($atts, $url, $content = null)
    {

        $ptsc_install = new ptsc_install();
        $html_template = "";
        extract(shortcode_atts([
            'currency' => '0',
            'id' => '',
            'button_text' => '',
            'product_id' => '0',
            'show_discount' => '',
            'template_name' => '',
            'button_class' => 'ptsc-btn ptsc_order_button'
        ], $atts));

        $template_name = substr(strrchr($template_name, '/'), 1);
        $combo_class = '';
        if ($id == NULL || $id == "") {
            $product_id = $product_id;
        } else {
            $group = $this->ptsc_get_group_full($id);
            $product_id = $group["plans"]["0"]["product_id"];
        }
        //$price_tmp = $this->ptsc_break_price( $group, $group["product_id"], $group["billingcycle"] );

        $decimal = get_option("ptsc_decimals");
        if (!is_numeric($decimal)) {
            $decimal = "0";
        }
        $currency_info = $this->ptsc_currency_info();

        if ($id == NULL || $id == "") {
            $showdiscount = $show_discount;
        } else {
            $showdiscount = $group["show_discount"];
        }
        $discount_type = "monthly";
        //$showbutton = $show_button;
        //$buttontext = $button_text;


# Getting WordPress DB variable for communicating with DB.
        global $wpdb;
        $smarty_array = [];

# Getting currency symbol
        $suffcursymbol = "";
        $prefcursymbol = "";
        //if (strtolower($prefix) == "yes") {
        $prefcursymbol = $currency_info["prefix"];
        //}
        //if (strtolower($suffix) == "yes") {
        $suffcursymbol = $currency_info["suffix"];
        //}

        /*
         * if billing cycles are provided, turn them in array and fetch billing details of only those
         */

# Getting data from DB.
        $billingcycles = ["monthly", "quarterly", "semiannually", "annually", "biennially", "triennially"];

        $currency = $this->ptsc_currency_info();
        $c_id = $currency["c_id"];
        if (is_array($billingcycles)) {
            $billingcycles = trim(implode(",", $billingcycles));
        }
        if (trim($billingcycles) <> "") {
            # Setting up billing cycles
            $billingcycles = explode(",", $billingcycles);
            $billingcycles = array_map('trim', $billingcycles);
            $billingcycles = array_map('strtolower', $billingcycles);
            //$Q = "SELECT `pay_type` FROM `" . $ptsc_install->get_table_name("products") ;
            $Q = "SELECT `pay_type`," . implode(",", $billingcycles) . " FROM `" . $ptsc_install->get_table_name("pricings") . "` pri,
        `" . $ptsc_install->get_table_name("products") . "` prd WHERE  prd.product_id=pri.relid";
        } else {
            $Q = "SELECT prd.`pay_type`,pri.`triennially`,pri.`biennially`,pri.`annually`,pri.`semiannually`,pri.`quarterly`,pri.`monthly` FROM `" . $ptsc_install->get_table_name("pricings") . "` pri,
        `" . $ptsc_install->get_table_name("products") . "` prd WHERE  prd.product_id=pri.relid";
        }
        if (isset($product_id)) {
            $Q .= " AND `relid`=" . $product_id;
            //$Q .= "` WHERE `product_id`=" . $product_id;
        }

        $Q .= " AND `currency`=" . $c_id;

        $row = $wpdb->get_row($Q, ARRAY_A);
        /*echo "<pre>";
        print_r ($row);
        echo "</pre>";*/

# Checking that provided ID is valid
        if ($row === false || !is_array($row)) {
            return esc_html_x('Invalid ID', 'ptsc');
        }

# Generating string for output
        $action_url = get_option("order_url");
        /*if ($params <> "") {
            $action_url .= "&" . $params;
        }*/
        $string = "<!--ptsc-combo-start-->";
        $string .= "<form action='" . $action_url . "'>\n";

## Checking/Adding parameters if found in URL
        $params = parse_url($action_url);
        if (!isset($params["query"])) {
            $params["query"] = "";
        }
        if ($params["query"] <> "") {
            parse_str($params["query"], $params);
            foreach ($params as $key => $val) {
                $string .= "<input type=\"hidden\" value=\"{$val}\" name=\"{$key}\">\n";
            }
        }

        $string .= "<input type=\"hidden\" value=\"add\" name=\"a\">    
    <input type=\"hidden\" value=\"{$id}\" name=\"pid\"> 
    <select name=\"billingcycle\" class=\"{$combo_class}\">\n";
        if (get_option("show_trailing_zeros") == "yes") {
            $CurrencyFunction = "number_format";
        } else {
            $CurrencyFunction = "round";
        }
        if (!isset($row["monthly"])) {
            $row["monthly"] = "0";
        }

        $decimal_sperator = get_option("ptsc_decimal_separator");
        //$decimal_sperator = $WHMPress->get_currency_decimal_separator($currency);

        if ($row["pay_type"] == "onetime") {
            $process_price = $this->process_price($row["monthly"]);
            $string .= "<option value=\"\">{$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol} " . __("One Time", "ptsc") . "</option>\n";
        } else if ($row["monthly"] > 0) {
            if (is_array($billingcycles) && in_array("monthly", $billingcycles)) {
                $process_price = $this->process_price($row["monthly"]);
                if ($row["pay_type"] == "onetime") {
                    $string .= "<option value=\"monthly\">{$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                } else {
                    $string .= "<option value=\"monthly\">" . __("1 Month", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["monthly"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "monthly",
                    "pay_type" => $row["pay_type"]
                ];
            } else if ((strtolower($discount_type) == "yearly" || "annually" == strtolower($discount_type))) {
                $process_price = $this->process_price($row["monthly"]);
                if ($row["pay_type"] == "onetime") {
                    $string .= "<option value=\"monthly\">{$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                } else {
                    $string .= "<option value=\"monthly\">" . esc_html_x("1 Month", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["monthly"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "monthly",
                    "pay_type" => $row["pay_type"]
                ];
            } else if (strtolower($discount_type) == "monthly") {
                $process_price = $this->process_price($row["monthly"]);
                if ($row["pay_type"] == "onetime") {
                    $string .= "<option value=\"monthly\">{$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                } else {
                    $string .= "<option value=\"monthly\">" . esc_html_x("1 Month", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["monthly"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "monthly",
                    "pay_type" => $row["pay_type"]
                ];
            }
        }


        if (!isset($row["quarterly"])) {
            $row["quarterly"] = "0";
        }
        if ($row["quarterly"] > 0 && $row["pay_type"] <> "onetime") {
            if (strtolower($showdiscount) == "percentage") {
                if ($row["monthly"] > 0) {
                    $per = round(100 - ($row["quarterly"] / ($row["monthly"] * 3) * 100), 0);
                } else {
                    $per = "";
                }
            } else if (strtolower($showdiscount) == "amount") {
                if ($row["monthly"] > 0) {
                    $amount = ($row["quarterly"] - $row["monthly"]);
                } else {
                    $amount = "";
                }
            }
            if (is_array($billingcycles) && in_array("quarterly", $billingcycles)) {
                $process_price = $this->process_price($row["quarterly"]);

                $string .= "<option value=\"quarterly\">" . esc_html_x('3 Months', 'ptsc') . "- {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";

                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                } else if (strtolower($showdiscount) == "amount" && $amount <> "") {
                    $string .= " " . esc_html_x("Save", "amount", "ptsc") . " {$prefcursymbol}" . "{$amount}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["quarterly"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "quarterly",
                    "pay_type" => $row["pay_type"]
                ];
            } else if (strtolower($discount_type) == "yearly") {
                $process_price = $this->process_price($row["quarterly"]);

                $string .= "<option value='quarterly'>" . esc_html_x('3 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["quarterly"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "quarterly",
                ];
            } else {
                $process_price = $this->process_price($row["quarterly"]);
                $monthly = $CurrencyFunction($row["quarterly"] / 3, $decimal);
                $string .= "<option value=\"quarterly\">" . esc_html_x('3 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol} @ {$monthly}/" . __("mo", "ptsc") . "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["quarterly"], $decimal),
                    "discount" => $monthly,
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "quarterly",
                ];
            }
        }

        if (!isset($row["semiannually"])) {
            $row["semiannually"] = "0";
        }
        if ($row["semiannually"] > 0 && $row["pay_type"] <> "onetime") {
            if (strtolower($showdiscount) == "percentage") {
                if ($row["monthly"] > 0) {
                    $per = round(100 - ($row["semiannually"] / ($row["monthly"] * 6)), 0);
                } else if ($row["quarterly"] > 0) {
                    $per = round(100 - ($row["semiannually"] / ($row["quarterly"] * 2)), 0);
                } else {
                    $per = "";
                }
            } else if (strtolower($showdiscount) == "amount") {
                if ($row["monthly"] > 0) {
                    $amount = ($row["semiannually"] - $row["monthly"]);
                } else if ($row["quarterly"] > 0) {
                    $amount = ($row["semiannually"] - $row["quarterly"]);
                } else {
                    $amount = "";
                }
            }
            if (is_array($billingcycles) && in_array("semiannually", $billingcycles)) {
                $process_price = $this->process_price($row["semiannually"]);
                $string .= "<option value=\"semiannually\">" . esc_html_x("6 Months", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                } else if (strtolower($showdiscount) == "amount" && $amount <> "") {
                    $string .= " " . esc_html_x("Save", "amount", "ptsc") . " {$prefcursymbol}" . "{$amount}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["semiannually"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "semiannually",
                ];
            } else if (strtolower($discount_type) == "yearly") {
                $process_price = $this->process_price($row["semiannually"]);
                $string .= "<option value=\"semiannually\">" . __("6 Months", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["semiannually"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "semiannually",
                ];
            } else {
                $process_price = $this->process_price($row["semiannually"]);
                $monthly = $CurrencyFunction($row["semiannually"] / 6, $decimal);
                $string .= "<option value=\"semiannually\">" . esc_html_x("6 Months", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol} @ {$monthly}/" . __("mo", "ptsc") . "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["semiannually"], $decimal),
                    "discount" => $monthly,
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "semiannually",
                ];
            }
        }

        if (!isset($row["annually"])) {
            $row["annually"] = "0";
        }
        if ($row["annually"] > 0 && $row["pay_type"] <> "onetime") {
            if (strtolower($showdiscount) == "percentage") {
                if ($row["monthly"] > 0) {
                    $per = round(100 - ($row["annually"] / ($row["monthly"] * 12) * 100), 0);
                } else if ($row["quarterly"] > 0) {
                    $per = round(100 - ($row["annually"] / ($row["quarterly"] * 4) * 100), 0);
                } else if ($row["semiannually"] > 0) {
                    $per = round(100 - ($row["annually"] / ($row["semiannually"] * 2) * 100), 0);
                } else {
                    $per = "0";
                }
            } else if (strtolower($showdiscount) == "amount") {
                if ($row["monthly"] > 0) {
                    $amount = ($row["annually"] - $row["monthly"]);
                } else if ($row["quarterly"] > 0) {
                    $amount = ($row["annually"] - $row["quarterly"]);
                } else if ($row["semiannually"] > 0) {
                    $amount = ($row["annually"] - $row["semiannually"]);
                } else {
                    $amount = "0";
                }
            }

            if (is_array($billingcycles) && in_array("annually", $billingcycles)) {
                $process_price = $this->process_price($row["annually"]);
                $monthly = $CurrencyFunction($row["annually"] / 12, $decimal);
                $string .= "<option value=\"annually\">" . esc_html_x('12 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                } else if (strtolower($showdiscount) == "amount" && $amount <> "") {
                    $string .= " " . esc_html_x("Save", "amount", "ptsc") . " {$prefcursymbol}" . "{$amount}</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["annually"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "annually",
                ];
            } else if (strtolower($discount_type) == "yearly") {
                $process_price = $this->process_price($row["annually"]);
                $string .= "<option value=\"annually\">" . __("1 Year", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                }

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["annually"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "annually",
                ];
            } else if (strtolower($discount_type) == "monthly") {
                $monthly = $CurrencyFunction($row["annually"] / 12, $decimal);
                $process_price = $this->process_price($row["annually"]);
                $string .= "<option value=\"annually\">" . esc_html_x('12 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage") {
                    $string .= " @ {$monthly}/" . esc_html_x("mo", "ptsc");
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["annually"], $decimal),
                    "discount" => $monthly,
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "annually",
                ];
            }
        }

        if (!isset($row["biennially"])) {
            $row["biennially"] = "0";
        }
        if ($row["biennially"] > 0 && $row["pay_type"] <> "onetime") {
            if (strtolower($showdiscount) == "percentage") {
                if ($row["monthly"] > 0) {
                    $per = round(100 - ($row["biennially"] / ($row["monthly"] * 24) * 100), 0);
                } else if ($row["quarterly"] > 0) {
                    $per = round(100 - ($row["biennially"] / ($row["quarterly"] * 8) * 100), 0);
                } else if ($row["semiannually"] > 0) {
                    $per = round(100 - ($row["biennially"] / ($row["semiannually"] * 4) * 100), 0);
                } else if ($row["annually"] > 0) {
                    $per = round(100 - ($row["biennially"] / ($row["annually"] * 2) * 100), 0);
                } else {
                    $per = "";
                }
            } else if (strtolower($showdiscount) == "amount") {
                if ($row["monthly"] > 0) {
                    $amount = ($row["biennially"] - $row["monthly"]);
                } else if ($row["quarterly"] > 0) {
                    $amount = ($row["biennially"] - $row["quarterly"]);
                } else if ($row["semiannually"] > 0) {
                    $amount = ($row["biennially"] - $row["semiannually"]);
                } else if ($row["annually"] > 0) {
                    $amount = ($row["biennially"] - $row["annually"]);
                } else {
                    $amount = "";
                }
            }
            if (is_array($billingcycles) && in_array("biennially", $billingcycles)) {
                $process_price = $this->process_price($row["biennially"]);
                $monthly = $CurrencyFunction($row["biennially"] / 24, $decimal);
                $string .= "<option value=\"biennially\">" . esc_html_x('24 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                } else if (strtolower($showdiscount) == "amount" && $amount <> "") {
                    $string .= " " . esc_html_x("Save", "amount", "ptsc") . " {$prefcursymbol}" . "{$amount}</option>\n";
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["biennially"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "biennially",
                ];
            } else if (strtolower($discount_type) == "yearly") {

                $process_price = $this->process_price($row["biennially"]);
                $string .= "<option value=\"biennially\">" . __("2 Years", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";

                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%";
                    esc_html__("", "", "");
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["biennially"], $decimal),
                    "discount" => "10%",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "biennially",
                ];
            } else {
                $monthly = $CurrencyFunction($row["biennially"] / 24, $decimal);
                $process_price = $this->process_price($row["biennially"]);
                $string .= "<option value=\"biennially\">" . esc_html_x('24 Months', 'ptsc') . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage") {
                    $string .= " @ {$monthly}/" . esc_html_x("mo", "ptsc");
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["biennially"], $decimal),
                    "discount" => $monthly,
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "biennially",
                ];
            }
        }

        if (!isset($row["triennially"])) {
            $row["triennially"] = "0";
        }
        if ($row["triennially"] > 0 && $row["pay_type"] <> "onetime") {
            if (strtolower($showdiscount) == "percentage") {
                if ($row["monthly"] > 0) {
                    $per = round(100 - ($row["triennially"] / ($row["monthly"] * 36) * 100), 0);
                } else if ($row["quarterly"] > 0) {
                    $per = round(100 - ($row["triennially"] / ($row["quarterly"] * 12) * 100), 0);
                } else if ($row["semiannually"] > 0) {
                    $per = round(100 - ($row["triennially"] / ($row["semiannually"] * 6) * 100), 0);
                } else if ($row["annually"] > 0) {
                    $per = round(100 - ($row["triennially"] / ($row["annually"] * 3) * 100), 0);
                } else {
                    $per = "";
                }
            } else if (strtolower($showdiscount) == "amount") {
                if ($row["monthly"] > 0) {
                    $amount = ($row["triennially"] - $row["monthly"]);
                } else if ($row["quarterly"] > 0) {
                    $amount = ($row["triennially"] - $row["quarterly"]);
                } else if ($row["semiannually"] > 0) {
                    $amount = ($row["triennially"] - $row["semiannually"]);
                } else if ($row["annually"] > 0) {
                    $amount = ($row["triennially"] - $row["annually"]);
                } else {
                    $amount = "";
                }
            }

            if (is_array($billingcycles) && in_array("triennially", $billingcycles)) {
                $monthly = $CurrencyFunction($row["triennially"] / 36, $decimal);
                $process_price = $this->process_price($row["triennially"]);
                $string .= "<option value=\"triennially\">" . esc_html_x("36 Months", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%</option>\n";
                } else if (strtolower($showdiscount) == "amount" && $amount <> "") {
                    $string .= " " . esc_html_x("Save", "amount", "ptsc") . " {$prefcursymbol}" . "{$amount}</option>\n";
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["triennially"], $decimal),
                    "discount" => "",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "triennially",
                ];
            } else if (strtolower($discount_type) == "yearly") {

                $process_price = $this->process_price($row["triennially"]);
                $string .= "<option value=\"triennially\"> " . esc_html_x("3 Years", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . "{$suffcursymbol}";
                if (strtolower($showdiscount) == "percentage" && $per <> "") {
                    $string .= " " . esc_html_x("Save", "discount", "ptsc") . " {$per}%";
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["triennially"], $decimal),
                    "discount" => "20%",
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "triennially",
                ];
            } else {
                $monthly = $CurrencyFunction($row["triennially"] / 36, $decimal);

                $process_price = $this->process_price($row["triennially"]);
                $string .= "<option value=\"triennially\">" . esc_html_x("36 Months", "ptsc") . " - {$prefcursymbol}" . ($process_price["amount"] . $decimal_sperator . $process_price["fraction"]) . $suffcursymbol;
                if (strtolower($showdiscount) == "percentage") {
                    $string .= " @ {$monthly}/" . esc_html_x("mo", "ptsc");
                }
                $string .= "</option>\n";

                $smarty_array[] = [
                    "prefix" => $prefcursymbol,
                    "suffix" => $suffcursymbol,
                    "product_price" => $CurrencyFunction($row["triennially"], $decimal),
                    "discount" => $monthly,
                    "amount" => $process_price["amount"],
                    "fraction" => $process_price["fraction"],
                    "decimal" => $decimal_sperator,
                    "duration" => "triennially",
                ];
            }
        }

        if ($html_template == "") {
            if ($id == NULL || $id == "") {
                $html_template = $template_name;
                if ($html_template == trim("")) {
                    $html_template = "advance-01-mod.tpl";
                }
            } else {
                $html_template = $group['template_file'];
                if ($html_template == trim("")) {
                    $html_template = "advance-01-mod.tpl";
                }
            }

        }

        $string .= "</select>\n";

#echo nl2br(htmlentities($string));
        //$button = "<button class=\"ptsc-btn ptsc_order_button\">{$group['button_text']}</button>";
        if ($id == NULL || $id == "") {
            ob_start();
            ?>
            <a type="button" class="ptsc-btn ptsc_order_button"
               href="<?php echo $url ?>"><?php echo $button_text ?></a>
            <?php
            $button = ob_get_clean();
        } else {
            ob_start();
            ?>
            <a type="button" class="ptsc-btn ptsc_order_button"
               href="<?php echo $group["plans"][0]["order_url"] ?>"><?php echo $group["button_text"] ?></a>
            <?php
            $button = ob_get_clean();
        }
        $rows = "";
        if ($rows == "2") {
            $string .= "<br />";
        }

        $string .= $button;
        $string .= "</form>";
#echo $html_template."<br />";
        if (is_file($html_template)) {
            #echo "Yes<br />";
            $vars = [
                "product_order_combo" => $string,
                "product_order_button" => $button,
                //"order_button_text" => $buttontext,
                "data" => $smarty_array,
                "pid" => $id,
                "product_id" => $id,
                "currency_id" => $currency_info["c_id"],
                "action_url" => $action_url,
            ];

            /*# Getting custom fields and adding in output
            $TemplateArray = $WHMPress->get_template_array("ptsc_order_combo");
            foreach ($TemplateArray as $custom_field) {
                $vars[$custom_field] = isset($atts[$custom_field]) ? $atts[$custom_field] : "";
            }*/

            $OutputString = $this->ptsc_smarty_template($html_template, $vars);
        } else {
            # Returning output string including HTML wrapper with ID
            $OutputString = "<div class='ptsc ptsc_order_combo'>" . $string . "</div>";
        }
        return $OutputString;
    }


    public function get_shortcode_parameters($shortcode)
    {

        /**
         * Explanation about parameters
         *
         * vc_hide = template_file, parameter will not show in VC editor if tempalte file exists.
         * "hide_in_editor"=>"yes" will hide from editor's combo list.
         */
        switch ($shortcode) {

            /*
			* --------------price_table------------------
			*/
            case "ptsc_pricing_table":
                global $wpdb;
                global $html_file;
                $result[] = "--Select widget id--";
                $name = 'single pricing table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }
                /*foreach ($All_custom_fields as $custom_field)
                {
                    $param_name[] = $custom_field["param_name"];
                    $heading[] = $custom_field["param_name"];
                    $types[] = $custom_field["type"];
                    $value[] = $custom_field["value"];
                    $description[] = $custom_field["description"];
                }*/
                if (!class_exists('WooCommerce')) {
                    $vendor_option = esc_html__("WooCommerce (not istalled)", "ptsc");
                } else {
                    $vendor_option = esc_html__("WooCommerce", "ptsc");
                }
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("ptsc pricing table", "ptsc"),
                    ),

                    /*"shortcode_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Visual Editor", "ptsc") => "vc",
                            esc_html__("Plugin options in WP admin", "ptsc") => "shortcpde_option",
                        ),
                        "heading" => esc_html__("To Set Shortcode Options I will use", "ptsc"),
                        "description" => esc_html__("Visual Editor: You set all options using WP Bakery Visual editor, Avada page builder or using our button in classic editor.
                        With Plugin options in WP: you can make the shortcode WP-admin > PTSC, and then simply select only ID here. Or even do not use this interface at all and copy paste the shortcode from admin.", "ptsc"),
                    ),*/

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),

                    /*"product_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Table data in WP admin", "ptsc") => "table_data",
                            $vendor_option => "WC",
                        ),
                        "heading" => esc_html__("Choose Product From", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"WC_prod_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Product Id", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),
                    ),*/

                    /*"description_option" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("WooCommerce product custom field description", "ptsc") => "wc_custom_desc",
                            esc_html__("WooCommerce product description", "ptsc") => "wc_desc",
                        ),
                        "heading" => esc_html__("I will pick description from", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "woocommercepid" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select WooCommerce Product Id", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "product_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Table", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                        "description" => esc_html__("You can create table data in PTSC > Add Table Data", "ptsc"),
                    ),

                    "html_template" => array(
                        "vc_type" => "dropdown",
                        "heading" => "Select template File",
                        "value" => 'html_template_files',
                        "description" => "Select HTML template file",
                        "dependency" => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),*/


                    /*"image_url" => array(
                        "vc_type" => "textfield",
                        "heading" => "Enter Image URL",
                        "value"   => 'http://sajid.hostriplex.com/whmpress/wp-content/uploads/2018/01/plan02.jpg',
                        "description" => "URL for the image to display",
                        "dependency" =>  array(
                            'element' => 'html_template',
                            'value' => $html_file,
                        ),

                    ),*/
                    /*"image",
                    "my_custom_field",*/

                    /*"Image_URL" => array(
                        "type" => "textfield",
                        "value" => "",
                        "heading" => esc_html__("Enter Image URL", "ptsc"),
                        'dependency' => array(
                            'element' => 'html_template',
                            'value' => $html_file,
                        ),
                    ),*/

                    /*"button_text" => array(
                        "value" => "Buy Now",
                        "heading" => esc_html__("Button Text", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"billingcycle" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle",
                        "heading" => esc_html__("Primary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"billingcycle2" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle2",
                        "heading" => esc_html__("Secondary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"currency" => array(
                        "vc_type" => "currencies",
                        "heading" => esc_html__("Select currency", "ptsc"),

                    ),*/

                    //--------Section-------------
                    /*"section1" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Advance", "whmpress"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"featured" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Featured", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("Select Yes if you want to show the ribbon text in corner", "ptsc"),
                    ),

                    "featured_text" => array(
                        "value" => "Most Popular",
                        "heading" => esc_html__("Highlighted text for featured plan", "whmpress"),
                        "description" => esc_html__("Where supported by selected template.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'featured',
                            'value' => array('yes'),
                        ),
                    ),

                    "process_description" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Process Description", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("Select Yes, if you want to show description in key: value pairs. Or if you want to use tool tips.", "ptsc"),
                    ),

                    "Description_separator" => array(
                        "value" => ":",
                        "heading" => esc_html__("Description separator", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "enable_tooltips" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Enable Tooltip", "ptsc"),
                        "description" => esc_html__("Tooltips are defined in PTSC > Tool tips.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/


                    /*"show_description_icon" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Icon", "whmpress"),
                        "description" => esc_html__("Weather to show Description Icon or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_description_tooltip" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Tooltip", "ptsc"),
                        "description" => esc_html__("Weather to show Description Tooltip or not.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/


                    /*"show_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show order combo", "whmpress"),
                        "description" => esc_html__("Weather to show billingcycle combo to select duration.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_button" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show order button", "whmpress"),
                        "description" => esc_html__("Show Order Button > Weather to show order button or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"override_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Override Order URL", "whmpress"),
                        "description" => esc_html__("Use if you want to change order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"append_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Append Order URL", "whmpress"),
                        "description" => esc_html__("If you want to append some thing to order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Discount", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/

                    /*"show_order_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show Order Combo", "ptsc"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),


                    "show_discount" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("No", "ptsc") => "no",
                            esc_html__("Percentage", "ptsc") => "percentage",
                            esc_html__("Amount", "ptsc") => "amount",
                        ),
                        "heading" => esc_html__("Show discount", "ptsc"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'show_order_combo',
                            'value' => array('yes'),
                        ),

                    ),*/


                    /*"convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Convert to Monthly", "whmpress"),
                        "description" => esc_html__("Convert price to sudo monthly price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"explain_convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Explain Sudo monthly Price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'convert_monthly',
                            'value' => array('yes'),
                        ),

                    ),*/


                    //--------Section-------------
                    /*"section_single_pricing_table" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Single Pricing Table options", "ptsc"),
                        "classes" => "ptsc-custom-label",
                        "style" => "",
                    ),*/

                    /*"custom_text" => array(
                        "value" => "",
                        "heading" => esc_html__("Custom Text", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("If you want to show additional text near price display", "ptsc"),
                    ),

                    "featured_rows" => array(
                        "vc_type" => "",
                        "value" => "50",
                        "heading" => esc_html__("Number of rows to show", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("if you have long table data, you can strip using this.", "ptsc")
                    ),*/

                    /*"Hide_table" => array(
                        "value" => "0",
                        "heading" => esc_html__("Hide table group below", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"id" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("ID (should remain Null)", "ptsc"),
                        "description" => esc_html__("This fied should remain Null"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/
                    /*"section2" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Colors", "ptsc"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),
                    "primary_color" => array(
                        "vc_type" => "colorpicker",
                        "heading" => esc_html__("Primary Color", "ptsc"),
                        "group" => esc_html__("Colors", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),

                    "secondary_color" => array(
                        "vc_type" => "colorpicker",
                        "heading" => esc_html__("Secondary Color", "ptsc"),
                        "group" => esc_html__("Colors", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),*/

                );
                break;
            case "ptsc_comparison_table":

                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'comparison table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }
                if (!class_exists('WooCommerce')) {
                    $vendor_option = esc_html__("WooCommerce (not istalled)", "ptsc");
                } else {
                    $vendor_option = esc_html__("WooCommerce", "ptsc");
                }

                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Comparison Table", "ptsc"),
                    ),

                    /*"shortcode_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Plugin options in WP admin", "ptsc") => "shortcpde_option",
                        ),
                        "heading" => esc_html__("To Set Shortcode Options I will use", "ptsc"),
                        "description" => esc_html__("Visual Editor: You set all options using WP Bakery Visual editor, Avada page builder or using our button in classic editor.
                        With Plugin options in WP: you can make the shortcode WP-admin > PTSC, and then simply select only ID here. Or even do not use this interface at all and copy paste the shortcode from admin.", "ptsc"),
                    ),*/
                    /*"product_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Table data in WP admin", "ptsc") => "table_data",
                            $vendor_option => "WC",
                        ),
                        "heading" => esc_html__("Choose Product From", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),

                    /*"product_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Product Ids", "ptsc"),
                        "description" => esc_html__("You can create table data in PTSC > Add Table Data, Enter comma separated productd Ids"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                    ),

                    "woocommerce_multiple_pids" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select WooCommerce Product Id", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "html_template" => array(
                        "vc_type" => "dropdown",
                        "heading" => "Select template File",
                        "value" => 'html_template_files',
                        "description" => "Select HTML template file",
                        "dependency" => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),

                    "image",

                    "billingcycle" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle",
                        "heading" => esc_html__("Primary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "billingcycle2" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle2",
                        "heading" => esc_html__("Secondary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"currency" => array(
                        "vc_type" => "currencies",
                        "heading" => esc_html__("Select currency", "ptsc"),

                    ),*/

                    //--------Section-------------
                    /*"section1" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Advance", "whmpress"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "featured_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Id for Featured Product", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                        "description" => esc_html__("Select Id if you want to show the ribbon text in corner", "ptsc"),
                    ),
                    "woocommerce_featured_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Id for Featured Product", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),
                        "description" => esc_html__("Select Id if you want to show the ribbon text in corner", "ptsc"),
                    ),

                    "Description_separator" => array(
                        "value" => ":",
                        "heading" => esc_html__("Description separator", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "enable_tooltips" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Enable Tooltip", "ptsc"),
                        "description" => esc_html__("Tooltips are defined in PTSC > Tool tips.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),


                    "featured_text" => array(
                        "value" => "Most Popular",
                        "heading" => esc_html__("Highlighted text for featured plan", "whmpress"),
                        "description" => esc_html__("Where supported by selected template.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"show_description_icon" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Icon", "whmpress"),
                        "description" => esc_html__("Weather to show Description Icon or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_description_tooltip" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Tooltip", "ptsc"),
                        "description" => esc_html__("Weather to show Description Tooltip or not.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/


                    /*"show_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show order combo", "whmpress"),
                        "description" => esc_html__("Weather to show billingcycle combo to select duration.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_button" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show order button", "whmpress"),
                        "description" => esc_html__("Show Order Button > Weather to show order button or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"button_text" => array(
                        "value" => "Buy Now",
                        "heading" => esc_html__("Button Text", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"override_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Override Order URL", "whmpress"),
                        "description" => esc_html__("Use if you want to change order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"append_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Append Order URL", "whmpress"),
                        "description" => esc_html__("If you want to append some thing to order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Discount", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("No", "ptsc") => "no",
                            esc_html__("Percentage", "ptsc") => "percentage",
                            esc_html__("Amount", "ptsc") => "amount",
                        ),
                        "heading" => esc_html__("Show discount", "ptsc"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),*/
                    /*'dependency' => array(
                        'element' => 'show_discount',
                        'value' => array('yes'),
                    ),*/

                    /* ),*/

                    /*"convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Convert to Monthly", "whmpress"),
                        "description" => esc_html__("Convert price to sudo monthly price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"explain_convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Explain Sudo monthly Price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'convert_monthly',
                            'value' => array('yes'),
                        ),

                    ),*/


                    //--------Section-------------
                    /* "section_comparison_table" => array(
                         "vc_type" => "label",
                         "heading" => esc_html__("Comparison Table options", "ptsc"),
                         "classes" => "ptsc-custom-label",
                         "style" => "",
                     ),*/

                    /*"show_yes_no_icon" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Convert Yes/No to icons", "ptsc"),
                        "description" => esc_html__("Weather to replace Yes/No text to Icon.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "convert_yes_with" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("Icon to convert Yes", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "convert_no_with" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("Icon to convert No", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"toggle_stle" => array(
                        "vc_type" => "toggle_stle",
                        "heading" => esc_html__("Price Toggle Style", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"featured_rows" => array(
                        "vc_type" => "",
                        "value" => "50",
                        "heading" => esc_html__("Number of rows to show", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("if you have long table data, you can strip using this.", "ptsc")
                    ),*/

                    /*"Hide_table" => array(
                        "value" => "0",
                        "heading" => esc_html__("Hide table group below", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"id" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("ID (should remain Null)", "ptsc"),
                        "description" => esc_html__("This fied should remain Null"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                );
                break;
            case "ptsc_order_slider":

                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'pricing slider';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }
                if (!class_exists('WooCommerce')) {
                    $vendor_option = esc_html__("WooCommerce (not istalled)", "ptsc");
                } else {
                    $vendor_option = esc_html__("WooCommerce", "ptsc");
                }
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Pricing Slider", "ptsc"),
                    ),

                    /*"shortcode_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Plugin options in WP admin", "ptsc") => "shortcpde_option",
                        ),
                        "heading" => esc_html__("To set shortcode options i will use", "ptsc"),
                        "description" => esc_html__("Visual Editor: You set all options using WP Bakery Visual editor, Avada page builder or using our button in classic editor.
                        With Plugin options in WP: you can make the shortcode WP-admin > PTSC, and then simply select only ID here. Or even do not use this interface at all and copy paste the shortcode from admin.", "ptsc"),
                    ),*/

                    /*"product_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Table data in WP admin", "ptsc") => "table_data",
                            $vendor_option => "WC",
                        ),
                        "heading" => esc_html__("Choose Product From", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),

                    /*"product_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Product Ids", "ptsc"),
                        "description" => esc_html__("You can create table data in PTSC > Add Table Data, Enter comma separated productd Ids"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                    ),

                    "description_option" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("WooCommerce product custom field description", "ptsc") => "wc_custom_desc",
                            esc_html__("WooCommerce product description", "ptsc") => "wc_desc",
                        ),
                        "heading" => esc_html__("I will pick description from", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "woocommerce_multiple_pids" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select WooCommerce Product Id", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "html_template" => array(
                        "vc_type" => "dropdown",
                        "heading" => "Select template File",
                        "value" => 'html_template_files',
                        "description" => "Select HTML template file",
                        "dependency" => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),

                    "image",

                    "billingcycle" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle",
                        "heading" => esc_html__("Primary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "billingcycle2" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle2",
                        "heading" => esc_html__("Secondary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"currency" => array(
                        "vc_type" => "currencies",
                        "heading" => esc_html__("Select currency", "ptsc"),

                    ),*/

                    //--------Section-------------
                    /*"section1" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Advance", "whmpress"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"featured_id" => array(
                        "vc_type" => "single_productid",
                        "heading" => esc_html__("Select Id for Featured Product", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("Select Id if you want to show the ribbon text in corner", "ptsc"),
                    ),*/
                    /*"Description_separator" => array(
                        "value" => ":",
                        "heading" => esc_html__("Description separator", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"process_description" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Process Description", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("Select Yes, if you want to show description in key: value pairs. Or if you want to use tool tips.", "ptsc"),
                    ),

                    "enable_tooltips" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Enable Tooltip", "ptsc"),
                        "description" => esc_html__("Tooltips are defined in PTSC > Tooltips.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/


                    /*"featured_text" => array(
                        "value" => "Most Popular",
                        "heading" => esc_html__("Highlighted text for featured plan", "whmpress"),
                        "description" => esc_html__("Where supported by selected template.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"show_description_icon" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Icon", "whmpress"),
                        "description" => esc_html__("Weather to show Description Icon or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_description_tooltip" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Tooltip", "ptsc"),
                        "description" => esc_html__("Weather to show Description Tooltip or not.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/


                    /*"show_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show order combo", "whmpress"),
                        "description" => esc_html__("Weather to show billingcycle combo to select duration.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_button" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show order button", "whmpress"),
                        "description" => esc_html__("Show Order Button > Weather to show order button or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"button_text" => array(
                        "value" => "Buy Now",
                        "heading" => esc_html__("Button Text", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"override_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Override Order URL", "whmpress"),
                        "description" => esc_html__("Use if you want to change order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"append_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Append Order URL", "whmpress"),
                        "description" => esc_html__("If you want to append some thing to order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Discount", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("No", "ptsc") => "no",
                            esc_html__("Percentage", "ptsc") => "percentage",
                            esc_html__("Amount", "ptsc") => "amount",
                        ),
                        "heading" => esc_html__("Show discount", "ptsc"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),*/
                    /*'dependency' => array(
                        'element' => 'show_discount',
                        'value' => array('yes'),
                    ),*/

                    /*),*/

                    /*"convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Convert to Monthly", "whmpress"),
                        "description" => esc_html__("Convert price to sudo monthly price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"explain_convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Explain Sudo monthly Price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'convert_monthly',
                            'value' => array('yes'),
                        ),

                    ),*/


                    //--------Section-------------
                    /*"section_pricing_slider" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Pricing Slider options", "ptsc"),
                        "classes" => "ptsc-custom-label",
                        "style" => "",
                    ),*/

                    /*"toggle_stle" => array(
                        "vc_type" => "toggle_stle",
                        "heading" => esc_html__("Price Toggle Style", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"featured_rows" => array(
                        "vc_type" => "",
                        "value" => "50",
                        "heading" => esc_html__("Number of rows to show", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("if you have long table data, you can strip using this.", "ptsc")
                    ),*/

                    /*"Hide_table" => array(
                        "value" => "0",
                        "heading" => esc_html__("Hide Slider below", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"id" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("ID (should remain Null)", "ptsc"),
                        "description" => esc_html__("This fied should remain Null"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                );
                break;
            case "ptsc_pricing_table_group":

                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'group pricing table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }
                if (!class_exists('WooCommerce')) {
                    $vendor_option = esc_html__("WooCommerce (not istalled)", "ptsc");
                } else {
                    $vendor_option = esc_html__("WooCommerce", "ptsc");
                }
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Pricing Table", "ptsc"),
                    ),

                    /*"shortcode_vendor" => array(

                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Visual Editor", "ptsc") => "vc",
                            esc_html__("Plugin options in WP admin", "ptsc") => "shortcpde_option",
                        ),
                        "heading" => esc_html__("To set shortcode options i will use", "ptsc"),
                        "description" => esc_html__("Visual Editor: You set all options using WP Bakery Visual editor, Avada page builder or using our button in classic editor.
                        With Plugin options in WP: you can make the shortcode WP-admin > PTSC, and then simply select only ID here. Or even do not use this interface at all and copy paste the shortcode from admin.", "ptsc"),
                    ),*/

                    /*"product_vendor" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Table data in WP admin", "ptsc") => "table_data",
                            $vendor_option => "WC",
                        ),
                        "heading" => esc_html__("Choose Product From", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),

                    /*"product_id" => array(
                        "vc_type" => "productids",
                        "heading" => esc_html__("Select Product Ids", "ptsc"),
                        "description" => esc_html__("You can create table data in PTSC > Add Table Data, Enter comma separated productd Ids"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                    ),

                    "description_option" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("WooCommerce product custom field description", "ptsc") => "wc_custom_desc",
                            esc_html__("WooCommerce product description", "ptsc") => "wc_desc",
                        ),
                        "heading" => esc_html__("I will pick description from", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "woocommerce_multiple_pids" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select WooCommerce Product Id", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),

                    ),

                    "html_template" => array(
                        "vc_type" => "dropdown",
                        "heading" => "Select template File",
                        "value" => 'html_template_files',
                        "description" => "Select HTML template file",
                        "dependency" => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),

                    ),

                    "my_custom_field",
                    "image",

                    "billingcycle" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle",
                        "heading" => esc_html__("Primary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "billingcycle2" => array(
                        "vc_type" => "dropdown",
                        "value" => "billing_cycle2",
                        "heading" => esc_html__("Secondary Billing cycle", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"currency" => array(
                        "vc_type" => "currencies",
                        "heading" => esc_html__("Select currency", "ptsc"),

                    ),*/

                    //--------Section-------------
                    /*"section1" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Advance", "whmpress"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "featured_id" => array(
                        "vc_type" => "single_productid",
                        "heading" => esc_html__("Select Id for Featured Product", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('table_data'),
                        ),
                        "description" => esc_html__("Select Id if you want to show the ribbon text in corner", "ptsc"),
                    ),

                    "woocommerce_featured_id" => array(
                        "vc_type" => "textfield",
                        "heading" => esc_html__("Select Id for Featured Product", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'product_vendor',
                            'value' => array('WC'),
                        ),
                        "description" => esc_html__("Select Id if you want to show the ribbon text in corner", "ptsc"),
                    ),

                    "process_description" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Process Description", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("Select Yes, if you want to show description in key: value pairs. Or if you want to use tool tips.", "ptsc"),
                    ),

                    "Description_separator" => array(
                        "value" => ":",
                        "heading" => esc_html__("Description separator", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "enable_tooltips" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Enable Tooltip", "ptsc"),
                        "description" => esc_html__("Tooltips are defined in PTSC > Tooltips.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),


                    "featured_text" => array(
                        "value" => "Most Popular",
                        "heading" => esc_html__("Highlighted text for featured plan", "whmpress"),
                        "description" => esc_html__("Where supported by selected template.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "custom_text" => array(
                        "value" => "",
                        "heading" => esc_html__("Custom Text", "whmpress"),
                        "description" => esc_html__("If you want to show additional text near price display.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"show_description_icon" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Icon", "whmpress"),
                        "description" => esc_html__("Weather to show Description Icon or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_description_tooltip" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Description Tooltip", "ptsc"),
                        "description" => esc_html__("Weather to show Description Tooltip or not.", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/


                    /*"show_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show order combo", "whmpress"),
                        "description" => esc_html__("Weather to show billingcycle combo to select duration.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_button" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show order button", "whmpress"),
                        "description" => esc_html__("Show Order Button > Weather to show order button or not.", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"button_text" => array(
                        "value" => "Buy Now",
                        "heading" => esc_html__("Button Text", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"override_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Override Order URL", "whmpress"),
                        "description" => esc_html__("Use if you want to change order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"append_order_url" => array(
                        "value" => "",
                        "heading" => esc_html__("Append Order URL", "whmpress"),
                        "description" => esc_html__("If you want to append some thing to order URL", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"show_discount" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show Discount", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                    ),*/

                    /* "show_discount" => array(
                         "vc_type" => "dropdown",
                         "value" => array(
                             esc_html__("No", "ptsc") => "no",
                             esc_html__("Percentage", "ptsc") => "percentage",
                             esc_html__("Amount", "ptsc") => "amount",
                         ),
                         "heading" => esc_html__("Show discount", "ptsc"),
                         "group" => esc_html__("Advance", "whmpress"),
                         'dependency' => array(
                             'element' => 'shortcode_vendor',
                             'value' => array('vc'),
                         ),*/
                    /*'dependency' => array(
                        'element' => 'show_discount',
                        'value' => array('yes'),
                    ),*/

                    /*),*/

                    /*"convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Convert to Monthly", "whmpress"),
                        "description" => esc_html__("Convert price to sudo monthly price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                    ),*/

                    /*"explain_convert_monthly" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Explain Sudo monthly Price", "whmpress"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'convert_monthly',
                            'value' => array('yes'),
                        ),

                    ),*/


                    //--------Section-------------
                    /*"section_group_pricing_table" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Group Pricing Table options", "ptsc"),
                        "classes" => "ptsc-custom-label",
                        "style" => "",
                    ),*/

                    /*"toggle_stle" => array(
                        "vc_type" => "toggle_stle",
                        "heading" => esc_html__("Price Toggle Style", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"enable_table_carousel" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Enable Table Carousel", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "featured_rows" => array(
                        "vc_type" => "",
                        "value" => "50",
                        "heading" => esc_html__("Number of rows to show", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                        "description" => esc_html__("if you have long table data, you can strip using this.", "ptsc")
                    ),

                    "show_order_combo" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Show Order Combo", "ptsc"),
                        "group" => esc_html__("Advance", "whmpress"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),


                    ),*/

                    /*"Hide_table" => array(
                        "value" => "0",
                        "heading" => esc_html__("Hide table group below", "ptsc"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/

                    /*"id" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("ID (should remain Null)", "ptsc"),
                        "description" => esc_html__("This fied should remain Null"),
                        "group" => esc_html__("Advance", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/
                    /*"section2" => array(
                        "vc_type" => "label",
                        "heading" => esc_html__("Colors", "ptsc"),
                        "classes" => "ptsc-custom-label",
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),
                    "primary_color" => array(
                        "vc_type" => "colorpicker",
                        "heading" => esc_html__("Primary Color", "ptsc"),
                        "group" => esc_html__("Colors", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),

                    "secondary_color" => array(
                        "vc_type" => "colorpicker",
                        "heading" => esc_html__("Secondary Color", "ptsc"),
                        "group" => esc_html__("Colors", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('vc'),
                        ),
                    ),*/


                );
                break;

            case "makli_carousel":
                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'carousel_table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }

                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Carousel Table", "ptsc"),
                    ),

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),
                );
                break;
            case "makli_jumbotron":
                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'jumbotron';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }

                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Jumbotron", "ptsc"),
                    ),

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),
                );


                break;
            case "makli_section":
                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'section_table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }

                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Section Table", "ptsc"),
                    ),

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),
                );


                break;
            case "makli_tabs":
                global $wpdb;
                $result[] = "--Select widget id--";
                $name = 'tabs_table';
                $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
                $id_array = $wpdb->get_results($Q, ARRAY_A);
                foreach ($id_array as $id) {
                    $result[] = $id["group_id"];
                }

                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Tabs Table", "ptsc"),
                    ),

                    "gid" => array(
                        "vc_type" => "dropdown",
                        "value" => $result,
                        "heading" => esc_html__("Select Widget", "ptsc"),
                        'dependency' => array(
                            'element' => 'shortcode_vendor',
                            'value' => array('shortcpde_option'),
                        ),
                        "description" => esc_html__("Widget Id from admin > Makli > Widgets", "ptsc"),
                    ),
                );


                break;
            case "ptsc_currency_combo":
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Currency Selector", "ptsc"),
                    ),

                    "image",

                    "prefix" => array(
                        "vc_type" => "yesno",
                        "heading" => esc_html__("Show prefix", "ptsc"),
                    ),

                    "combo_name" => array(
                        "heading" => esc_html__("Combo Name", "ptsc"),
                    ),
                );
                break;
            case "makli_client_area":
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Client Area", "ptsc"),
                    ),
                    "params" => array(
                        array(
                            "type" => "textfield",
                            "heading" => __("No Parameter", "ptsc"),
                            "param_name" => "default",
                            "value" => __("", "ptsc"),
                            "description" => __("Displays the Makli Client Area. It takes no necessary parameters to work by default,  Settings are controlled by admin area settings.", "ptsc")
                        ),
                    ),
                );
                break;
            case "makli_cart_single_page":
                return array(
                    "vc_options" => array(
                        "title" => esc_html__("Makli Checkout", "ptsc"),
                    ),
                    "style" => array(
                        "vc_type" => "dropdown",
                        "heading" => "Select template File",
                        "value" => array(
                            esc_html__("Dafault", "ptsc") => "01_default",
                            esc_html__("Sleek Minimal", "ptsc") => "02_sleek_minimal",
                            esc_html__("Bold", "ptsc") => "03_bold",
                            esc_html__("Ease", "ptsc") => "04_ease",
                            esc_html__("Simple", "ptsc") => "05_simple",
                            esc_html__("Sleek", "ptsc") => "06_sleek",
                            esc_html__("Minimal", "ptsc") => "07_minimal",
                            esc_html__("Elegant", "ptsc") => "08_elegant",
                            esc_html__("Collapse", "ptsc") => "09_collapse",
                        ),
                        "description" => "Select HTML template file",

                    ),
                    "hide_product" => array(
                        "vc_type" => "noyes",
                        "heading" => esc_html__("Hide Product", "ptsc"),
                    ),

                    "pid" => array(
                        "vc_type" => "",
                        "heading" => esc_html__("Product id", "ptsc"),
                    ),

                    "billingcycle" => array(
                        "vc_type" => "dropdown",
                        "value" => array(
                            esc_html__("Monthly", "ptsc") => "monthly",
                            esc_html__("Quarterly", "ptsc") => "quarterly",
                            esc_html__("Semi Annually", "ptsc") => "semiannually",
                            esc_html__("Annually", "ptsc") => "annually",
                            esc_html__("Bi Annually", "ptsc") => "biennially",
                            esc_html__("Tri Annually", "ptsc") => "triennially",
                        ),
                        "heading" => esc_html__("BillingCycle", "ptsc"),

                    ),

                );
                break;
            default:
                return array();
        }
    }

    public function all_shortcodes()
    {
        $group = $this->ptsc_group;
        $groups = $group->ptsc_select();
        if (is_array($groups) && sizeof($groups) > 0) {
            $shortcodes = array();
            foreach ($groups as $group) {
                $shortcodes["ptsc_comparison_table"] = '[ptsc_comparison_table id="' . $group["group_id"] . '"]';
                $shortcodes["ptsc_order_slider"] = '[ptsc_order_slider id="' . $group["group_id"] . '"]';
                $shortcodes["ptsc_pricing_table_group"] = '[ptsc_pricing_table_group id="' . $group["group_id"] . '"]';
                $shortcodes["ptsc_pricing_table"] = '[ptsc_pricing_table id="' . $group["group_id"] . '"]';
            }
        }
        return $shortcodes;
    }

    public function get_table_name($name = "")
    {
        global $wpdb;

        switch ($name) {
            case "groups":
                return $wpdb->prefix . "ptsc_groups";
            case "products":
                return $wpdb->prefix . "ptsc_products";
            case "tooltips":
                return $wpdb->prefix . "ptsc_tooltips";
            case "group_details":
                return $wpdb->prefix . "ptsc_group_details";
            case "currencies":
                return $wpdb->prefix . "ptsc_currencies";
            case "pricings":
                return $wpdb->prefix . "ptsc_pricings";
            default:
                return $wpdb->prefix . "ptsc_groups";
        }
    }

    function ptsc_products_name()
    {
        $products_info = $this->ptsc_products;
        $list_products = $products_info->ptsc_select();
        $pro_name_id = [];
        foreach ($list_products as $pro) {
            $pro_name_id[$pro["product_name"] . " (" . $pro["product_id"] . ")"] = $pro["product_id"];
        }
        return $pro_name_id;
    }

    public function get_custom_fields($shortcode)
    {


        $Files = $this->get_template_files($shortcode);
        $custom_field = [];
        $All_custom_fields = [];
        if (is_array($Files["custom_fields"])) {

            foreach ($Files["custom_fields"] as $custom_field) {
                foreach ($custom_field as $k => &$cs) {
                    if (is_null($cs)) {
                        unset($custom_field[$k]);
                    } elseif ($this->is_json(str_replace("'", '"', $cs))) {
                        $cs = json_decode(str_replace("'", '"', $cs), true);
                    }
                }

                if (isset($custom_field["type"]) && $custom_field["type"] == "dropdown" && isset($custom_field["value"]) && !is_array($custom_field["value"])) {
                    $custom_field["value"] = explode(",", $custom_field["value"]);
                    $custom_field["value"] = array_map('trim', $custom_field["value"]);
                }

                $custom_field = array_filter($custom_field);

                if (!isset($custom_field["admin_label"])) {
                    $custom_field["admin_label"] = false;
                }

                $All_custom_fields[] = $custom_field;
            }
        }

        return $All_custom_fields;
    }

    public function get_products_from_category_by_ID($category_id)
    {

        $products = new WP_Query(array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'fields' => 'ids',
            'tax_query' => array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'term_id',
                    'terms' => $category_id,
                )
            ),

        ));
        return $products->posts;
    }

    public function accessProtected($obj, $prop)
    {
        $reflection = new ReflectionClass($obj);
        $property = $reflection->getProperty($prop);
        $property->setAccessible(true);
        return $property->getValue($obj);
    }

    public function ptsc_woocommerce_shortcode($atts)
    {
        /*$actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
        ppa($actual_link);*/
        /*$link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF'];
        $link = substr(strrchr($link, '/'), 2);*/
        $woocommerce_cart_url = wc_get_cart_url();
        extract(shortcode_atts([
            "rows" => '',
            "sep" => '',
            "billingcycle" => '',
            "html_template" => '',
            "woocommercepid" => '',
            "description_option" => '',
            "featured_text" => '',
            "enable_tooltips" => '',
            "primary_color" => '',
            "secondary_color" => '',
            "process_description" => '',
            "custom_text" => '',
            "image_url" => '',
            "button_text" => 'Add to Cart',
            "featured" => '',
            "woocommercepid" => '0',
        ], $atts));

        $group_woo = array();
        $template_pic_03 = substr(strrchr($html_template, '/'), 1);
        $product_WC = wc_get_product($woocommercepid);
        /*$product_WC = (array) $product_WC;*/
        $woo_prod_array = $this->accessProtected($product_WC, "data");
        $group_woo = array_merge($group_woo, $woo_prod_array);

        $html_template = $this->get_template_file($html_template, 'ptsc_pricing_table');
        $html_template = $this->select_tpl_first($html_template);
        $woo_currency_prefix = get_woocommerce_currency_symbol();
        $woo_currency_suffix = get_woocommerce_currency();
        $Woo_price = ($woo_prod_array["sale_price"] == "") ? $woo_prod_array["regular_price"] : $woo_prod_array["sale_price"];


        if (is_file($html_template)) {
            $group_woo["prefix"] = $woo_currency_prefix;
            $group_woo["suffix"] = $woo_currency_suffix;


            $group_woo["price"] = $Woo_price;
            $group_woo["amount"] = $Woo_price;
            $group_woo["fraction"] = "";
            $group_woo["decimal"] = "2";
            $group_woo["prefix"] = $group_woo["prefix"];
            $group_woo["suffix"] = $group_woo["suffix"];
            $group_woo["duration"] = "One Time";
            $group_woo["billingcycle"] = "monthly";
            $group_woo["billingcycle2"] = "";
            $group_woo["order_url"] = "";

            $group_woo["plan"]["all_durations"] = $this->all_prices_woo($group_woo, [
                $group_woo["billingcycle"]

            ]);

            $group_woo["plan"]["product_name"] = $woo_prod_array["name"];
            $group_woo["plan"]["prefix"] = $group_woo["prefix"];
            $group_woo["plan"]["pay_type"] = "one time";
            $group_woo["plan"]["featured_text"] = $featured_text;
            $group_woo["group"]["enable_tooltips"] = $enable_tooltips;


            $group_woo["plan"]["primary_color"] = $primary_color;
            $group_woo["plan"]["secondary_color"] = $secondary_color;
            $group_woo["plan"]["process_description"] = $process_description;
            $group_woo["plan"]["show_order_combo"] = "no";
            $group_woo["plan"]["show_description_icon"] = "yes";
            $group_woo["plan"]["price_sub_text"] = "";
            $group_woo["plan"]["product_tag_line"] = $custom_text;
            $group_woo["plan"]["custom_text_1"] = $custom_text;
            $group_woo["plan"]["custom_text_2"] = "";
            $group_woo["plan"]["custom_text_3"] = "";
            $group_woo["plan"]["image_url"] = $image_url;
            $group_woo["plan"]["product_detail"] = $custom_text;
            //$button_text = get_option("button_text");
            ob_start(); ?>
            <div class="pricing_table_submit">
                <div class="holder">
                    <a href="<?php echo $woocommerce_cart_url ?>?add-to-cart=<?php echo $woocommercepid ?>"
                       type="button" class="ptsc-btn ptsc_order_button"
                       href=""><?php echo $button_text ?></a>
                </div>
            </div>
            <?php
            $group_woo["plan"]["product_order_button"] = ob_get_clean();
            if ($featured == "yes") {
                $group_woo["plan"]["featured"] = "yes";
            } else {
                $group_woo["plan"]["featured"] = "no";
            }

            if ($description_option == "wc_desc") {

                $group_woo["plan"]["product_description"] = $woo_prod_array["description"];

                //== Get Description from WooCommerce Product
                $plan_description = $group_woo["plan"]["product_description"];
            }

            if ($description_option == "wc_custom_desc") {
                //== Get All Custom fields of WooCommerce Product
                $custom_fields = get_post_custom($woocommercepid);

                //== Get Description from custom field of WooCommerce Product
                $plan_description = $custom_fields["_ptsc_description"]["0"];
            }

            if ($enable_tooltips == "yes") {
                $group_woo["description"] = $this->linked_description_to_array($plan_description, $rows, $sep, 3, 1);
                //~~Description in Associative Array
                $group_woo["description_array1"] = $this->linked_description_to_array($plan_description, $rows, $sep, 4, 1);

                $group_woo["split_description"] = $this->linked_description_to_array($plan_description, $rows, $sep, 5, 1);
            } else {
                //~~Description in array
                $group_woo["description"] = $this->description_to_array($plan_description, $rows, $sep, 3, 1);
                //~~Description in Associative Array
                $group_woo["description_array1"] = $this->description_to_array($plan_description, $rows, $sep, 4, 1);

                $group_woo["split_description"] = $this->description_to_array($plan_description, $rows, $sep, 5, 1);
            }
            $group_woo["plan"]["split_description"] = $group_woo["split_description"];
            if (strpos($plan_description, $sep) !== false) {
                $group_woo["plan"]["description_process"] = "true";
            } else {
                $group_woo["plan"]["description_process"] = "false";
            }

            if ($image_url == "" && $template_pic_03 == "pic-03-mod.tpl") {
                $image_url = "http://sajid.hostriplex.com/whmpress/wp-content/uploads/2018/01/download.png";
            } else {
                $image_url = $image_url;
            }
            $group_woo['plan']['image_url'] = ($image_url == "") ? "http://sajid.hostriplex.com/whmpress/wp-content/uploads/2018/01/plan02.jpg" : $image_url;

            $r = rand();
            $vars_woo = $group_woo;
            unset($vars_woo["plans"]);


            $random_id = 'ptsc_table_' . rand(10000, 99999);

            $vars_woo["random_id"] = $random_id;

            $OutputString_woo = $this->ptsc_smarty_template($html_template, $vars_woo);
            echo $OutputString_woo;
            return $OutputString_woo;
        }
    }

    public function ptsc_woocommerce_group_pricing_table_shortcode($atts)
    {
        extract(shortcode_atts([
            'html_template' => "",
            'image' => "",
            'product_id' => "",
            'woocommerce_multiple_pids' => "",
            'description_option' => "",
            'featured_rows' => "",
            'description_separator' => "",
            'billingcycle' => "",
            'billingcycle2' => "",
            'enable_tooltips' => "",
            'button_text' => "",
            'hide_width_table' => "",
            'featured_text' => "",
            'toggle_style' => "",
            'enable_table_carousel' => "",
            'woocommerce_featured_id' => "",
            'process_description' => "",
            'custom_text' => "",
            'show_order_combo' => "",
            'image_url' => "",
            "pay_type" => "",
        ], $atts));

        $template_pic_03 = substr(strrchr($html_template, '/'), 1);
        $WC_product_count = count($woocommerce_multiple_pids);
        $rows = $featured_rows;

        //== Save all product data in one Array
        $count = 0;
        $WC_product_para = array();
        foreach ($woocommerce_multiple_pids as $WC_p_id) {
            $WC_product_para[$count] = wc_get_product($WC_p_id);
            $count++;
        }
        //== Get data array from WC Products
        $count = 0;

        foreach ($WC_product_para as $single_WC) {
            $WC_data_array[$count] = $this->accessProtected($single_WC, "data");
            $count++;
        }

        //== Populate Group with All 3 products
        $WC_group_para["plans"] = $WC_data_array;

        //== Set width for different Number of Pricing Tables
        if ($WC_product_count == "1") {
            $cols = "12";
            $column_class = "one_cols";
        } elseif ($WC_product_count == "2") {
            $cols = "9";
            $column_class = "two_cols";
        } elseif ($WC_product_count == "3") {
            $cols = "4";
            $column_class = "three_cols";
        } elseif ($WC_product_count == "4") {
            $cols = "3";
            $column_class = "four_cols";
        } elseif ($WC_product_count == "5") {
            $cols = "2";
            $column_class = "five_cols";
        } elseif ($WC_product_count == "6") {
            $cols = "2";
            $column_class = "six_cols";
        } else {
            $cols = "3";
            $column_class = "three_cols";
        }

        //== Set Separator
        $sep = $description_separator;
        if (empty($sep)) {
            $sep = ":";
        }

        //== Set Default html template
        $html_template = $html_template;
        if ($html_template == trim("")) {
            $html_template = "default.tpl";
        }

        //== Get html template file
        $html_template = $this->get_template_file($html_template, 'ptsc_pricing_table_group');


        //== If there is a template file make an array to be passed to smarty
        $html_template = $this->select_tpl_first($html_template);

        $woo_currency_prefix = get_woocommerce_currency_symbol();
        $woo_currency_suffix = get_woocommerce_currency();
        //== If html file is valid
        if (is_file($html_template)) {
            $WC_group_para["prefix"] = $woo_currency_prefix;
            $WC_group_para["suffix"] = $woo_currency_suffix;
            $WC_group_para["billingcycle"] = $billingcycle;
            $WC_group_para["billingcycle2"] = $billingcycle2;
            $WC_group_para["show_discount"] = "no";
            $WC_group_para["decimals"] = get_option("decimals");
            $WC_group_para["show_duration_as"] = get_option("show_duration_as");
            $WC_group_para["rows_table"] = $featured_rows;
            $WC_group_para["enable_tooltips"] = $enable_tooltips;
            $WC_group_para["button_text"] = $button_text;
            $WC_group_para["enable_table_carousel"] = $enable_table_carousel;
            $WC_group_para["ribbon_text"] = $featured_text;
            $WC_group_para["toggle_style"] = $toggle_style;
            $WC_group_para_saved = $WC_group_para;

            $count = 0;
            foreach ($WC_group_para["plans"] as &$plan) {
                $Woo_price = ($plan["sale_price"] == "") ? $plan["regular_price"] : $plan["sale_price"];
                $plan["price"] = $Woo_price;
                $plan['show_discount'] = $atts['show_discount'];
                $plan["amount"] = $Woo_price;
                $plan["fraction"] = "";
                $plan["decimal"] = "2";
                $plan["prefix"] = $woo_currency_prefix;
                $plan["suffix"] = $woo_currency_suffix;
                $plan["duration"] = "one Time";
                $plan["billingcycle"] = "monthly";
                $plan["billingcycle2"] = "";
                $plan["product_name"] = $plan["name"];
                $plan["font_awesome"] = "";
                $plan["cdescription"] = "";
                $plan["order_url"] = "";
                $plan["pay_type"] = $pay_type;
                $plan['complete_discount_string']['primary_discount_string'] = '';
                $plan["all_durations"] = $this->all_prices_woo($plan, [
                    $billingcycle,
                ]);

                //$plan['complete_discount_string'] = $this->ptsc_discount_string($plan,$group);

                $plan['multi_price'] = $this->ptsc_auto_plan_price($plan);

                if ($description_option == "wc_desc") {
                    $plan_description = $plan["description"];
                } elseif ($description_option == "wc_custom_desc") {
                    //== Get All Custom fields of WooCommerce Product
                    $custom_fields = get_post_custom($woocommerce_multiple_pids[$count]);

                    //== Get Description from custom field of WooCommerce Product
                    $plan_description = $custom_fields["_ptsc_description"]["0"];
                }

                $plan['product_description'] = $plan_description;

                //== Get All Custom fields of WooCommerce Product
                /*$custom_fields = get_post_custom($woocommercepid);*/

                //== Get Description from custom field of WooCommerce Product
                /*$plan_description = $custom_fields["_ptsc_description"]["0"];*/

                $plan["description"] = $this->description_to_array($plan_description, $rows, $sep, 3, 1);
                //~~Description in Associative Array
                $plan["description_array"] = $this->description_to_array($plan_description, $rows, $sep, 4, 1);

                $plan["split_description"] = $this->description_to_array($plan_description, $rows, $sep, 5, 1);


                if ($woocommerce_multiple_pids[$count] == $woocommerce_featured_id) {
                    $plan["featured"] = "yes";
                } else {
                    $plan["featured"] = "no";
                }

                if ($process_description == "yes") {
                    $plan["description_process"] = "true";
                } else {
                    $plan["description_process"] = "false";
                }

                $plan["primary_color"] = "";
                $plan["secondary_color"] = "";
                $plan["process_description"] = $process_description;
                //$vars["show_order_combo"] = "yes";
                $plan["show_description_icon"] = "yes";
                $plan["price_sub_text"] = "";
                /*$plan["product_tag_line"] = "This is the custom text";*/
                $plan["custom_text_1"] = $custom_text;
                $plan["custom_text_2"] = "";
                $plan["custom_text_3"] = "";
                $plan["featured_text"] = $featured_text;
                $plan["product_detail"] = $custom_text;
                $plan["product_tag_line"] = "";
                $plan["image_url"] = $image_url;
                $plan["price_sub_text"] = "";
                /*$plan["process_description"] = "yes";*/
                $plan["show_order_combo"] = "no";
                if ($image_url == "" && $template_pic_03 == "pic-03-mod-group.tpl") {
                    $image_url = "http://sajid.hostriplex.com/whmpress/wp-content/uploads/2018/01/download.png";
                } else {
                    $image_url = $image_url;
                }
                $plan['image_url'] = ($image_url == "") ? "http://sajid.hostriplex.com/whmpress/wp-content/uploads/2018/01/plan02.jpg" : $image_url;
                $woocommerce_cart_url = wc_get_cart_url();
                $plan["order_url"] = $woocommerce_cart_url . "?add-to-cart=" . $woocommerce_multiple_pids[$count];
                ob_start(); ?>
                <div class="pricing_table_submit">
                    <div class="holder">
                        <a type="button" class="ptsc-btn ptsc_order_button"
                           href="<?php echo $woocommerce_cart_url ?>?add-to-cart=<?php echo $woocommerce_multiple_pids[$count] ?>"><?php echo $button_text ?></a>
                    </div>
                </div>
                <?php
                $plan["product_order_button"] = ob_get_clean();

                $plan["product_detail"] = $custom_text;
                $count++;
            }
            $r = rand();
            $WC_group_para['duration_toggle'] = "";
            /*$group_para['dropdown_duratoin_toggle'] = $ptsc->ptsc_prepare_duration_dropdown($group_para, $r);*/
            $vars = [
                "group" => $WC_group_para,
            ];

            $vars["random"] = $r;
            $vars["prefix"] = $WC_group_para["prefix"];
            $vars["show_description_tooltip"] = $WC_group_para["enable_tooltips"];

            $OutputString = $this->ptsc_smarty_template($html_template, $vars);
            //echo $OutputString;

        }
        return $OutputString;

    }

    public function ptsc_woocommerce_comparison_table_shortcode($atts)
    {

        extract(shortcode_atts([
            'html_template' => "",
            'image' => "",
            'woocommerce_multiple_pids' => "",
            'featured_rows' => "",
            'description_separator' => "",
            'billingcycle' => 'monthly',
            'billingcycle2' => '',
            'enable_tooltips' => "",
            'button_text' => "Add to Cart",
            'show_discount' => '',
            'hide_width_comparison' => "",
            'featured_text' => "",
            'toggle_style' => '',
            'show_yes_no_icon' => "",
            'convert_yes_with' => "",
            'convert_no_with' => "",
            'woocommerce_featured_id' => "",
            'show_discount' => ''
        ], $atts));

        $html_template = $html_template;
        if ($html_template == trim("")) {
            $html_template = "default.tpl";
        }
        $rows = $featured_rows;
        $enable_tooltips = $enable_tooltips == "yes" ? 1 : 0;
        $show_yes_no_icon = $show_yes_no_icon == "yes" ? 1 : 0;

        $sep = $description_separator;
        if (empty($sep)) {
            $sep = ":";
        }
        $WC_group_para["have_sections"] = 0;
        $WC_group_para["mobile_breakpoint"] = $hide_width_comparison;
        $WC_group_para["billingcycle"] = "monthly";
        $WC_group_para["billingcycle2"] = "";
        $WC_group_para["show_discount"] = "no";
        $WC_group_para["decimals"] = get_option("decimals");
        $WC_group_para["show_duration_as"] = get_option("show_duration_as");
        $WC_group_para["important"] = "";
        $WC_group_para["show_discount_secondary"] = "";
        $WC_group_para['convert_to_symbol'] = $show_yes_no_icon;
        $WC_group_para['convert_no_with'] = $convert_no_with;
        $WC_group_para['convert_yes_with'] = $convert_yes_with;
        $WC_group_para['button_text'] = $button_text;
        $WC_group_para['enable_tooltips'] = $enable_tooltips;
        $WC_group_para["ribbon_text"] = $featured_text;

        $WC_product_count = count($woocommerce_multiple_pids);

        //== Save all product data in one Array
        $count = 0;
        $WC_product_para = array();
        foreach ($woocommerce_multiple_pids as $WC_p_id) {
            $WC_product_para[$count] = wc_get_product($WC_p_id);
            $count++;
        }

        //== Get data array from WC Products
        $count = 0;
        foreach ($WC_product_para as $single_WC) {
            $WC_data_array[$count] = $this->accessProtected($single_WC, "data");
            $count++;
        }

        $WC_group_para["plans"] = $WC_data_array;
        $woo_currency_prefix = get_woocommerce_currency_symbol();
        $woo_currency_suffix = get_woocommerce_currency();

        $WC_group_para["prefix"] = $woo_currency_prefix;

        $html_template = $this->get_template_file($html_template, 'ptsc_comparison_table');
        $html_table_class = str_replace(['.html', '.tpl'], '', basename($html_template));
        $html_template = $this->select_tpl_first($html_template);


        //== If html_template is valid
        if (is_file($html_template)) {
            $count = 0;
            foreach ($WC_group_para["plans"] as &$plan) {
                $Woo_price = ($plan["sale_price"] == "") ? $plan["regular_price"] : $plan["sale_price"];
                $WC_group_para["prefix"] = $woo_currency_prefix;
                $WC_group_para["suffix"] = $woo_currency_suffix;
                $plan["decimal"] = '.';
                $plan["prefix"] = $woo_currency_prefix;
                $plan["suffix"] = $woo_currency_suffix;
                $plan["price"] = $Woo_price;
                $plan["amount"] = $Woo_price;
                $plan["fraction"] = "";
                $plan["featured"] = "";
                $plan["name"] = $plan["name"];
                $plan["cdescription"] = "";
                $woocommerce_cart_url = wc_get_cart_url();
                $plan["order_url"] = $woocommerce_cart_url . "?add-to-cart=" . $woocommerce_multiple_pids[$count];
                $plan["duration"] = "one Time";
                $plan["product_id"] = $woocommerce_multiple_pids[$count];
                $plan['show_discount'] = $atts['show_discount'];
                $plan['complete_discount_string']['primary_discount_string'] = '';
                $plan["all_durations"] = $this->all_prices_woo($plan, [
                    $billingcycle,
                ]);


                /*$plan_description = $plan["description"];*/

                //== Get All Custom fields of WooCommerce Product
                $custom_fields = get_post_custom($woocommerce_multiple_pids[$count]);

                //== Get Description from custom field of WooCommerce Product
                $plan_description = isset($custom_fields["_ptsc_description"]["0"]) ? $custom_fields["_ptsc_description"]["0"] : '';
                $plan["description"] = $this->description_to_array($plan_description, $rows, $sep, 3, 1);
                $plan["description_array"] = $this->linked_description_to_array($plan_description, $rows, $sep, 4, 1);

                if ($woocommerce_multiple_pids[$count] == $woocommerce_featured_id) {
                    $plan["featured"] = "yes";
                } else {
                    $plan["featured"] = "no";
                }
                $tmp = $this->description_to_array($plan_description, $rows, $sep, 3, false);

                //~~ build sections
                $section_index = 0;
                $description_section_index = 0;
                $description_section = [];
                foreach ($tmp as $line) {
                    if (strpos($line, "--") !== false && strpos($line, "--", 3) == true) {
                        $description_section_index = $section_index;
                        $section = str_replace("--", "", $line);
                        $WC_group_para["section"][$section_index] = $section;
                        $WC_group_para["have_sections"] = 1;
                        $section_index++;
                    } else {
                        $strpos = strpos($line, $sep);
                        $feature = substr($line, 0, $strpos - 1);
                        $value = trim(substr($line, $strpos + 1));
                        if ($strpos === false) {
                            $plan["description_section"][$line] = "";
                        } else {
                            $plan["description_section"][$description_section_index][$feature] = [
                                "value" => $value,
                                "tooltip" => $this->return_tooltip($feature),
                            ];
                        }
                    }
                }

                $count++;
            }

            $vars = [
                "group" => $WC_group_para,
            ];

            $vars["random"] = $r = rand();


            $vars['group_new'] = $this->ptsc_prepare_html($WC_group_para, $html_table_class, $r);


            $OutputString = $this->ptsc_smarty_template($html_template, $vars);
        }//== End if html template file is valid

        return $OutputString;
    }

    public function ptsc_woocommerce_slider_shortcode($atts)
    {
        extract(shortcode_atts([
            'html_template' => '',
            'image' => '',
            'woocommerce_multiple_pids' => array(),
            'description_option' => '',
            'featured_rows' => '10',
            'description_separator' => ':',
            'billingcycle' => 'monthly',
            'billingcycle2' => '',
            'enable_tooltips' => '',
            'button_text' => 'Buy Now',
            'show_discount' => '',
            'hide_width_slider' => '',
            'featured_text' => '',
            'process_description' => 'yes',
        ], $atts));

        $WC_product_count = count($woocommerce_multiple_pids);
        $woocommerce_cart_url = wc_get_cart_url();

        //== Save all product data in one Array
        $count = 0;
        $WC_product_para = array();
        foreach ($woocommerce_multiple_pids as $WC_p_id) {
            $WC_product_para[$count] = wc_get_product($WC_p_id);
            $count++;
        }
        //== Get data array from WC Products
        $count = 0;
        foreach ($WC_product_para as $single_WC) {
            $WC_data_array[$count] = $this->accessProtected($single_WC, "data");
            $count++;
        }
        //== Populate Group with All 3 products
        $WC_group_para["plans"] = $WC_data_array;

        $html_template = $html_template;
        if ($html_template == trim("")) {
            $html_template = "default.tpl";
        }
        // Get html template file
        $html_template = $this->get_template_file($html_template, 'ptsc_order_slider');

        /**~~----------------------------------------------------------------
         * If there is a template file make an array to be passed to smarty
         * --------------------------------------------------------------------*/
        $html_template = $this->select_tpl_first($html_template);

        //== If Template file is valid
        if (is_file($html_template)) {
            //~~ Extract veriable that are not package dependent for later use in code.
            $sep = $description_separator;
            if (empty($sep)) {
                $sep = ":";
            }
            $rows = $featured_rows;

            $woo_currency_prefix = get_woocommerce_currency_symbol();
            $woo_currency_suffix = get_woocommerce_currency();

            $WC_group_para["prefix"] = $woo_currency_prefix;
            $WC_group_para["suffix"] = $woo_currency_suffix;
            /*$WC_group_para["currency"] = $currency_info["c_id"];*/
            $WC_group_para["billingcycle"] = "monthly";
            $WC_group_para["billingcycle2"] = "";
            $WC_group_para["show_discount"] = "no";
            $WC_group_para["decimals"] = get_option("decimals");
            $WC_group_para["show_duration_as"] = get_option("show_duration_as");
            $WC_group_para["rows"] = $featured_rows;
            $WC_group_para["enable_tooltips"] = $enable_tooltips;
            $WC_group_para["button_text"] = $button_text;
            $WC_group_para['duration_toggle'] = "";

            $count = 0;
            foreach ($WC_group_para["plans"] as &$plan) {
                $Woo_price = ($plan["sale_price"] == "") ? $plan["regular_price"] : $plan["sale_price"];
                $plan["price"] = $Woo_price;
                $plan["amount"] = $Woo_price;
                /*$plan["fraction"] = $price_tmp["fraction"];*/

                $plan["prefix"] = $WC_group_para["prefix"];
                $plan["suffix"] = $WC_group_para["suffix"];
                $plan["fraction"] = "";
                $plan["decimal"] = $WC_group_para["decimals"];
                $plan["duration"] = "one Time";
                $plan["billingcycle"] = $WC_group_para["billingcycle"];
                $plan["name"] = $plan["name"];
                $plan["show_discount"] = $atts["show_discount"];
                $plan["complete_discount_string"]['primary_discount_string'] = '';
                $plan["order_url"] = $woocommerce_cart_url . "?add-to-cart=" . $woocommerce_multiple_pids[$count];
                $plan["all_durations"] = $this->all_prices_woo($plan, [
                    $billingcycle,
                ]);

                if ($description_option == "wc_desc") {
                    $plan_description = $plan["description"];
                } elseif ($description_option == "wc_custom_desc") {
                    //== Get All Custom fields of WooCommerce Product
                    $custom_fields = get_post_custom($woocommerce_multiple_pids[$count]);

                    //== Get Description from custom field of WooCommerce Product
                    $plan_description = $custom_fields["_ptsc_description"]["0"];
                }
                if ($WC_group_para["enable_tooltips"] == 1) {
                    $plan["description"] = $this->linked_description_to_array($plan_description, $rows, $sep, 3, 1);
                    //~~Description in Associative Array
                    $plan["description_array"] = $this->linked_description_to_array($plan_description, $rows, $sep, 4, 1);

                } else {
                    //~~Description in array
                    $plan["description"] = $this->description_to_array($plan_description, $rows, $sep, 3, 1);
                    //~~Description in Associative Array
                    $plan["description_array"] = $this->description_to_array($plan_description, $rows, $sep, 4, 1);

                }

                /*if ($plan["product_id"] == $featured_id) {
                    $plan["featured"] = "yes";
                } else {
                    $plan["featured"] = "no";
                }*/

                $plan['multi_price'] = $this->ptsc_prepare_plan_price($plan);

                $plan["url"] = $woocommerce_cart_url . "?add-to-cart=" . $woocommerce_multiple_pids[$count];
                $plan['multi_button'] = $this->ptsc_prepare_plan_button($WC_group_para, $plan);


                if ($process_description == "yes") {
                    $plan["description_process"] = "true";
                } else {
                    $plan["description_process"] = "false";
                }
                $count++;
            }
            $r = rand();

            $WC_group_para["primary_color"] = get_option('ptsc_primary_color');
            $WC_group_para["secondary_color"] = get_option('ptsc_secondary_color');
            $vars = [
                "group" => $WC_group_para,
            ];
            $vars["ptsc_GRP_URL"] = PTSC_URL;
            $vars["random"] = $r;


            $OutputString = $this->ptsc_smarty_template($html_template, $vars);
        }
        return $OutputString;
    }

    public function All_available_group_ids($name)
    {
        global $wpdb;
        $result[] = "--Select widget id--";
        //$name = 'single pricing table';
        $Q = "SELECT `group_id` FROM `" . $this->get_table_name("groups") . "` WHERE `name`= '$name' ";
        $id_array = $wpdb->get_results($Q, ARRAY_A);
        foreach ($id_array as $id) {
            $result[$id["group_id"]] = $id["group_id"];
        }
        return $result;
    }

    public function wc_active_deactive_text()
    {
        if (!class_exists('WooCommerce')) {
            $vendor_option = esc_html__("WooCommerce (not istalled)", "ptsc");
        } else {
            $vendor_option = esc_html__("WooCommerce", "ptsc");
        }
        return $vendor_option;
    }

    public function wc_all_products()
    {

        // If WooCommerce is installed and activated then populate array with WC products ids.
        $pro_name_WC = array();
        if (class_exists('WooCommerce')) {
            $categories_ids = get_terms("product_cat", "term_id");
            /*ppa($categories_ids);*/
            foreach ($categories_ids as $cat) {

                $product_WC_product_id = $this->get_products_from_category_by_ID($cat);
                $product_WC_name = array();
                foreach ($product_WC_product_id as $index => $id) {
                    $product_WC_name[] = get_the_title($id);
                }
                foreach ($product_WC_name as $index_pro => $name_pro) {
                    $pro_name_WC[$cat->name . " (" . $cat->term_id . " )" . " > " . $name_pro . " " . "(" . $product_WC_product_id[$index_pro] . ")"] = $product_WC_product_id[$index_pro];
                }
            }
        }
        return $pro_name_WC;
    }

    public function Elementor_html_file_list($name)
    {
        //==Get All html template files
        $FilesList = $ImagesList = [];
        $FilesList["Default"] = "";
        $ImagesList["Default"] = "";

        $AllTemplateFiles = $this->get_all_ptsc_template_files($name);
        foreach ($AllTemplateFiles as $FILE) {
            $FilesList[$FILE['description']] = $FILE['file_path'];
        }
        return $FilesList;
    }

    public function Elementor_BillingCycles()
    {
        $BillingCycles["Default/Onetime"] = "monthly";
        $BillingCycles["Quarterly"] = "quarterly";
        $BillingCycles["Semi Annually"] = "semiannually";
        $BillingCycles["Annually"] = "annually";
        $BillingCycles["Biennially"] = "biennially";
        $BillingCycles["Triennially"] = "triennially";

        return $BillingCycles;
    }

    public function charater_limits($no_of_plans)
    {
        $limit = 0;
        if ($no_of_plans == 2) {
            $limit = 40;
        } elseif ($no_of_plans == 3) {
            $limit = 28;
        } elseif ($no_of_plans == 4) {
            $limit = 23;
        } elseif ($no_of_plans == 5) {
            $limit = 12;
        } elseif ($no_of_plans >= 6) {
            $limit = 27;
        }
        return $limit;
    }


}

